@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: freeswan.h,v 1.2 2003/09/12 19:23:31 ken Exp $
+ * RCSID $Id: freeswan.h,v 1.1.1.1 2003/10/31 17:56:25 ken Exp $
  */
 #define	_FREESWAN_H	/* seen it, no need to see it again */
 
@@ -75,6 +75,16 @@
 #  define DEBUG_NO_STATIC static
 #endif /* CONFIG_IPSEC_DEBUG */
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL /* KERNEL ifdef */
+#ifndef NAT_TRAVERSAL
+#define NAT_TRAVERSAL
+#endif
+#endif
+#ifdef NAT_TRAVERSAL
+#define ESPINUDP_WITH_NON_IKE   1  /* draft-ietf-ipsec-nat-t-ike-00/01 */
+#define ESPINUDP_WITH_NON_ESP   2  /* draft-ietf-ipsec-nat-t-ike-02    */
+#endif
+
 /*
  * Basic data types for the address-handling functions.
  * ip_address and ip_subnet are supposed to be opaque types; do not
@@ -455,8 +465,9 @@ const char *optionsfrom(const char *filename, int *argcp, char ***argvp,
 
 extern unsigned int pfkey_lib_debug;  /* bits selecting what to report */
 
-/* 
- * for lwdnsq interaction
+/*
+ * pluto and lwdnsq need to know the maximum size of the commands to,
+ * and replies from lwdnsq. 
  */
 
 #define LWDNSQ_CMDBUF_LEN      1024
