@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_ah.h,v 1.2 2003/09/15 12:57:27 jjo Exp $
+ * RCSID $Id: ipsec_ah.h,v 1.1.1.1 2003/10/31 17:56:26 ken Exp $
  */
 
 #include "ipsec_md5h.h"
@@ -35,11 +35,6 @@
 
 #define AHMD596_BLKLEN  	64		/* MD5 block length */
 #define AHSHA196_BLKLEN 	64		/* SHA1 block length */
-#define AHSHA2_256_BLKLEN 	64		/* SHA2-256 block length */
-#define AHSHA2_384_BLKLEN 	128 		/* SHA2-384 block length (?) */
-#define AHSHA2_512_BLKLEN 	128		/* SHA2-512 block length */
-
-#define AH_BLKLEN_MAX 		128		/* keep up to date! */
 
 #define AH_AMAX         	AHSHA196_ALEN   /* keep up to date! */
 #define AHHMAC_HASHLEN  	12              /* authenticator length of 96bits */
@@ -112,11 +107,9 @@ extern int debug_ah;
 
 /*
  * $Log: ipsec_ah.h,v $
- * Revision 1.2  2003/09/15 12:57:27  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:26  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:49  ken
- * Stock 2.02
+ * Stock 2.03
  *
  * Revision 1.20  2003/02/06 02:21:34  rgb
  *
