@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_esp.h,v 1.2 2003/09/15 12:57:27 jjo Exp $
+ * RCSID $Id: ipsec_esp.h,v 1.1.1.1 2003/10/31 17:56:27 ken Exp $
  */
 
 #include "freeswan/ipsec_md5h.h"
@@ -24,8 +24,6 @@
 #define IPPROTO_ESP 50
 #endif /* IPPROTO_ESP */
 
-#define ESP_HEADER_LEN		8	/* 64 bits header (spi+rpl)*/
-
 #define EMT_ESPDESCBC_ULEN	20	/* coming from user mode */
 #define EMT_ESPDES_KMAX		64	/* 512 bit secret key enough? */
 #define EMT_ESPDES_KEY_SZ	8	/* 56 bit secret key with parity = 64 bits */
@@ -33,9 +31,6 @@
 #define EMT_ESPDES_IV_SZ	8	/* IV size */
 #define ESP_DESCBC_BLKLEN       8       /* DES-CBC block size */
 
-#define ESP_IV_MAXSZ		16	/* This is _critical_ */
-#define ESP_IV_MAXSZ_INT	(ESP_IV_MAXSZ/sizeof(int))
-
 #define DB_ES_PKTRX	0x0001
 #define DB_ES_PKTRX2	0x0002
 #define DB_ES_IPSA	0x0010
@@ -66,10 +61,6 @@ esp_rcv(struct sk_buff *skb,
 	int redo,
 	struct inet_protocol *protocol);
 
-/* 
- * XXX: only for 64 bits IVs, eg. ESP_3DES,
- * there should really be esp_iv[0] 
- */
 struct esphdr
 {
 	__u32	esp_spi;		/* Security Parameters Index */
@@ -84,11 +75,9 @@ extern int debug_esp;
 
 /*
  * $Log: ipsec_esp.h,v $
- * Revision 1.2  2003/09/15 12:57:27  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:27  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:49  ken
- * Stock 2.02
+ * Stock 2.03
  *
  * Revision 1.21  2003/02/06 02:21:34  rgb
  *
