@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_kversion.h,v 1.1.1.1 2003/09/12 19:02:49 ken Exp $
+ * RCSID $Id: ipsec_kversion.h,v 1.1.1.1 2003/10/31 17:56:27 ken Exp $
  */
 #define	_FREESWAN_KVERSIONS_H	/* seen it, no need to see it again */
 
@@ -54,6 +54,12 @@
 #  ifndef CONFIG_IP_ALIAS
 #  define CONFIG_IP_ALIAS
 #  endif
+#include <linux/socket.h>
+#include <linux/skbuff.h>
+#include <linux/netlink.h>
+#  ifdef NETLINK_XFRM
+#  define NETDEV_25
+#  endif
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,25)
@@ -112,6 +118,26 @@
 #  define uint64_t __u64 
 #endif
 
+#ifdef NET_21
+# define ipsec_kfree_skb(a) kfree_skb(a)
+#else /* NET_21 */
+# define ipsec_kfree_skb(a) kfree_skb(a, FREE_WRITE)
+#endif /* NET_21 */
+
+#ifdef NETDEV_23
+# define device net_device
+# define ipsec_dev_get dev_get_by_name
+# define __ipsec_dev_get __dev_get_by_name
+# define ipsec_dev_put(x) dev_put(x)
+# define __ipsec_dev_put(x) __dev_put(x)
+# define ipsec_dev_hold(x) dev_hold(x)
+#else /* NETDEV_23 */
+# define ipsec_dev_get dev_get
+# define __ipsec_dev_put(x) 
+# define ipsec_dev_put(x)
+# define ipsec_dev_hold(x) 
+#endif /* NETDEV_23 */
+
 #ifndef SPINLOCK
 #  include <linux/bios32.h>
      /* simulate spin locks and read/write locks */
@@ -166,8 +192,20 @@
 
 /*
  * $Log: ipsec_kversion.h,v $
- * Revision 1.1.1.1  2003/09/12 19:02:49  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:27  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.7  2003/07/31 22:48:08  mcr
+ * 	derive NET25-ness from presence of NETLINK_XFRM macro.
+ *
+ * Revision 1.6  2003/06/24 20:22:32  mcr
+ * 	added new global: ipsecdevices[] so that we can keep track of
+ * 	the ipsecX devices. They will be referenced with dev_hold(),
+ * 	so 2.2 may need this as well.
+ *
+ * Revision 1.5  2003/04/03 17:38:09  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
  *
  * Revision 1.4  2002/04/24 07:36:46  mcr
  * Moved from ./klips/net/ipsec/ipsec_kversion.h,v
