@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_param.h,v 1.1.1.1 2003/09/12 19:02:50 ken Exp $
+ * RCSID $Id: ipsec_param.h,v 1.1.1.1 2003/10/31 17:56:28 ken Exp $
  *
  */
 
@@ -50,14 +50,16 @@
 /* Note that the "interfaces=" line in /etc/ipsec.conf would be, um, challenging. */
 
 /* use dynamic ipsecX device allocation */
+#ifndef CONFIG_IPSEC_DYNDEV
 #define CONFIG_IPSEC_DYNDEV 1
+#endif /* CONFIG_IPSEC_DYNDEV */
 
 
 #ifdef CONFIG_IPSEC_BIGGATE
-#define SADB_HASHMOD   8069
-#else
-#define SADB_HASHMOD	257
-#endif
+# define SADB_HASHMOD   8069
+#else /* CONFIG_IPSEC_BIGGATE */
+# define SADB_HASHMOD	257
+#endif /* CONFIG_IPSEC_BIGGATE */
 #endif /* __KERNEL__ */
 
 /*
@@ -70,86 +72,74 @@
  *
  */
 #ifndef IPSEC_SA_REF_TABLE_IDX_WIDTH
-#define IPSEC_SA_REF_TABLE_IDX_WIDTH 16
+# define IPSEC_SA_REF_TABLE_IDX_WIDTH 16
 #endif
 
 #ifndef IPSEC_SA_REF_MAINTABLE_IDX_WIDTH 
-#define IPSEC_SA_REF_MAINTABLE_IDX_WIDTH 4 
+# define IPSEC_SA_REF_MAINTABLE_IDX_WIDTH 4 
 #endif
 
 #ifndef IPSEC_SA_REF_FREELIST_NUM_ENTRIES 
-#define IPSEC_SA_REF_FREELIST_NUM_ENTRIES 256
+# define IPSEC_SA_REF_FREELIST_NUM_ENTRIES 256
 #endif
 
 #ifndef IPSEC_SA_REF_CODE 
-#define IPSEC_SA_REF_CODE 1 
+# define IPSEC_SA_REF_CODE 1 
 #endif
 
 #ifdef __KERNEL__
 /* This is defined for 2.4, but not 2.2.... */
 #ifndef ARPHRD_VOID
-#define ARPHRD_VOID 0xFFFF
+# define ARPHRD_VOID 0xFFFF
 #endif
 
-#ifdef NETDEV_23
-
-#define device net_device
-#define ipsec_dev_get __dev_get_by_name
-
-#else
-
-#define ipsec_dev_get dev_get
-
-#endif /* NETDEV_23 */
-
 /*
  * Worry about PROC_FS stuff
  */
 #if defined(PROC_FS_2325)
 /* kernel 2.4 */
-#define IPSEC_PROC_LAST_ARG ,int *eof,void *data
-#define IPSEC_PROCFS_DEBUG_NO_STATIC
-#define IPSEC_PROC_SUBDIRS
-
+# define IPSEC_PROC_LAST_ARG ,int *eof,void *data
+# define IPSEC_PROCFS_DEBUG_NO_STATIC
+# define IPSEC_PROC_SUBDIRS
 #else
 /* kernel <2.4 */
-#define IPSEC_PROCFS_DEBUG_NO_STATIC DEBUG_NO_STATIC
+# define IPSEC_PROCFS_DEBUG_NO_STATIC DEBUG_NO_STATIC
 
-#ifndef PROC_NO_DUMMY
-#define IPSEC_PROC_LAST_ARG , int dummy
-#else
-#define IPSEC_PROC_LAST_ARG
-#endif /* !PROC_NO_DUMMY */
+# ifndef PROC_NO_DUMMY
+#  define IPSEC_PROC_LAST_ARG , int dummy
+# else
+#  define IPSEC_PROC_LAST_ARG
+# endif /* !PROC_NO_DUMMY */
 #endif /* PROC_FS_2325 */
 
 #if !defined(LINUX_KERNEL_HAS_SNPRINTF)
 /* GNU CPP specific! */
-#define snprintf(buf, len, fmt...) sprintf(buf, ##fmt)
+# define snprintf(buf, len, fmt...) sprintf(buf, ##fmt)
 #endif /* !LINUX_KERNEL_HAS_SNPRINTF */
 
 #ifdef SPINLOCK
- #ifdef SPINLOCK_23
-  #include <linux/spinlock.h> /* *lock* */
- #else /* SPINLOCK_23 */
-  #include <asm/spinlock.h> /* *lock* */
- #endif /* SPINLOCK_23 */
+# ifdef SPINLOCK_23
+#  include <linux/spinlock.h> /* *lock* */
+# else /* SPINLOCK_23 */
+#  include <asm/spinlock.h> /* *lock* */
+# endif /* SPINLOCK_23 */
 #endif /* SPINLOCK */
 
 #ifndef KLIPS_FIXES_DES_PARITY
-#define KLIPS_FIXES_DES_PARITY 1
+# define KLIPS_FIXES_DES_PARITY 1
 #endif /* !KLIPS_FIXES_DES_PARITY */
 
 /* we don't really want to print these unless there are really big problems */
 #ifndef KLIPS_DIVULGE_CYPHER_KEY
-#define KLIPS_DIVULGE_CYPHER_KEY 0
+# define KLIPS_DIVULGE_CYPHER_KEY 0
 #endif /* !KLIPS_DIVULGE_CYPHER_KEY */
 
 #ifndef KLIPS_DIVULGE_HMAC_KEY
-#define KLIPS_DIVULGE_HMAC_KEY 0
+# define KLIPS_DIVULGE_HMAC_KEY 0
 #endif /* !KLIPS_DIVULGE_HMAC_KEY */
 
 #ifndef IPSEC_DISALLOW_IPOPTIONS
-#define IPSEC_DISALLOW_IPOPTIONS 1
+# define IPSEC_DISALLOW_IPOPTIONS 1
 #endif /* !KLIPS_DIVULGE_HMAC_KEY */
 
 /* extra toggles for regression testing */
@@ -161,12 +151,12 @@
  */
 extern int sysctl_ipsec_regress_pfkey_lossage;
 #ifndef KLIPS_PFKEY_ACQUIRE_LOSSAGE
-#ifdef CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE
-#define KLIPS_PFKEY_ACQUIRE_LOSSAGE 100
-#else /* CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE */
+# ifdef CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE
+#  define KLIPS_PFKEY_ACQUIRE_LOSSAGE 100
+# else /* CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE */
 /* not by default! */
-#define KLIPS_PFKEY_ACQUIRE_LOSSAGE 0
-#endif /* CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE */
+#  define KLIPS_PFKEY_ACQUIRE_LOSSAGE 0
+# endif /* CONFIG_IPSEC_PFKEY_ACQUIRE_LOSSAGE */
 #endif /* KLIPS_PFKEY_ACQUIRE_LOSSAGE */
 
 #endif /* CONFIG_IPSEC_REGRESS */
@@ -182,7 +172,7 @@ extern int sysctl_ipsec_regress_pfkey_lossage;
 
 /* IP_FRAGMENT_LINEARIZE is set in freeswan.h if Kernel > 2.4.4 */
 #ifndef IP_FRAGMENT_LINEARIZE
-#define IP_FRAGMENT_LINEARIZE 0
+# define IP_FRAGMENT_LINEARIZE 0
 #endif /* IP_FRAGMENT_LINEARIZE */
 #endif /* __KERNEL__ */
 
@@ -191,8 +181,16 @@ extern int sysctl_ipsec_regress_pfkey_lossage;
 
 /*
  * $Log: ipsec_param.h,v $
- * Revision 1.1.1.1  2003/09/12 19:02:50  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:28  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.21  2003/04/03 17:38:18  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
+ * Change indentation for readability.
+ *
+ * Revision 1.20  2003/03/14 08:09:26  rgb
+ * Fixed up CONFIG_IPSEC_DYNDEV definitions.
  *
  * Revision 1.19  2003/01/30 02:31:43  rgb
  *
