@@ -15,7 +15,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_sa.h,v 1.2 2003/09/15 12:57:27 jjo Exp $
+ * RCSID $Id: ipsec_sa.h,v 1.1.1.1 2003/10/31 17:56:28 ken Exp $
  *
  * This file derived from ipsec_xform.h on 2001/9/18 by mcr.
  *
@@ -182,6 +182,17 @@ struct ipsec_sa
 	__u64		ips_comp_ratio_dbytes;	/* decompressed (or uncompressed) bytes */
 #endif /* CONFIG_IPSEC_IPCOMP */
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	__u8		ips_natt_type;
+	__u8		ips_natt_reserved[3];
+	__u16		ips_natt_sport;
+	__u16		ips_natt_dport;
+
+	struct sockaddr *ips_natt_oa;
+	__u16		ips_natt_oa_size;
+	__u16		ips_natt_reserved2;
+#endif
+
 #if 0
 	__u32		ips_sens_dpd;
 	__u8		ips_sens_sens_level;
@@ -191,8 +202,6 @@ struct ipsec_sa
 	__u8		ips_sens_integ_len;
 	__u64*		ips_sens_integ_bitmap;
 #endif
-	struct ipsec_alg_enc *ips_alg_enc;
-	struct ipsec_alg_auth *ips_alg_auth;
 	IPsecSAref_t	ips_ref_rel;
 };
 
@@ -240,11 +249,9 @@ enum ipsec_direction {
 
 /*
  * $Log: ipsec_sa.h,v $
- * Revision 1.2  2003/09/15 12:57:27  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:28  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:50  ken
- * Stock 2.02
+ * Stock 2.03
  *
  * Revision 1.15  2003/05/11 00:53:09  mcr
  * 	IPsecSAref_t and macros were moved to freeswan.h.
