@@ -1,7 +1,7 @@
 /*
  * IPSEC tunneling code
  * Copyright (C) 1996, 1997  John Ioannidis.
- * Copyright (C) 1998, 1999, 2000, 2001  Richard Guy Briggs.
+ * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003  Richard Guy Briggs.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_tunnel.h,v 1.1.1.1 2003/09/12 19:02:50 ken Exp $
+ * RCSID $Id: ipsec_tunnel.h,v 1.1.1.1 2003/10/31 17:56:29 ken Exp $
  */
 
 
@@ -36,7 +36,7 @@
 # define IP_SEND(skb, dev) \
 	if(ntohs(iph->tot_len) > physmtu) { \
 		ip_fragment(NULL, skb, dev, 0); \
-		dev_kfree_skb(skb, FREE_WRITE); \
+		ipsec_kfree_skb(skb); \
 	} else { \
 		dev_queue_xmit(skb, dev, SOPRI_NORMAL); \
 	}
@@ -100,6 +100,8 @@ struct ipsecpriv
 
 extern char ipsec_tunnel_c_version[];
 
+extern struct device *ipsecdevices[IPSEC_NUM_IF];
+
 int ipsec_tunnel_init_devices(void);
 
 /* void */ int ipsec_tunnel_cleanup_devices(void);
@@ -126,8 +128,20 @@ extern int sysctl_ipsec_debug_verbose;
 
 /*
  * $Log: ipsec_tunnel.h,v $
- * Revision 1.1.1.1  2003/09/12 19:02:50  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:29  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.28  2003/06/24 20:22:32  mcr
+ * 	added new global: ipsecdevices[] so that we can keep track of
+ * 	the ipsecX devices. They will be referenced with dev_hold(),
+ * 	so 2.2 may need this as well.
+ *
+ * Revision 1.27  2003/04/03 17:38:09  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
+ *
+ * Revision 1.26  2003/02/12 19:32:20  rgb
+ * Updated copyright year.
  *
  * Revision 1.25  2002/05/27 18:56:07  rgb
  * Convert to dynamic ipsec device allocation.
