@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_xform.h,v 1.2 2003/09/15 12:57:27 jjo Exp $
+ * RCSID $Id: ipsec_xform.h,v 1.1.1.1 2003/10/31 17:56:29 ken Exp $
  */
 
 #ifndef _IPSEC_XFORM_H_
@@ -46,17 +46,10 @@
 #define AH_NONE			0
 #define AH_MD5			2
 #define AH_SHA			3
-/* draft-ietf-ipsec-ciph-aes-cbc-03.txt */
-#define AH_SHA2_256		5
-#define AH_SHA2_384		6
-#define AH_SHA2_512		7
-#define AH_RIPEMD		8
-#define AH_MAX			15
 
 /* IPsec ESP transform values */
 
 #define ESP_NONE		0
-#define ESP_DES			2
 #define ESP_3DES		3
 #define ESP_RC5			4
 #define ESP_IDEA		5
@@ -65,14 +58,7 @@
 #define ESP_3IDEA		8
 #define ESP_RC4			10
 #define ESP_NULL		11
-#define ESP_AES			12
 
-/* as draft-ietf-ipsec-ciph-aes-cbc-02.txt */
-#define ESP_MARS		249
-#define	ESP_RC6			250
-#define ESP_SERPENT		252
-#define ESP_TWOFISH		253
-			 
 /* IPCOMP transform values */
 
 #define IPCOMP_NONE		0
@@ -93,16 +79,7 @@
 	(x) == IPPROTO_IPIP ? "IPIP" : \
 	(x) == IPPROTO_COMP ? "COMP" : \
 	"UNKNOWN_proto"
-static inline const char *enc_name_id (unsigned id) {
-	static char buf[16];
-	snprintf(buf, sizeof(buf), "_ID%d", id);
-	return buf;
-}
-static inline const char *auth_name_id (unsigned id) {
-	static char buf[16];
-	snprintf(buf, sizeof(buf), "_ID%d", id);
-	return buf;
-}
+
 #define IPS_XFORM_NAME(x) \
 	PROTO2TXT((x)->ips_said.proto), \
 	(x)->ips_said.proto == IPPROTO_COMP ? \
@@ -110,33 +87,20 @@ static inline const char *auth_name_id (unsigned id) {
 		 "_DEFLATE" : "_UNKNOWN_comp") : \
 	(x)->ips_encalg == ESP_NONE ? "" : \
 	(x)->ips_encalg == ESP_3DES ? "_3DES" : \
- 	(x)->ips_encalg == ESP_AES ? "_AES" : \
- 	(x)->ips_encalg == ESP_TWOFISH ? "_TWOFISH" : \
- 	(x)->ips_encalg == ESP_SERPENT ? "_SERPENT" : \
- 	(x)->ips_encalg == ESP_BLOWFISH ? "_BLOWFISH" : \
- 	(x)->ips_encalg == ESP_CAST ? "_CAST" : \
- 	(x)->ips_encalg == ESP_DES ? "_DES" : \
- 	(x)->ips_encalg == ESP_NULL ? "_NULL" : \
-	enc_name_id(x->ips_encalg)/* "_UNKNOWN_encr" */, \
+	"_UNKNOWN_encr", \
 	(x)->ips_authalg == AH_NONE ? "" : \
 	(x)->ips_authalg == AH_MD5 ? "_HMAC_MD5" : \
 	(x)->ips_authalg == AH_SHA ? "_HMAC_SHA1" : \
-	(x)->ips_authalg == AH_SHA2_256 ? "_HMAC_SHA2_256" : \
-	(x)->ips_authalg == AH_SHA2_384 ? "_HMAC_SHA2_384" : \
-	(x)->ips_authalg == AH_SHA2_512 ? "_HMAC_SHA2_512" : \
-	(x)->ips_authalg == AH_RIPEMD ? "_HMAC_RIPEMD" : \
-	auth_name_id(x->ips_authalg) /* "_UNKNOWN_auth" */ \
+	"_UNKNOWN_auth" \
 
 #define _IPSEC_XFORM_H_
 #endif /* _IPSEC_XFORM_H_ */
 
 /*
  * $Log: ipsec_xform.h,v $
- * Revision 1.2  2003/09/15 12:57:27  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:29  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:51  ken
- * Stock 2.02
+ * Stock 2.03
  *
  * Revision 1.36  2002/04/24 07:36:48  mcr
  * Moved from ./klips/net/ipsec/ipsec_xform.h,v
