@@ -12,13 +12,12 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey.h,v 1.3 2003/09/15 12:57:26 jjo Exp $
+ * RCSID $Id: pfkey.h,v 1.1.1.1 2003/10/31 17:56:25 ken Exp $
  */
 
 #ifndef __NET_IPSEC_PF_KEY_H
 #define __NET_IPSEC_PF_KEY_H
 #ifdef __KERNEL__
-extern void pfkey_proto_init(struct net_proto *pro);
 extern struct proto_ops pfkey_proto_ops;
 typedef struct sock pfkey_sock;
 extern int debug_pfkey;
@@ -37,11 +36,6 @@ extern int pfkey_list_remove_socket(struct socket*, struct socket_list**);
 extern struct socket_list *pfkey_open_sockets;
 extern struct socket_list *pfkey_registered_sockets[SADB_SATYPE_MAX+1];
 
-/* 
- *	There is a field-by-field copy in klips/net/ipsec/ipsec_alg.h
- *	please keep in sync until we migrate all support stuff
- *	to ipsec_alg objects
- */
 struct supported
 {
 	uint16_t supported_alg_exttype;
@@ -50,6 +44,7 @@ struct supported
 	uint16_t supported_alg_minbits;
 	uint16_t supported_alg_maxbits;
 };
+
 extern struct supported_list *pfkey_supported_list[SADB_SATYPE_MAX+1];
 struct supported_list
 {
@@ -124,7 +119,6 @@ extern int
 pfkey_x_debug_process(struct sadb_ext *pfkey_ext,
 		      struct pfkey_extracted_data* extr);
 
-extern int pfkey_register_reply(int satype, struct sadb_msg *);
 extern int pfkey_upmsg(struct socket *, struct sadb_msg *);
 extern int pfkey_expire(struct ipsec_sa *, int);
 extern int pfkey_acquire(struct ipsec_sa *);
@@ -243,6 +237,21 @@ pfkey_ident_build(struct sadb_ext**	pfkey_ext,
 		  uint8_t               ident_len,
 		  char*			ident_string);
 
+#ifdef NAT_TRAVERSAL
+#ifdef __KERNEL__
+extern int pfkey_nat_t_new_mapping(struct ipsec_sa *, struct sockaddr *, __u16);
+extern int pfkey_x_nat_t_type_process(struct sadb_ext *pfkey_ext, struct pfkey_extracted_data* extr);
+extern int pfkey_x_nat_t_port_process(struct sadb_ext *pfkey_ext, struct pfkey_extracted_data* extr);
+#endif /* __KERNEL__ */
+int
+pfkey_x_nat_t_type_build(struct sadb_ext**  pfkey_ext,
+            uint8_t         type);
+int
+pfkey_x_nat_t_port_build(struct sadb_ext**  pfkey_ext,
+            uint16_t         exttype,
+            uint16_t         port);
+#endif
+
 int
 pfkey_sens_build(struct sadb_ext**	pfkey_ext,
 		 uint32_t		dpd,
@@ -313,14 +322,12 @@ pfkey_v2_sadb_type_string(int sadb_type);
 
 /*
  * $Log: pfkey.h,v $
- * Revision 1.3  2003/09/15 12:57:26  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:25  ken
  *
- * Revision 1.2  2003/09/12 19:23:31  ken
- * Import X.509 1.4.6
+ * Stock 2.03
  *
- * Revision 1.1.1.1  2003/09/12 19:02:48  ken
- * Stock 2.02
+ * Revision 1.42  2003/08/25 22:08:19  mcr
+ * 	removed pfkey_proto_init() from pfkey.h for 2.6 support.
  *
  * Revision 1.41  2003/05/07 17:28:57  mcr
  * 	new function pfkey_debug_func added for us in debugging from
