@@ -1,5 +1,5 @@
 /*
- * RCSID $Id: pfkeyv2.h,v 1.3 2003/09/15 12:57:26 jjo Exp $
+ * RCSID $Id: pfkeyv2.h,v 1.1.1.1 2003/10/31 17:56:25 ken Exp $
  */
 
 /*
@@ -36,7 +36,12 @@ you leave this credit intact on any copies of this file.
 #define SADB_X_ADDFLOW	14
 #define SADB_X_DELFLOW	15
 #define SADB_X_DEBUG	16
+#ifdef NAT_TRAVERSAL
+#define SADB_X_NAT_T_NEW_MAPPING  17
+#define SADB_MAX                  17
+#else
 #define SADB_MAX        16
+#endif
 
 struct sadb_msg {
   uint8_t sadb_msg_version;
@@ -186,6 +191,16 @@ struct sadb_x_satype {
   uint8_t sadb_x_satype_reserved[3];
 };
   
+struct sadb_x_policy {
+  uint16_t sadb_x_policy_len;
+  uint16_t sadb_x_policy_exttype;
+  uint16_t sadb_x_policy_type;
+  uint8_t sadb_x_policy_dir;
+  uint8_t sadb_x_policy_reserved;
+  uint32_t sadb_x_policy_id;
+  uint32_t sadb_x_policy_reserved2;
+};
+ 
 struct sadb_x_debug {
   uint16_t sadb_x_debug_len;
   uint16_t sadb_x_debug_exttype;
@@ -203,6 +218,21 @@ struct sadb_x_debug {
   uint32_t sadb_x_debug_verbose;
   uint8_t sadb_x_debug_reserved[4];
 };
+
+#ifdef NAT_TRAVERSAL
+struct sadb_x_nat_t_type {
+  uint16_t sadb_x_nat_t_type_len;
+  uint16_t sadb_x_nat_t_type_exttype;
+  uint8_t sadb_x_nat_t_type_type;
+  uint8_t sadb_x_nat_t_type_reserved[3];
+};
+struct sadb_x_nat_t_port {
+  uint16_t sadb_x_nat_t_port_len;
+  uint16_t sadb_x_nat_t_port_exttype;
+  uint16_t sadb_x_nat_t_port_port;
+  uint16_t sadb_x_nat_t_port_reserved;
+};
+#endif
   
 /*
  * A protocol structure for passing through the transport level
@@ -238,6 +268,9 @@ struct sadb_protocol {
 #define SADB_EXT_SPIRANGE             16
 #define SADB_X_EXT_KMPRIVATE          17
 #define SADB_X_EXT_SATYPE2            18
+#ifdef KERNEL26_HAS_KAME_DUPLICATES
+#define SADB_X_EXT_POLICY             18
+#endif
 #define SADB_X_EXT_SA2                19
 #define SADB_X_EXT_ADDRESS_DST2       20
 #define SADB_X_EXT_ADDRESS_SRC_FLOW   21
@@ -246,7 +279,15 @@ struct sadb_protocol {
 #define SADB_X_EXT_ADDRESS_DST_MASK   24
 #define SADB_X_EXT_DEBUG              25
 #define SADB_X_EXT_PROTOCOL           26
+#ifdef NAT_TRAVERSAL
+#define SADB_X_EXT_NAT_T_TYPE         27
+#define SADB_X_EXT_NAT_T_SPORT        28
+#define SADB_X_EXT_NAT_T_DPORT        29
+#define SADB_X_EXT_NAT_T_OA           30
+#define SADB_EXT_MAX                  30
+#else
 #define SADB_EXT_MAX                  26
+#endif
 
 /* SADB_X_DELFLOW required over and above SADB_X_SAFLAGS_CLEARFLOW */
 #define SADB_X_EXT_ADDRESS_DELFLOW \
@@ -263,6 +304,9 @@ struct sadb_protocol {
 #define SADB_SATYPE_RIPV2     7
 #define SADB_SATYPE_MIP       8
 #define SADB_X_SATYPE_IPIP    9
+#ifdef KERNEL26_HAS_KAME_DUPLICATES
+#define SADB_X_SATYPE_IPCOMP  9   /* ICK! */
+#endif
 #define SADB_X_SATYPE_COMP    10
 #define SADB_X_SATYPE_INT     11
 #define SADB_SATYPE_MAX       11
@@ -286,28 +330,33 @@ struct sadb_protocol {
  * and if not, then please try to use a private-use value, and
  * consider asking IANA to assign a value.
  */
-#define SADB_AALG_NONE        0
-#define SADB_AALG_MD5HMAC     2
-#define SADB_AALG_SHA1HMAC    3
-#define	SADB_AALG_SHA256_HMAC    5
-#define	SADB_AALG_SHA384_HMAC    6
-#define	SADB_AALG_SHA512_HMAC    7
-#define	SADB_AALG_RIPEMD160HMAC      8
-#define	SADB_AALG_MAX         15
+#define SADB_AALG_NONE                  0
+#define SADB_AALG_MD5HMAC               2
+#define SADB_AALG_SHA1HMAC              3
+#define SADB_X_AALG_SHA2_256HMAC	5
+#define SADB_X_AALG_SHA2_384HMAC	6
+#define SADB_X_AALG_SHA2_512HMAC	7
+#define SADB_X_AALG_RIPEMD160HMAC	8
+#define SADB_X_AALG_NULL		251	/* kame */
+#define SADB_AALG_MAX			251
 
-#define SADB_EALG_NONE        0
-#define SADB_EALG_DESCBC      2
-#define SADB_EALG_3DESCBC     3
-#define SADB_EALG_BFCBC	      7
-#define SADB_EALG_NULL        11
-#define SADB_EALG_AESCBC      12
-#define SADB_EALG_MAX         255
+#define SADB_EALG_NONE                  0
+#define SADB_EALG_DESCBC                2
+#define SADB_EALG_3DESCBC               3
+#define SADB_X_EALG_CASTCBC		6
+#define SADB_X_EALG_BLOWFISHCBC		7
+#define SADB_EALG_NULL			11
+#define SADB_X_EALG_AESCBC		12
+#define SADB_EALG_MAX			12
 
 #define SADB_X_CALG_NONE          0
 #define SADB_X_CALG_OUI           1
 #define SADB_X_CALG_DEFLATE       2
 #define SADB_X_CALG_LZS           3
 #define SADB_X_CALG_V42BIS        4
+#ifdef KERNEL26_HAS_KAME_DUPLICATES
+#define SADB_X_CALG_LZJH          4
+#endif
 #define SADB_X_CALG_MAX           4
 
 #define SADB_X_TALG_NONE          0
@@ -330,14 +379,16 @@ struct sadb_protocol {
 
 /*
  * $Log: pfkeyv2.h,v $
- * Revision 1.3  2003/09/15 12:57:26  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:25  ken
  *
- * Revision 1.2  2003/09/12 19:23:31  ken
- * Import X.509 1.4.6
+ * Stock 2.03
  *
- * Revision 1.1.1.1  2003/09/12 19:02:48  ken
- * Stock 2.02
+ * Revision 1.25  2003/07/31 23:59:17  mcr
+ * 	re-introduce kernel 2.6 duplicate values for now.
+ * 	hope to get them changed!
+ *
+ * Revision 1.24  2003/07/31 22:55:27  mcr
+ * 	added some definitions to keep pfkeyv2.h files in sync.
  *
  * Revision 1.23  2003/05/11 00:43:48  mcr
  * 	added comment about origin of values used
