@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: addrtot.c,v 1.1.1.1 2003/09/12 19:02:31 ken Exp $
+ * RCSID $Id: addrtot.c,v 1.1.1.1 2003/10/31 17:56:07 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -23,10 +23,9 @@
 
 /* forwards */
 static size_t normal4(const unsigned char *s, size_t len, char *b, char **dp);
-static size_t normal6(const unsigned char *s, size_t len, char *b, char **dp);
+static size_t normal6(const unsigned char *s, size_t len, char *b, char **dp, int squish);
 static size_t reverse4(const unsigned char *s, size_t len, char *b, char **dp);
 static size_t reverse6(const unsigned char *s, size_t len, char *b, char **dp);
-static size_t reverse62(const unsigned char *s, size_t len, char *b, char **dp);
 
 /*
  - addrtot - convert binary address to text (dotted decimal or IPv6 string)
@@ -54,7 +53,13 @@ size_t dstlen;
 		n = normal4(b, n, buf, &p);
 		break;
 	case TF(AF_INET6, 0):
-		n = normal6(b, n, buf, &p);
+		n = normal6(b, n, buf, &p, 1);
+		break;
+	case TF(AF_INET, 'Q'):
+		n = normal4(b, n, buf, &p);
+		break;
+	case TF(AF_INET6, 'Q'):
+		n = normal6(b, n, buf, &p, 0);
 		break;
 	case TF(AF_INET, 'r'):
 		n = reverse4(b, n, buf, &p);
@@ -62,9 +67,6 @@ size_t dstlen;
 	case TF(AF_INET6, 'r'):
 		n = reverse6(b, n, buf, &p);
 		break;
-	case TF(AF_INET6, 'R'):
-		n = reverse62(b, n, buf, &p);
-		break;
 	default:		/* including (AF_INET, 'R') */
 		return 0;
 		break;
@@ -107,11 +109,12 @@ char **dstp;			/* where to put result pointer */
  - normal6 - normal IPv6 address-text conversion
  */
 static size_t			/* size of text, including NUL */
-normal6(srcp, srclen, buf, dstp)
+normal6(srcp, srclen, buf, dstp, squish)
 const unsigned char *srcp;
 size_t srclen;
 char *buf;			/* guaranteed large enough, plus 2 */
 char **dstp;			/* where to put result pointer */
+int    squish;                  /* whether to squish out 0:0 */
 {
 	int i;
 	unsigned long piece;
@@ -129,7 +132,7 @@ char **dstp;			/* where to put result pointer */
 	}
 	*p = '\0';
 	q = strstr(buf, ":0:0:");
-	if (q != NULL) {	/* zero squishing is possible */
+	if (squish && q != NULL) {	/* zero squishing is possible */
 		p = q + 1;
 		while (*p == '0' && *(p+1) == ':')
 			p += 2;
@@ -178,11 +181,11 @@ char **dstp;			/* where to put result pointer */
 }
 
 /*
- - reverse62 - obsolete IPv6 reverse-lookup conversion (RFC 1886)
+ - reverse6 - IPv6 reverse-lookup conversion (RFC 1886)
  * A trifle inefficient, really shouldn't use ultot...
  */
 static size_t			/* size of text, including NUL */
-reverse62(srcp, srclen, buf, dstp)
+reverse6(srcp, srclen, buf, dstp)
 const unsigned char *srcp;
 size_t srclen;
 char *buf;			/* guaranteed large enough */
@@ -202,29 +205,98 @@ char **dstp;			/* where to put result pointer */
 		p += ultot(piece>>4, 16, p, 2);
 		*(p-1) = '.';
 	}
-	strcpy(p, "IP6.INT.");
+	strcpy(p, "IP6.ARPA.");
 	*dstp = buf;
 	return strlen(buf) + 1;
 }
 
 /*
  - reverse6 - modern IPv6 reverse-lookup conversion (RFC 2874)
+ * this version removed as it was obsoleted in the end.
  */
-static size_t			/* size of text, including NUL */
-reverse6(srcp, srclen, buf, dstp)
-const unsigned char *srcp;
-size_t srclen;
-char *buf;			/* guaranteed large enough */
-char **dstp;			/* where to put result pointer */
-{
-	char *p;
 
-	if (srclen != IP6BYTES)	/* "can't happen" */
-		return 0;
-	strcpy(buf, "\\[x");
-	p = buf + strlen(buf);
-	(void) datatot((const char *)srcp, srclen, 16, p, IP6BYTES*2 + 1);
-	strcat(buf, "].IP6.ARPA.");	/* leave count implicit */
-	*dstp = buf;
-	return strlen(buf) + 1;
+#ifdef ADDRTOT_MAIN
+
+#include <stdio.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+
+void regress(void);
+
+int
+main(int argc, char *argv[])
+{
+	if (argc < 2) {
+		fprintf(stderr, "Usage: %s {addr|net/mask|begin...end|-r}\n",
+								argv[0]);
+		exit(2);
+	}
+
+	if (strcmp(argv[1], "-r") == 0) {
+		regress();
+		fprintf(stderr, "regress() returned?!?\n");
+		exit(1);
+	}
+	exit(0);
 }
+
+struct rtab {
+	char *input;
+        char  format;
+	char *output;			/* NULL means error expected */
+} rtab[] = {
+	{"1.2.3.0",			0, "1.2.3.0"},
+	{"1:2::3:4",                    0, "1:2::3:4"},
+	{"1:2::3:4",                   'Q', "1:2:0:0:0:0:3:4"},
+	{"1:2:0:0:3:4:0:0",             0, "1:2::3:4:0:0"},
+	{"1.2.3.4",                    'r' , "4.3.2.1.IN-ADDR.ARPA."},
+ 	/*                                    0 1 2 3 4 5 6 7 8 9 a b c d e f 0 1 2 3 4 5 6 7 8 9 a b c d e f */
+	{"1:2::3:4",                   'r', "4.0.0.0.3.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.2.0.0.0.1.0.0.0.IP6.ARPA."},
+	 {NULL,				0, NULL}
+};
+
+void
+regress()
+{
+	struct rtab *r;
+	int status = 0;
+	ip_address a;
+	char in[100];
+	char buf[100];
+	const char *oops;
+	size_t n;
+
+	for (r = rtab; r->input != NULL; r++) {
+		strcpy(in, r->input);
+
+		/* convert it *to* internal format */
+		oops = ttoaddr(in, strlen(in), 0, &a);
+
+		/* now convert it back */
+
+		n = addrtot(&a, r->format, buf, sizeof(buf));
+
+		if (n == 0 && r->output == NULL)
+			{}		/* okay, error expected */
+		
+		else if (n == 0) {
+			printf("`%s' atoasr failed\n", r->input);
+			status = 1;
+			
+		} else if (r->output == NULL) {
+			printf("`%s' atoasr succeeded unexpectedly '%c'\n",
+							r->input, r->format);
+			status = 1;
+		} else {
+		  if (strcasecmp(r->output, buf) != 0) {
+		    printf("`%s' '%c' gave `%s', expected `%s'\n",
+			   r->input, r->format, buf, r->output);
+		    status = 1;
+		  }
+		}
+	}
+	exit(status);
+}
+
+#endif /* ADDRTOT_MAIN */
