@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: atoasr.c,v 1.1.1.1 2003/09/12 19:02:31 ken Exp $
+ * RCSID $Id: atoasr.c,v 1.1.1.1 2003/10/31 17:56:08 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -75,13 +75,14 @@ struct in_addr addrsp[2];
 #ifdef ATOASR_MAIN
 
 #include <stdio.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
-void regress();
+void regress(void);
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 	struct in_addr a[2];
 	char buf[100];
@@ -138,27 +139,26 @@ struct rtab {
 	char *input;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	"1.2.3.0",			"1.2.3.0",
-	"1.2.3.0/255.255.255.0",	"1.2.3.0/24",
-	"1.2.3.0...1.2.3.5",		"1.2.3.0...1.2.3.5",
-	"1.2.3.4.5",			NULL,
-	"1.2.3.4/",			NULL,
-	"1.2.3.4...",			NULL,
-	"1.2.3.4....",			NULL,
-	"localhost/32",		        "127.0.0.1/32",
-	"localhost...127.0.0.3",	"127.0.0.1...127.0.0.3",
-	"127.0.0.0...localhost",	"127.0.0.0...127.0.0.1",
-	"127.0.0.3...localhost",	NULL,
-	NULL,				NULL
+	{"1.2.3.0",			"1.2.3.0"},
+	{"1.2.3.0/255.255.255.0",	"1.2.3.0/24"},
+	{"1.2.3.0...1.2.3.5",		"1.2.3.0...1.2.3.5"},
+	{"1.2.3.4.5",			NULL},
+	{"1.2.3.4/",			NULL},
+	{"1.2.3.4...",			NULL},
+	{"1.2.3.4....",			NULL},
+	{"localhost/32",		        "127.0.0.1/32"},
+	{"localhost...127.0.0.3",	"127.0.0.1...127.0.0.3"},
+	{"127.0.0.0...localhost",	"127.0.0.0...127.0.0.1"},
+	{"127.0.0.3...localhost",	NULL},
+	{NULL,				NULL}
 };
 
 void
-regress()
+regress(void)
 {
 	struct rtab *r;
 	int status = 0;
 	struct in_addr a[2];
-	struct in_addr m;
 	char in[100];
 	char buf[100];
 	const char *oops;
