@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: atosa.c,v 1.1.1.1 2003/09/12 19:02:31 ken Exp $
+ * RCSID $Id: atosa.c,v 1.1.1.1 2003/10/31 17:56:08 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -93,13 +93,14 @@ struct sa_id *sa;
 #ifdef ATOSA_MAIN
 
 #include <stdio.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
-void regress();
+void regress(void);
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 	struct sa_id sa;
 	char buf[100];
@@ -125,7 +126,7 @@ char *argv[];
 	n = satoa(sa, 0, buf, sizeof(buf));
 	if (n > sizeof(buf)) {
 		fprintf(stderr, "%s: reverse conv of `%d'", argv[0], sa.proto);
-		fprintf(stderr, "%lu@", sa.spi);
+		fprintf(stderr, "%lu@", (long unsigned int)sa.spi);
 		fprintf(stderr, "%s", inet_ntoa(sa.dst));
 		fprintf(stderr, " failed: need %ld bytes, have only %ld\n",
 						(long)n, (long)sizeof(buf));
@@ -140,25 +141,25 @@ struct rtab {
 	char *input;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	"esp257@1.2.3.0",		"esp257@1.2.3.0",
-	"ah0x20@1.2.3.4",		"ah32@1.2.3.4",
-	"tun011@111.2.3.99",		"tun11@111.2.3.99",
-	"",				NULL,
-	"_",				NULL,
-	"ah2.2",			NULL,
-	"goo2@1.2.3.4",			NULL,
-	"esp9@1.2.3.4",			"esp9@1.2.3.4",
-	"espp9@1.2.3.4",		NULL,
-	"es9@1.2.3.4",			NULL,
-	"ah@1.2.3.4",			NULL,
-	"esp7x7@1.2.3.4",		NULL,
-	"esp77@1.0x2.3.4",		NULL,
-	PASSTHROUGHNAME,		PASSTHROUGHNAME,
-	NULL,				NULL
+	{"esp257@1.2.3.0",		"esp257@1.2.3.0"},
+	{"ah0x20@1.2.3.4",		"ah32@1.2.3.4"},
+	{"tun011@111.2.3.99",		"tun11@111.2.3.99"},
+	{"",				NULL},
+	{"_",				NULL},
+	{"ah2.2",			NULL},
+	{"goo2@1.2.3.4",			NULL},
+	{"esp9@1.2.3.4",			"esp9@1.2.3.4"},
+	{"espp9@1.2.3.4",		NULL},
+	{"es9@1.2.3.4",			NULL},
+	{"ah@1.2.3.4",			NULL},
+	{"esp7x7@1.2.3.4",		NULL},
+	{"esp77@1.0x2.3.4",		NULL},
+	{PASSTHROUGHNAME,		PASSTHROUGHNAME},
+        {NULL,				NULL}
 };
 
 void
-regress()
+regress(void)
 {
 	struct rtab *r;
 	int status = 0;
