@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: atosubnet.c,v 1.1.1.1 2003/09/12 19:02:31 ken Exp $
+ * RCSID $Id: atosubnet.c,v 1.1.1.1 2003/10/31 17:56:08 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -89,13 +89,14 @@ struct in_addr *maskp;
 #ifdef ATOSUBNET_MAIN
 
 #include <stdio.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
-void regress();
+void regress(void);
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 	struct in_addr a;
 	struct in_addr m;
@@ -137,39 +138,39 @@ struct rtab {
 	char *input;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	"1.2.3.0/255.255.255.0",	"1.2.3.0/24",
-	"1.2.3.0/24",			"1.2.3.0/24",
-	"1.2.3.1/255.255.255.240",	"1.2.3.0/28",
-	"1.2.3.1/32",			"1.2.3.1/32",
-	"1.2.3.1/0",			"0.0.0.0/0",
+	{"1.2.3.0/255.255.255.0",	"1.2.3.0/24"},
+	{"1.2.3.0/24",			"1.2.3.0/24"},
+	{"1.2.3.1/255.255.255.240",	"1.2.3.0/28"},
+	{"1.2.3.1/32",			"1.2.3.1/32"},
+	{"1.2.3.1/0",			"0.0.0.0/0"},
 /*	"1.2.3.1/255.255.127.0",	"1.2.3.0/255.255.127.0",	*/
-	"1.2.3.1/255.255.127.0",	NULL,
-	"128.009.000.032/32",		"128.9.0.32/32",
-	"128.0x9.0.32/32",		NULL,
-	"0x80090020/32",		"128.9.0.32/32",
-	"0x800x0020/32",		NULL,
-	"128.9.0.32/0xffFF0000",	"128.9.0.0/16",
-	"128.9.0.32/0xff0000FF",	NULL,
-	"128.9.0.32/0x0000ffFF",	NULL,
-	"128.9.0.32/0x00ffFF0000",	NULL,
-	"128.9.0.32/0xffFF",		NULL,
-	"128.9.0.32.27/32",		NULL,
-	"128.9.0k32/32",		NULL,
-	"328.9.0.32/32",		NULL,
-	"128.9..32/32",			NULL,
-	"10/8",				"10.0.0.0/8",
-	"10.0/8",			"10.0.0.0/8",
-	"10.0.0/8",			"10.0.0.0/8",
-	"10.0.1/24",			"10.0.1.0/24",
-	"_",				NULL,
-	"_/_",				NULL,
-	"1.2.3.1",			NULL,
-	"1.2.3.1/_",			NULL,
-	"1.2.3.1/24._",			NULL,
-	"1.2.3.1/99",			NULL,
-	"localhost/32",		        "127.0.0.1/32",
-	"%default",			"0.0.0.0/0",
-	NULL,				NULL
+	{"1.2.3.1/255.255.127.0",	NULL},
+	{"128.009.000.032/32",		"128.9.0.32/32"},
+	{"128.0x9.0.32/32",		NULL},
+	{"0x80090020/32",		"128.9.0.32/32"},
+	{"0x800x0020/32",		NULL},
+	{"128.9.0.32/0xffFF0000",	"128.9.0.0/16"},
+	{"128.9.0.32/0xff0000FF",	NULL},
+	{"128.9.0.32/0x0000ffFF",	NULL},
+	{"128.9.0.32/0x00ffFF0000",	NULL},
+	{"128.9.0.32/0xffFF",		NULL},
+	{"128.9.0.32.27/32",		NULL},
+	{"128.9.0k32/32",		NULL},
+	{"328.9.0.32/32",		NULL},
+	{"128.9..32/32",		NULL},
+	{"10/8",			"10.0.0.0/8"},
+	{"10.0/8",			"10.0.0.0/8"},
+	{"10.0.0/8",			"10.0.0.0/8"},
+	{"10.0.1/24",			"10.0.1.0/24"},
+	{"_",				NULL},
+	{"_/_",				NULL},
+	{"1.2.3.1",			NULL},
+	{"1.2.3.1/_",			NULL},
+	{"1.2.3.1/24._",		NULL},
+	{"1.2.3.1/99",			NULL},
+	{"localhost/32",		"127.0.0.1/32"},
+	{"%default",			"0.0.0.0/0"},
+	{NULL,				NULL}
 };
 
 void
