@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2_debug.c,v 1.1.1.1 2003/09/12 19:02:33 ken Exp $
+ * RCSID $Id: pfkey_v2_debug.c,v 1.1.1.1 2003/10/31 17:56:09 ken Exp $
  *
  */
 
@@ -80,6 +80,12 @@ static char *pfkey_sadb_ext_strings[]={
   "X-source-mask",                /* SADB_X_EXT_ADDRESS_SRC_MASK   23 */
   "X-dest-mask",                  /* SADB_X_EXT_ADDRESS_DST_MASK   24 */
   "X-set-debug",                  /* SADB_X_EXT_DEBUG              25 */
+#ifdef NAT_TRAVERSAL
+  "X-NAT-T-type",                 /* SADB_X_EXT_NAT_T_TYPE         26 */
+  "X-NAT-T-sport",                /* SADB_X_EXT_NAT_T_SPORT        27 */
+  "X-NAT-T-dport",                /* SADB_X_EXT_NAT_T_DPORT        28 */
+  "X-NAT-T-OA",                   /* SADB_X_EXT_NAT_T_OA           29 */
+#endif  
 };
 
 const char *
@@ -128,8 +134,9 @@ pfkey_v2_sadb_type_string(int sadb_type)
 
 /*
  * $Log: pfkey_v2_debug.c,v $
- * Revision 1.1.1.1  2003/09/12 19:02:33  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:09  ken
+ *
+ * Stock 2.03
  *
  * Revision 1.7  2002/09/20 05:01:26  rgb
  * Fixed limit inclusion error in both type and ext string conversion.
