@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: rangetosubnet.c,v 1.1.1.1 2003/09/12 19:02:35 ken Exp $
+ * RCSID $Id: rangetosubnet.c,v 1.1.1.1 2003/10/31 17:56:13 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -85,12 +85,10 @@ ip_subnet *dst;
 
 #include <stdio.h>
 
-void regress();
+void regress(void);
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 	ip_address start;
 	ip_address stop;
@@ -153,24 +151,24 @@ struct rtab {
 	char *stop;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	4, "1.2.3.0",		"1.2.3.255",		"1.2.3.0/24",
-	4, "1.2.3.0",		"1.2.3.7",		"1.2.3.0/29",
-	4, "1.2.3.240",		"1.2.3.255",		"1.2.3.240/28",
-	4, "0.0.0.0",		"255.255.255.255",	"0.0.0.0/0",
-	4, "1.2.3.4",		"1.2.3.4",		"1.2.3.4/32",
-	4, "1.2.3.0",		"1.2.3.254",		NULL,
-	4, "1.2.3.0",		"1.2.3.126",		NULL,
-	4, "1.2.3.0",		"1.2.3.125",		NULL,
-	4, "1.2.0.0",		"1.2.255.255",		"1.2.0.0/16",
-	4, "1.2.0.0",		"1.2.0.255",		"1.2.0.0/24",
-	4, "1.2.255.0",		"1.2.255.255",		"1.2.255.0/24",
-	4, "1.2.255.0",		"1.2.254.255",		NULL,
-	4, "1.2.255.1",		"1.2.255.255",		NULL,
-	4, "1.2.0.1",		"1.2.255.255",		NULL,
-	6, "1:2:3:4:5:6:7:0",	"1:2:3:4:5:6:7:ffff",	"1:2:3:4:5:6:7:0/112",
-	6, "1:2:3:4:5:6:7:0",	"1:2:3:4:5:6:7:fff",	"1:2:3:4:5:6:7:0/116",
-	6, "1:2:3:4:5:6:7:f0",	"1:2:3:4:5:6:7:ff",	"1:2:3:4:5:6:7:f0/124",
-	4, NULL,		NULL,			NULL,
+	{4, "1.2.3.0",		"1.2.3.255",		"1.2.3.0/24"},
+	{4, "1.2.3.0",		"1.2.3.7",		"1.2.3.0/29"},
+	{4, "1.2.3.240",	"1.2.3.255",		"1.2.3.240/28"},
+	{4, "0.0.0.0",		"255.255.255.255",	"0.0.0.0/0"},
+	{4, "1.2.3.4",		"1.2.3.4",		"1.2.3.4/32"},
+	{4, "1.2.3.0",		"1.2.3.254",		NULL},
+	{4, "1.2.3.0",		"1.2.3.126",		NULL},
+	{4, "1.2.3.0",		"1.2.3.125",		NULL},
+	{4, "1.2.0.0",		"1.2.255.255",		"1.2.0.0/16"},
+	{4, "1.2.0.0",		"1.2.0.255",		"1.2.0.0/24"},
+	{4, "1.2.255.0",		"1.2.255.255",	"1.2.255.0/24"},
+	{4, "1.2.255.0",		"1.2.254.255",	NULL},
+	{4, "1.2.255.1",		"1.2.255.255",	NULL},
+	{4, "1.2.0.1",		"1.2.255.255",		NULL},
+	{6, "1:2:3:4:5:6:7:0",	"1:2:3:4:5:6:7:ffff",	"1:2:3:4:5:6:7:0/112"},
+	{6, "1:2:3:4:5:6:7:0",	"1:2:3:4:5:6:7:fff",	"1:2:3:4:5:6:7:0/116"},
+	{6, "1:2:3:4:5:6:7:f0",	"1:2:3:4:5:6:7:ff",	"1:2:3:4:5:6:7:f0/124"},
+	{4, NULL,		NULL,			NULL},
 };
 
 void
