@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ttoaddr.c,v 1.1.1.1 2003/09/12 19:02:36 ken Exp $
+ * RCSID $Id: ttoaddr.c,v 1.1.1.1 2003/10/31 17:56:14 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -59,7 +59,9 @@ ip_address *dst;
 	switch (af) {
 	case AF_INET:
 	case AF_INET6:
+	case 0:                  /* guess */
 		break;
+	    
 	default:
 		return "invalid address family";
 	}
@@ -72,12 +74,17 @@ ip_address *dst;
 	}
 
 	if (memchr(src, ':', srclen) != NULL) {
+	    if(af == 0)
+	    {
+		af = AF_INET6;
+	    }
+	    
 		if (af != AF_INET6)
 			return "non-ipv6 address may not contain `:'";
 		return colon(src, srclen, dst);
 	}
 
-	if (af == AF_INET) {
+	if (af == 0 || af == AF_INET) {
 		oops = trydotted(src, srclen, dst);
 		if (oops == NULL)
 			return NULL;		/* it worked */
@@ -107,6 +114,20 @@ ip_address *dst;
 	}
 
 	switch (af) {
+	case 0:  /* guess */
+	        oops = colon(src, srclen, dst);
+		if(oops == NULL)
+		{
+		    return NULL;
+		}
+		oops = trydotted(src, srclen, dst);
+		if(oops == NULL)
+		{
+		    return NULL;
+		}
+		return "does not appear to be either IPv4 or IPv6 numeric address";
+		break;
+	    
 	case AF_INET6:
 		return colon(src, srclen, dst);
 		break;
