@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ttodata.c,v 1.1.1.1 2003/09/12 19:02:36 ken Exp $
+ * RCSID $Id: ttodata.c,v 1.1.1.1 2003/10/31 17:56:14 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -378,6 +378,8 @@ size_t errlen;
 
 #include <stdio.h>
 
+struct artab;
+static void check(struct artab *r, char *buf, size_t n, err_t oops, int *status);
 static void regress(char *pgm);
 static void hexout(const char *s, size_t len, FILE *f);
 
@@ -697,7 +699,7 @@ char *pgm;
 			printf("`");
 			hexout(dr->data, strlen(dr->data), stdout);
 			printf("' %c gave %d `%.*s', expecting error\n",
-				dr->format, n, n, buf);
+				dr->format, n, (int)n, buf);
 			status = 1;
 		} else if (n != should) {
 			printf("length wrong in `");
