@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ttosa.c,v 1.1.1.1 2003/09/12 19:02:36 ken Exp $
+ * RCSID $Id: ttosa.c,v 1.1.1.1 2003/10/31 17:56:14 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -142,12 +142,10 @@ ip_said *sa;
 
 #include <stdio.h>
 
-void regress();
+void regress(void);
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 	ip_said sa;
 	char buf[100];
@@ -174,7 +172,7 @@ char *argv[];
 	n = satot(&sa, 0, buf, sizeof(buf));
 	if (n > sizeof(buf)) {
 		fprintf(stderr, "%s: reverse conv of `%d'", argv[0], sa.proto);
-		fprintf(stderr, "%lx@", sa.spi);
+		fprintf(stderr, "%lx@", (long unsigned int)sa.spi);
 		(void) addrtot(&sa.dst, 0, buf2, sizeof(buf2));
 		fprintf(stderr, "%s", buf2);
 		fprintf(stderr, " failed: need %ld bytes, have only %ld\n",
@@ -192,54 +190,54 @@ struct rtab {
 	char *input;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	0, "esp257@1.2.3.0",		"esp.101@1.2.3.0",
-	0, "ah0x20@1.2.3.4",		"ah.20@1.2.3.4",
-	0, "tun20@1.2.3.4",		"tun.14@1.2.3.4",
-	0, "comp20@1.2.3.4",		"comp.14@1.2.3.4",
-	0, "esp257@::1",		"esp:101@::1",
-	0, "esp257@0bc:12de::1",	"esp:101@bc:12de::1",
-	0, "esp78@1049:1::8007:2040",	"esp:4e@1049:1::8007:2040",
-	0, "esp0x78@1049:1::8007:2040",	"esp:78@1049:1::8007:2040",
-	0, "ah78@1049:1::8007:2040",	"ah:4e@1049:1::8007:2040",
-	0, "ah0x78@1049:1::8007:2040",	"ah:78@1049:1::8007:2040",
-	0, "tun78@1049:1::8007:2040",	"tun:4e@1049:1::8007:2040",
-	0, "tun0x78@1049:1::8007:2040",	"tun:78@1049:1::8007:2040",
-	0, "duk99@3ffe:370:400:ff::9001:3001",	NULL,
-	0, "esp78x@1049:1::8007:2040",	NULL,
-	0, "esp0x78@1049:1:0xfff::8007:2040",	NULL,
-	0, "es78@1049:1::8007:2040",	NULL,
-	0, "",				NULL,
-	0, "_",				NULL,
-	0, "ah2.2",			NULL,
-	0, "goo2@1.2.3.4",		NULL,
-	0, "esp9@1.2.3.4",		"esp.9@1.2.3.4",
-	'f', "esp0xa9@1.2.3.4",		"esp.000000a9@1.2.3.4",
-	0, "espp9@1.2.3.4",		NULL,
-	0, "es9@1.2.3.4",		NULL,
-	0, "ah@1.2.3.4",		NULL,
-	0, "esp7x7@1.2.3.4",		NULL,
-	0, "esp77@1.0x2.3.4",		NULL,
-	0, PASSTHROUGHNAME,		PASSTHROUGH4NAME,
-	0, PASSTHROUGH6NAME,		PASSTHROUGH6NAME,
-	0, "%pass",			"%pass",
-	0, "int256@0.0.0.0",		"%pass",
-	0, "%drop",			"%drop",
-	0, "int257@0.0.0.0",		"%drop",
-	0, "%reject",			"%reject",
-	0, "int258@0.0.0.0",		"%reject",
-	0, "%hold",			"%hold",
-	0, "int259@0.0.0.0",		"%hold",
-	0, "%trap",			"%trap",
-	0, "int260@0.0.0.0",		"%trap",
-	0, "%trapsubnet",		"%trapsubnet",
-	0, "int261@0.0.0.0",		"%trapsubnet",
-	0, "int262@0.0.0.0",		"int.106@0.0.0.0",
-	FUDGE, "esp9@1.2.3.4",		"unk77.9@1.2.3.4",
-	0, NULL,			NULL
+	{0, "esp257@1.2.3.0",		"esp.101@1.2.3.0"},
+	{0, "ah0x20@1.2.3.4",		"ah.20@1.2.3.4"},
+	{0, "tun20@1.2.3.4",		"tun.14@1.2.3.4"},
+	{0, "comp20@1.2.3.4",		"comp.14@1.2.3.4"},
+	{0, "esp257@::1",		"esp:101@::1"},
+	{0, "esp257@0bc:12de::1",	"esp:101@bc:12de::1"},
+	{0, "esp78@1049:1::8007:2040",	"esp:4e@1049:1::8007:2040"},
+	{0, "esp0x78@1049:1::8007:2040",	"esp:78@1049:1::8007:2040"},
+	{0, "ah78@1049:1::8007:2040",	"ah:4e@1049:1::8007:2040"},
+	{0, "ah0x78@1049:1::8007:2040",	"ah:78@1049:1::8007:2040"},
+	{0, "tun78@1049:1::8007:2040",	"tun:4e@1049:1::8007:2040"},
+	{0, "tun0x78@1049:1::8007:2040",	"tun:78@1049:1::8007:2040"},
+	{0, "duk99@3ffe:370:400:ff::9001:3001",	NULL},
+	{0, "esp78x@1049:1::8007:2040",	NULL},
+	{0, "esp0x78@1049:1:0xfff::8007:2040",	NULL},
+	{0, "es78@1049:1::8007:2040",	NULL},
+	{0, "",				NULL},
+	{0, "_",				NULL},
+	{0, "ah2.2",			NULL},
+	{0, "goo2@1.2.3.4",		NULL},
+	{0, "esp9@1.2.3.4",		"esp.9@1.2.3.4"},
+	{'f', "esp0xa9@1.2.3.4",		"esp.000000a9@1.2.3.4"},
+	{0, "espp9@1.2.3.4",		NULL},
+	{0, "es9@1.2.3.4",		NULL},
+	{0, "ah@1.2.3.4",		NULL},
+	{0, "esp7x7@1.2.3.4",		NULL},
+	{0, "esp77@1.0x2.3.4",		NULL},
+	{0, PASSTHROUGHNAME,		PASSTHROUGH4NAME},
+	{0, PASSTHROUGH6NAME,		PASSTHROUGH6NAME},
+	{0, "%pass",			"%pass"},
+	{0, "int256@0.0.0.0",		"%pass"},
+	{0, "%drop",			"%drop"},
+	{0, "int257@0.0.0.0",		"%drop"},
+	{0, "%reject",			"%reject"},
+	{0, "int258@0.0.0.0",		"%reject"},
+	{0, "%hold",			"%hold"},
+	{0, "int259@0.0.0.0",		"%hold"},
+	{0, "%trap",			"%trap"},
+	{0, "int260@0.0.0.0",		"%trap"},
+	{0, "%trapsubnet",		"%trapsubnet"},
+	{0, "int261@0.0.0.0",		"%trapsubnet"},
+	{0, "int262@0.0.0.0",		"int.106@0.0.0.0"},
+	{FUDGE, "esp9@1.2.3.4",		"unk77.9@1.2.3.4"},
+	{0, NULL,			NULL}
 };
 
 void
-regress()
+regress(void)
 {
 	struct rtab *r;
 	int status = 0;
