@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ttosubnet.c,v 1.2 2003/09/12 19:23:31 ken Exp $
+ * RCSID $Id: ttosubnet.c,v 1.1.1.1 2003/10/31 17:56:15 ken Exp $
  */
 #include "internal.h"
 #include "freeswan.h"
@@ -123,14 +123,10 @@ ip_subnet *dst;
 
 #include <stdio.h>
 
-void regress();
+void regress(void);
 
-int
-main(argc, argv)
-int argc;
-char *argv[];
+int main(int argc, char *argv[])
 {
-	ip_address a;
 	ip_subnet s;
 	char buf[100];
 	char buf2[100];
@@ -184,77 +180,83 @@ struct rtab {
 	char *input;
 	char *output;			/* NULL means error expected */
 } rtab[] = {
-	4, "1.2.3.0/255.255.255.0",	"1.2.3.0/24",
-	4, "1.2.3.0/24",		"1.2.3.0/24",
-	4, "1.2.3.1/255.255.255.240",	"1.2.3.0/28",
-	4, "1.2.3.1/32",		"1.2.3.1/32",
-	4, "1.2.3.1/0",			"0.0.0.0/0",
-/*	4, "1.2.3.1/255.255.127.0",	"1.2.3.0/255.255.127.0",	*/
-	4, "1.2.3.1/255.255.127.0",	NULL,
-	4, "128.009.000.032/32",	"128.9.0.32/32",
-	4, "128.0x9.0.32/32",		NULL,
-	4, "0x80090020/32",		"128.9.0.32/32",
-	4, "0x800x0020/32",		NULL,
-	4, "128.9.0.32/0xffFF0000",	"128.9.0.0/16",
-	4, "128.9.0.32/0xff0000FF",	NULL,
-	4, "128.9.0.32/0x0000ffFF",	NULL,
-	4, "128.9.0.32/0x00ffFF0000",	NULL,
-	4, "128.9.0.32/0xffFF",		NULL,
-	4, "128.9.0.32.27/32",		NULL,
-	4, "128.9.0k32/32",		NULL,
-	4, "328.9.0.32/32",		NULL,
-	4, "128.9..32/32",		NULL,
-	4, "10/8",			"10.0.0.0/8",
-	4, "10.0/8",			"10.0.0.0/8",
-	4, "10.0.0/8",			"10.0.0.0/8",
-	4, "10.0.1/24",			"10.0.1.0/24",
-	4, "_",				NULL,
-	4, "_/_",			NULL,
-	4, "1.2.3.1",			NULL,
-	4, "1.2.3.1/_",			NULL,
-	4, "1.2.3.1/24._",		NULL,
-	4, "1.2.3.1/99",		NULL,
-	4, "localhost/32", 		"127.0.0.1/32",
-	4, "%default",			"0.0.0.0/0",
-	6, "3049:1::8007:2040/0",	"::/0",
-	6, "3049:1::8007:2040/128",	"3049:1::8007:2040/128",
-	6, "3049:1::192.168.0.1/128", NULL,	/*"3049:1::c0a8:1/128",*/
-	6, "3049:1::8007::2040/128",	NULL,
-	6, "3049:1::8007:2040/ffff::0",	"3049::/16",
-	6, "3049:1::8007:2040/64",	"3049:1::/64",
-	6, "3049:1::8007:2040/ffff::",	"3049::/16",
-	6, "3049:1::8007:2040/0000:ffff::0",	NULL,
-	6, "3049:1::8007:2040/ff1f::0",	NULL,
-	6, "3049:1::8007:x:2040/128",	NULL,
-	6, "3049:1t::8007:2040/128",	NULL,
-	6, "3049:1::80071:2040/128",	NULL,
-	6, "::/21",			"::/21",
-	6, "::1/128",			"::1/128",
-	6, "1::/21",			"1::/21",
-	6, "1::2/128",			"1::2/128",
-	6, "1:0:0:0:0:0:0:2/128",	"1::2/128",
-	6, "1:0:0:0:3:0:0:2/128",	"1::3:0:0:2/128",
-	6, "1:0:0:3:0:0:0:2/128",	"1::3:0:0:0:2/128",
-	6, "1:0:3:0:0:0:0:2/128",	"1:0:3::2/128",
-	6, "abcd:ef01:2345:6789:0:00a:000:20/128",	"abcd:ef01:2345:6789:0:a:0:20/128",
-	6, "3049:1::8007:2040/ffff:ffff:",	NULL,
-	6, "3049:1::8007:2040/ffff:88::",	NULL,
-	6, "3049:12::9000:3200/ffff:fff0::",	"3049:10::/28",
-	6, "3049:12::9000:3200/28",	"3049:10::/28",
-	6, "3049:12::9000:3200/ff00:::",	NULL,
-	6, "3049:12::9000:3200/ffff:::",	NULL,
-	6, "3049:12::9000:3200/128_",	NULL,
-	6, "3049:12::9000:3200/",	NULL,
-	6, "%default",			"::/0",
-	4, NULL,			NULL
+	{4, "1.2.3.0/255.255.255.0",	"1.2.3.0/24"},
+	{4, "1.2.3.0/24",		"1.2.3.0/24"},
+	{4, "1.2.3.0/24:10",		"1.2.3.0/24:10"},
+	{4, "1.2.3.0/24:-1",		NULL},
+	{4, "1.2.3.0/24:none",		NULL},
+	{4, "1.2.3.0/24:",		NULL},
+	{4, "1.2.3.0/24:0x10",		"1.2.3.0/24:16"},
+	{4, "1.2.3.0/24:0X10",		"1.2.3.0/24:16"},
+	{4, "1.2.3.0/24:010",		"1.2.3.0/24:8"},
+	{4, "1.2.3.1/255.255.255.240",	"1.2.3.0/28"},
+	{4, "1.2.3.1/32",		"1.2.3.1/32"},
+	{4, "1.2.3.1/0",			"0.0.0.0/0"},
+/*	{4, "1.2.3.1/255.255.127.0",	"1.2.3.0/255.255.127.0"},	*/
+	{4, "1.2.3.1/255.255.127.0",	NULL},
+	{4, "128.009.000.032/32",	"128.9.0.32/32"},
+	{4, "128.0x9.0.32/32",		NULL},
+	{4, "0x80090020/32",		"128.9.0.32/32"},
+	{4, "0x800x0020/32",		NULL},
+	{4, "128.9.0.32/0xffFF0000",	"128.9.0.0/16"},
+	{4, "128.9.0.32/0xff0000FF",	NULL},
+	{4, "128.9.0.32/0x0000ffFF",	NULL},
+	{4, "128.9.0.32/0x00ffFF0000",	NULL},
+	{4, "128.9.0.32/0xffFF",	NULL},
+	{4, "128.9.0.32.27/32",		NULL},
+	{4, "128.9.0k32/32",		NULL},
+	{4, "328.9.0.32/32",		NULL},
+	{4, "128.9..32/32",		NULL},
+	{4, "10/8",			"10.0.0.0/8"},
+	{4, "10.0/8",			"10.0.0.0/8"},
+	{4, "10.0.0/8",			"10.0.0.0/8"},
+	{4, "10.0.1/24",			"10.0.1.0/24"},
+	{4, "_",				NULL},
+	{4, "_/_",			NULL},
+	{4, "1.2.3.1",			NULL},
+	{4, "1.2.3.1/_",			NULL},
+	{4, "1.2.3.1/24._",		NULL},
+	{4, "1.2.3.1/99",		NULL},
+	{4, "localhost/32", 		"127.0.0.1/32"},
+	{4, "%default",			"0.0.0.0/0"},
+	{6, "3049:1::8007:2040/0",	"::/0"},
+	{6, "3049:1::8007:2040/128",	"3049:1::8007:2040/128"},
+	{6, "3049:1::192.168.0.1/128", NULL},	/*"3049:1::c0a8:1/128",*/
+	{6, "3049:1::8007::2040/128",	NULL},
+	{6, "3049:1::8007:2040/ffff::0",	"3049::/16"},
+	{6, "3049:1::8007:2040/64",	"3049:1::/64"},
+	{6, "3049:1::8007:2040/ffff::",	"3049::/16"},
+	{6, "3049:1::8007:2040/0000:ffff::0",	NULL},
+	{6, "3049:1::8007:2040/ff1f::0",	NULL},
+	{6, "3049:1::8007:x:2040/128",	NULL},
+	{6, "3049:1t::8007:2040/128",	NULL},
+	{6, "3049:1::80071:2040/128",	NULL},
+	{6, "::/21",			"::/21"},
+	{6, "::1/128",			"::1/128"},
+	{6, "1::/21",			"1::/21"},
+	{6, "1::2/128",			"1::2/128"},
+	{6, "1:0:0:0:0:0:0:2/128",	"1::2/128"},
+	{6, "1:0:0:0:3:0:0:2/128",	"1::3:0:0:2/128"},
+	{6, "1:0:0:3:0:0:0:2/128",	"1::3:0:0:0:2/128"},
+	{6, "1:0:3:0:0:0:0:2/128",	"1:0:3::2/128"},
+	{6, "abcd:ef01:2345:6789:0:00a:000:20/128",	"abcd:ef01:2345:6789:0:a:0:20/128"},
+	{6, "3049:1::8007:2040/ffff:ffff:",	NULL},
+	{6, "3049:1::8007:2040/ffff:88::",	NULL},
+	{6, "3049:12::9000:3200/ffff:fff0::",	"3049:10::/28"},
+	{6, "3049:12::9000:3200/28",	"3049:10::/28"},
+	{6, "3049:12::9000:3200/ff00:::",	NULL},
+	{6, "3049:12::9000:3200/ffff:::",	NULL},
+	{6, "3049:12::9000:3200/128_",	NULL},
+	{6, "3049:12::9000:3200/",	NULL},
+	{6, "%default",			"::/0"},
+        {4, NULL,			NULL}
 };
 
 void
-regress()
+regress(void)
 {
 	struct rtab *r;
 	int status = 0;
-	ip_address a;
 	ip_subnet s;
 	char in[100];
 	char buf[100];
