@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.1.1.1 2003/09/12 19:02:52 ken Exp $";
+char ipcomp_c_version[] = "RCSID $Id: ipcomp.c,v 1.1.1.1 2003/10/31 17:56:30 ken Exp $";
 
 /* SSS */
 
@@ -98,31 +98,31 @@ struct sk_buff *skb_compress(struct sk_buff *skb, struct ipsec_sa *ips, unsigned
 	KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 		    "klips_debug:skb_compress: .\n");
 
-	if(!skb) {
+	if(skb == NULL) {
 		KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 			    "klips_debug:skb_compress: "
 			    "passed in NULL skb, returning ERROR.\n");
-		if (flags) *flags |= IPCOMP_PARMERROR;
+		if(flags != NULL) {
+			*flags |= IPCOMP_PARMERROR;
+		}
 		return skb;
 	}
 
-	if(!ips) {
+	if(ips == NULL) {
 		KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 			    "klips_debug:skb_compress: "
 			    "passed in NULL ipsec_sa needed for cpi, returning ERROR.\n");
-		if (flags) *flags |= IPCOMP_PARMERROR;
+		if(flags) {
+			*flags |= IPCOMP_PARMERROR;
+		}
 		return skb;
 	}
 
-	if (!flags) {
+	if (flags == NULL) {
 		KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 			    "klips_debug:skb_compress: "
 			    "passed in NULL flags, returning ERROR.\n");
-#ifdef NET_21
-		kfree_skb(skb);
-#else /* NET_21 */
-		dev_kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(skb);
 		return NULL;
 	}
 	
@@ -373,11 +373,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 		KLIPS_PRINT(sysctl_ipsec_debug_ipcomp,
 			    "klips_error:skb_decompress: "
 			    "passed in NULL flags, returning ERROR.\n");
-#ifdef NET_21
-		kfree_skb(skb);
-#else /* NET_21 */
-		dev_kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(skb);
 		return NULL;
 	}
 	
@@ -542,11 +538,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 			    zresult,
 			    zs.msg ? zs.msg : zError(zresult));
 		*flags |= IPCOMP_DECOMPRESSIONERROR;
-#ifdef NET_21
-		kfree_skb(nskb);
-#else /* NET_21 */
-		dev_kfree_skb(nskb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(nskb);
 
 		return skb;
 	}
@@ -574,11 +566,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 	/* Update skb length/tail by "unputting" the unused data area */
 	skb_put(nskb, -zs.avail_out);
 	
-#ifdef NET_21
-	kfree_skb(skb);
-#else /* NET_21 */
-	dev_kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
+	ipsec_kfree_skb(skb);
 	
 	if (iph->protocol == IPPROTO_COMP)
 	{
@@ -589,11 +577,7 @@ struct sk_buff *skb_decompress(struct sk_buff *skb, struct ipsec_sa *ips, unsign
 			    "Eh? inner packet is also compressed, dropping.\n");
 #endif /* CONFIG_IPSEC_DEBUG */
 		
-#ifdef NET_21
-		kfree_skb(nskb);
-#else /* NET_21 */
-		dev_kfree_skb(nskb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(nskb);
 		return NULL;
 	}
 	
