@@ -18,7 +18,7 @@
  *
  */
 
-char ipsec_init_c_version[] = "RCSID $Id: ipsec_init.c,v 1.2 2003/09/15 12:57:30 jjo Exp $";
+char ipsec_init_c_version[] = "RCSID $Id: ipsec_init.c,v 1.1.1.1 2003/10/31 17:56:30 ken Exp $";
 
 #include <linux/config.h>
 #include <linux/version.h>
@@ -91,7 +91,6 @@ char ipsec_init_c_version[] = "RCSID $Id: ipsec_init.c,v 1.2 2003/09/15 12:57:30
 #endif /* CONFIG_IPSEC_IPCOMP */
 
 #include "freeswan/ipsec_proto.h"
-#include "freeswan/ipsec_alg.h"
 
 #include <pfkeyv2.h>
 #include <pfkey.h>
@@ -116,7 +115,7 @@ int debug_netlink = 0;
 
 struct prng ipsec_prng;
 
-int ipsec_device_event(struct notifier_block *dnot, unsigned long event, void *ptr);
+extern int ipsec_device_event(struct notifier_block *dnot, unsigned long event, void *ptr);
 /*
  * the following structure is required so that we receive
  * event notifications when network devices are enabled and
@@ -133,18 +132,38 @@ extern int ipsec_sysctl_register(void);
 extern void ipsec_sysctl_unregister(void);
 #endif
 
+static inline int
+freeswan_inet_add_protocol(struct inet_protocol *prot, unsigned protocol)
+{
+#ifdef NETDEV_25
+	return inet_add_protocol(prot, protocol);
+#else
+	inet_add_protocol(prot);
+	return 0;
+#endif
+}
+
+static inline int
+freeswan_inet_del_protocol(struct inet_protocol *prot, unsigned protocol)
+{
+#ifdef NETDEV_25
+	return inet_del_protocol(prot, protocol);
+#else
+	inet_del_protocol(prot);
+	return 0;
+#endif
+}
+
 /* void */
 int
 ipsec_init(void)
 {
 	int error = 0;
-	unsigned char seed[256];
-#ifdef CONFIG_IPSEC_ENC_3DES
 	extern int des_check_key;
+	unsigned char seed[256];
 
 	/* turn off checking of keys */
 	des_check_key=0;
-#endif /* CONFIG_IPSEC_ENC_3DES */
 
 	KLIPS_PRINT(1, "klips_info:ipsec_init: "
 		    "KLIPS startup, FreeS/WAN IPSec version: %s\n",
@@ -171,29 +190,27 @@ ipsec_init(void)
 	error |= register_netdevice_notifier(&ipsec_dev_notifier);
 
 #ifdef CONFIG_IPSEC_ESP
-	inet_add_protocol(&esp_protocol);
+	freeswan_inet_add_protocol(&esp_protocol, IPPROTO_ESP);
 #endif /* CONFIG_IPSEC_ESP */
 
 #ifdef CONFIG_IPSEC_AH
-	inet_add_protocol(&ah_protocol);
+	freeswan_inet_add_protocol(&ah_protocol, IPPROTO_AH);
 #endif /* CONFIG_IPSEC_AH */
 
-#if 0
+/* we never actually link IPCOMP to the stack */
+#ifdef IPCOMP_USED_ALONE
 #ifdef CONFIG_IPSEC_IPCOMP
-	inet_add_protocol(&comp_protocol);
+ 	freeswan_inet_add_protocol(&comp_protocol, IPPROTO_COMP);
 #endif /* CONFIG_IPSEC_IPCOMP */
 #endif
 
 	error |= ipsec_tunnel_init_devices();
 
+
 #ifdef CONFIG_SYSCTL
         error |= ipsec_sysctl_register();
 #endif                                                                          
 
-#ifdef CONFIG_IPSEC_ALG
-	ipsec_alg_init();
-#endif
-
 	get_random_bytes((void *)seed, sizeof(seed));
 	prng_init(&ipsec_prng, seed, sizeof(seed));
 
@@ -215,20 +232,25 @@ ipsec_cleanup(void)
 		    "calling ipsec_tunnel_cleanup_devices.\n");
 	error |= ipsec_tunnel_cleanup_devices();
 
-#if 0
+	KLIPS_PRINT(debug_netlink, "called ipsec_tunnel_cleanup_devices");
+
+/* we never actually link IPCOMP to the stack */
+#ifdef IPCOMP_USED_ALONE
 #ifdef CONFIG_IPSEC_IPCOMP
-	if (inet_del_protocol(&comp_protocol) < 0)
+ 	if (freeswan_inet_del_protocol(&comp_protocol, IPPROTO_COMP) < 0)
 		printk(KERN_INFO "klips_debug:ipsec_cleanup: "
 		       "comp close: can't remove protocol\n");
 #endif /* CONFIG_IPSEC_IPCOMP */
-#endif /* 0 */
+#endif /* IPCOMP_USED_ALONE */
+
 #ifdef CONFIG_IPSEC_AH
-	if (inet_del_protocol(&ah_protocol) < 0)
+ 	if (freeswan_inet_del_protocol(&ah_protocol, IPPROTO_AH) < 0)
 		printk(KERN_INFO "klips_debug:ipsec_cleanup: "
 		       "ah close: can't remove protocol\n");
 #endif /* CONFIG_IPSEC_AH */
+
 #ifdef CONFIG_IPSEC_ESP
-	if (inet_del_protocol(&esp_protocol) < 0)
+ 	if (freeswan_inet_del_protocol(&esp_protocol, IPPROTO_ESP) < 0)
 		printk(KERN_INFO "klips_debug:ipsec_cleanup: "
 		       "esp close: can't remove protocol\n");
 #endif /* CONFIG_IPSEC_ESP */
@@ -240,6 +262,7 @@ ipsec_cleanup(void)
 		    "calling ipsec_sadb_cleanup.\n");
 	error |= ipsec_sadb_cleanup(0);
 	error |= ipsec_sadb_free();
+
 	KLIPS_PRINT(debug_netlink, /* debug_tunnel & DB_TN_INIT, */
 		    "klips_debug:ipsec_cleanup: "
 		    "calling ipsec_radijcleanup.\n");
@@ -288,11 +311,16 @@ cleanup_module(void)
 
 /*
  * $Log: ipsec_init.c,v $
- * Revision 1.2  2003/09/15 12:57:30  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:30  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:52  ken
- * Stock 2.02
+ * Stock 2.03
+ *
+ * Revision 1.89  2003/07/31 22:47:16  mcr
+ * 	preliminary (untested by FS-team) 2.5 patches.
+ *
+ * Revision 1.88  2003/06/22 20:05:36  mcr
+ * 	clarified why IPCOMP was not being registered, and put a new
+ * 	#ifdef in rather than #if 0.
  *
  * Revision 1.87  2002/09/20 15:40:51  rgb
  * Added a lock to the global ipsec_sadb struct for future use.
