@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipsec_mast_c_version[] = "RCSID $Id: ipsec_mast.c,v 1.1.1.1 2003/09/12 19:02:53 ken Exp $";
+char ipsec_mast_c_version[] = "RCSID $Id: ipsec_mast.c,v 1.1.1.1 2003/10/31 17:56:31 ken Exp $";
 
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -72,6 +72,8 @@ char ipsec_mast_c_version[] = "RCSID $Id: ipsec_mast.c,v 1.1.1.1 2003/09/12 19:0
 
 #include "freeswan/ipsec_proto.h"
 
+int ipsec_maxdevice_count = -1;
+
 DEBUG_NO_STATIC int
 ipsec_mast_open(struct device *dev)
 {
@@ -1035,143 +1037,9 @@ ipsec_mast_probe(struct device *dev)
 	return 0;
 }
 
-#if !CONFIG_IPSEC_DYNDEV
-static struct device dev_ipsec3 = 
-{
-	"ipsec3\0   ",		/* name */
-	0,			/* recv memory end */
-	0,			/* recv memory start */
-	0,			/* memory end */
-	0,			/* memory start */
- 	0x0,			/* base I/O address */
-	0,			/* IRQ */
-	0, 0, 0,		/* flags */
-	NULL,			/* next device */
-	ipsec_mast_probe	/* setup */
-};
-
-static struct device dev_ipsec2 = 
-{
-	"ipsec2\0   ",		/* name */
-	0,			/* recv memory end */
-	0,			/* recv memory start */
-	0,			/* memory end */
-	0,			/* memory start */
- 	0x0,			/* base I/O address */
-	0,			/* IRQ */
-	0, 0, 0,		/* flags */
-	NULL,			/* next device */
-	ipsec_mast_probe	/* setup */
-};
-
-static struct device dev_ipsec1 = 
-{
-	"ipsec1\0   ",		/* name */
-	0,			/* recv memory end */
-	0,			/* recv memory start */
-	0,			/* memory end */
-	0,			/* memory start */
- 	0x0,			/* base I/O address */
-	0,			/* IRQ */
-	0, 0, 0,		/* flags */
-	NULL,			/* next device */
-	ipsec_mast_probe	/* setup */
-};
-
-static struct device dev_ipsec0 = 
-{
-	"ipsec0\0   ",		/* name */
-	0,			/* recv memory end */
-	0,			/* recv memory start */
-	0,			/* memory end */
-	0,			/* memory start */
- 	0x0,			/* base I/O address */
-	0,			/* IRQ */
-	0, 0, 0,		/* flags */
-	NULL,			/* next device */
-	ipsec_mast_probe	/* setup */
-};
-#endif /* !CONFIG_IPSEC_DYNDEV */
-
 int 
 ipsec_mast_init_devices(void)
 {
-#if CONFIG_IPSEC_DYNDEV
-	int i;
-	char name[IFNAMSIZ];
-	struct device *dev_ipsec;
-	
-	KLIPS_PRINT(debug_mast & DB_MAST_INIT,
-		    "klips_debug:ipsec_mast_init_devices: "
-		    "creating and registering IPSEC_NUM_IF=%u devices, allocating %lu per device, IFNAMSIZ=%u.\n",
-		    IPSEC_NUM_IF,
-		    (unsigned long) (sizeof(struct device) + IFNAMSIZ),
-		    IFNAMSIZ);
-
-	for(i = 0; i < IPSEC_NUM_IF; i++) {
-		sprintf(name, IPSEC_DEV_FORMAT, i);
-		dev_ipsec = (struct device*)kmalloc(sizeof(struct device), GFP_KERNEL);
-		if (dev_ipsec == NULL) {
-			KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-				    "klips_debug:ipsec_mast_init_devices: "
-				    "failed to allocate memory for device %s, quitting device init.\n",
-				    name);
-			return -ENOMEM;
-		}
-		memset((caddr_t)dev_ipsec, 0, sizeof(struct device));
-		strncpy(dev_ipsec->name, name, sizeof(dev_ipsec->name));
-#if 0
-		KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-				    "klips_debug:ipsec_mast_init_devices: "
-				    "printing name one char at a time:");
-		{
-			int j;
-			for(j = 0; j < IFNAMSIZ; j++) {
-				printk( " %d=%c", dev_ipsec->name[j], dev_ipsec->name[j]);
-			}
-		}
-		printk( "\n");
-#endif
-		dev_ipsec->next = NULL;
-		dev_ipsec->init = &ipsec_mast_probe;
-#if 0
-		KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-			    "klips_debug:ipsec_mast_init_devices: "
-			    "registering device %s\n",
-			    dev_ipsec->name);
-#endif
-		if (register_netdev(dev_ipsec) != 0) {
-			KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-				    "klips_debug:ipsec_mast_init_devices: "
-				    "registering device %s failed, quitting device init.\n",
-				    dev_ipsec->name);
-			return -EIO;
-		} else {
-#if 0
-			KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-				    "klips_debug:ipsec_mast_init_devices: "
-				    "registering device %s succeeded, continuing...\n",
-				    dev_ipsec->name);
-#endif
-		}
-	}
-#else /* CONFIG_IPSEC_DYNDEV */
-#if 0
-	KLIPS_PRINT(1 || debug_mast & DB_MAST_INIT,
-		    "klips_debug:ipsec_mast_init_devices: "
-		    "creating and registering %d static devices.\n",
-		    IPSEC_NUM_IF);
-#endif
-	if (register_netdev(&dev_ipsec0) != 0)
-		return -EIO;
-	if (register_netdev(&dev_ipsec1) != 0)
-		return -EIO;
-	if (register_netdev(&dev_ipsec2) != 0)
-		return -EIO;
-	if (register_netdev(&dev_ipsec3) != 0)
-		return -EIO;
-#endif /* CONFIG_IPSEC_DYNDEV */
-
 	return 0;
 }
 
@@ -1180,42 +1048,30 @@ int
 ipsec_mast_cleanup_devices(void)
 {
 	int error = 0;
-#if CONFIG_IPSEC_DYNDEV
 	int i;
 	char name[10];
-	struct device *dev_ipsec;
+	struct device *dev_mast;
 	
-	for(i = 0; i < IPSEC_NUM_IF; i++) {
-		sprintf(name, IPSEC_DEV_FORMAT, i);
-		if((dev_ipsec = ipsec_dev_get(name)) == NULL) {
+	for(i = 0; i < ipsec_mastdevice_count; i++) {
+		sprintf(name, MAST_DEV_FORMAT, i);
+		if((dev_mast = ipsec_dev_get(name)) == NULL) {
 			break;
 		}
-		unregister_netdev(dev_ipsec);
-		kfree(dev_ipsec->priv);
-		dev_ipsec->priv=NULL;
+		unregister_netdev(dev_mast);
+		kfree(dev_mast->priv);
+		dev_mast->priv=NULL;
 	}
-#else /* CONFIG_IPSEC_DYNDEV */
-	unregister_netdev(&dev_ipsec0);
-	unregister_netdev(&dev_ipsec1);
-	unregister_netdev(&dev_ipsec2);
-	unregister_netdev(&dev_ipsec3);
-	kfree(dev_ipsec0.priv);
-	kfree(dev_ipsec1.priv);
-	kfree(dev_ipsec2.priv);
-	kfree(dev_ipsec3.priv);
-	dev_ipsec0.priv=NULL;
-	dev_ipsec1.priv=NULL;
-	dev_ipsec2.priv=NULL;
-	dev_ipsec3.priv=NULL;
-#endif /* CONFIG_IPSEC_DYNDEV */
-
 	return error;
 }
 
 /*
  * $Log: ipsec_mast.c,v $
- * Revision 1.1.1.1  2003/09/12 19:02:53  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:31  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.2  2003/06/22 20:06:17  mcr
+ * 	refactored mast code still had lots of ipsecX junk in it.
  *
  * Revision 1.1  2003/02/12 19:31:12  rgb
  * Refactored from ipsec_tunnel.c
