@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipsec_netlink_c_version[] = "RCSID $Id: ipsec_netlink.c,v 1.1.1.1 2003/09/12 19:02:53 ken Exp $";
+char ipsec_netlink_c_version[] = "RCSID $Id: ipsec_netlink.c,v 1.1.1.1 2003/10/31 17:56:32 ken Exp $";
 
 #include <linux/config.h>
 #include <linux/version.h>
@@ -46,8 +46,6 @@ char ipsec_netlink_c_version[] = "RCSID $Id: ipsec_netlink.c,v 1.1.1.1 2003/09/1
 #ifdef NET_21
 # include <asm/uaccess.h>
 # include <linux/in6.h>
-# define ip_chk_addr inet_addr_type
-# define IS_MYADDR RTN_LOCAL
 #endif
 #include <asm/checksum.h>
 #include <net/ip.h>
@@ -82,8 +80,12 @@ char ipsec_netlink_c_version[] = "RCSID $Id: ipsec_netlink.c,v 1.1.1.1 2003/09/1
 
 /*
  * $Log: ipsec_netlink.c,v $
- * Revision 1.1.1.1  2003/09/12 19:02:53  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:32  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.60  2003/02/12 19:31:27  rgb
+ * Removed useless crud.
  *
  * Revision 1.59  2002/05/14 02:35:16  rgb
  * delete stale code.
