@@ -18,7 +18,7 @@
  * Split out from ipsec_init.c version 1.70.
  */
 
-char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.1.1.1 2003/09/12 19:02:53 ken Exp $";
+char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.1.1.1 2003/10/31 17:56:32 ken Exp $";
 
 #include <linux/config.h>
 #include <linux/version.h>
@@ -76,6 +76,7 @@ char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.1.1.1 2003/09/12 19:0
 #include "freeswan/ipsec_netlink.h"
 #include "freeswan/ipsec_xform.h"
 #include "freeswan/ipsec_tunnel.h"
+#include "freeswan/ipsec_xmit.h"
 
 #include "freeswan/ipsec_rcv.h"
 #include "freeswan/ipsec_ah.h"
@@ -98,6 +99,7 @@ static struct proc_dir_entry *proc_eroute_dir    = NULL;
 static struct proc_dir_entry *proc_spi_dir       = NULL;
 static struct proc_dir_entry *proc_spigrp_dir    = NULL;
 static struct proc_dir_entry *proc_birth_dir     = NULL;
+static struct proc_dir_entry *proc_stats_dir     = NULL;
 #endif
 
 struct ipsec_birth_reply ipsec_ipv4_birth_packet;
@@ -466,7 +468,7 @@ ipsec_tncfg_get_info(char *buffer,
 
 	for(i = 0; i < IPSEC_NUM_IF; i++) {
 		sprintf(name, IPSEC_DEV_FORMAT, i);
-		dev = ipsec_dev_get(name);
+		dev = __ipsec_dev_get(name);
 		if(dev) {
 			priv = (struct ipsecpriv *)(dev->priv);
 			len += sprintf(buffer + len, "%s",
@@ -643,6 +645,30 @@ ipsec_klipsdebug_get_info(char *buffer,
 }
 #endif /* CONFIG_IPSEC_DEBUG */
 
+IPSEC_PROCFS_DEBUG_NO_STATIC
+int
+ipsec_stats_get_int_info(char *buffer,
+			 char **start,
+			 off_t offset,
+			 int count,
+			 int *eof,
+			 void *data)
+{
+	int len = 0;
+	off_t begin = 0;
+	int *thing;
+
+	thing = (int *)data;
+	
+	len += sprintf(buffer + len, "%08x\n", *thing);
+
+	*start = buffer + (offset - begin);	/* Start of wanted data */
+	len -= (offset - begin);			/* Start slop */
+	if (len > count)
+		len = count;
+	return len;
+}
+
 #ifndef PROC_FS_2325
 struct proc_dir_entry ipsec_eroute =
 {
@@ -731,6 +757,9 @@ static struct ipsec_proc_list proc_items[]={
 	{"ipv4",       &proc_birth_dir,     NULL,             ipsec_birth_info, ipsec_birth_set, (void *)&ipsec_ipv4_birth_packet},
 	{"ipv6",       &proc_birth_dir,     NULL,             ipsec_birth_info, ipsec_birth_set, (void *)&ipsec_ipv6_birth_packet},
 	{"tncfg",      &proc_net_ipsec_dir, NULL,             ipsec_tncfg_get_info,      NULL, NULL},
+	{"stats",      &proc_net_ipsec_dir, &proc_stats_dir,  NULL,      NULL, NULL},
+	{"trap_count", &proc_stats_dir,     NULL,             ipsec_stats_get_int_info, NULL, &ipsec_xmit_trap_count},
+	{"trap_sendcount", &proc_stats_dir, NULL,             ipsec_stats_get_int_info, NULL, &ipsec_xmit_trap_sendcount},
 	{"version",    &proc_net_ipsec_dir, NULL,             ipsec_version_get_info,    NULL, NULL},
 	{NULL,         NULL,                NULL,             NULL,      NULL, NULL}
 };
@@ -891,8 +920,16 @@ ipsec_proc_cleanup()
 
 /*
  * $Log: ipsec_proc.c,v $
- * Revision 1.1.1.1  2003/09/12 19:02:53  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:32  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.24  2003/06/20 01:42:21  mcr
+ * 	added counters to measure how many ACQUIREs we send to pluto,
+ * 	and how many are successfully sent.
+ *
+ * Revision 1.23  2003/04/03 17:38:09  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
  *
  * Revision 1.22  2002/09/20 15:40:57  rgb
  * Renamed saref macros for consistency and brevity.
