@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipsec_rcv_c_version[] = "RCSID $Id: ipsec_rcv.c,v 1.2 2003/09/15 12:57:30 jjo Exp $";
+char ipsec_rcv_c_version[] = "RCSID $Id: ipsec_rcv.c,v 1.1.1.1 2003/10/31 17:56:34 ken Exp $";
 
 #include <linux/config.h>
 #include <linux/version.h>
@@ -80,7 +80,6 @@ char ipsec_rcv_c_version[] = "RCSID $Id: ipsec_rcv.c,v 1.2 2003/09/15 12:57:30 j
 #include <pfkey.h>
 
 #include "freeswan/ipsec_proto.h"
-#include "freeswan/ipsec_alg.h"
 
 #ifdef CONFIG_IPSEC_DEBUG
 int debug_ah = 0;
@@ -90,6 +89,10 @@ int debug_rcv = 0;
 
 int sysctl_ipsec_inbound_policy_check = 1;
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+#include <linux/udp.h>
+#endif
+
 #ifdef CONFIG_IPSEC_DEBUG
 static void
 rcv_dmp(char *s, caddr_t bb, int len)
@@ -231,8 +234,7 @@ enum ipsec_rcv_value {
 	IPSEC_RCV_BADAUTH=-14,
 	IPSEC_RCV_REPLAYFAILED=-15,
 	IPSEC_RCV_AUTHFAILED=-16,
-	IPSEC_RCV_REPLAYROLLED=-17,
-	IPSEC_RCV_BAD_DECRYPT=-18
+	IPSEC_RCV_REPLAYROLLED=-17
 };
 
 struct ipsec_rcv_state {
@@ -268,6 +270,12 @@ struct ipsec_rcv_state {
 			struct ipcomphdr *compp;
 		} ipcompstuff;
 	} protostuff;
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	__u16 natt_len;
+	__u16 natt_sport;
+	__u16 natt_dport;
+	__u8 natt_type;
+#endif	
 };
 
 struct xform_functions {
@@ -360,21 +368,6 @@ ipsec_rcv_esp_authcalc(struct ipsec_rcv_state *irs,
 		SHA1_CTX	sha1;
 	} tctx;
 
-#ifdef CONFIG_IPSEC_ALG
-	if (irs->ipsp->ips_alg_auth) {
-		KLIPS_PRINT(debug_rcv,
-				"klips_debug:ipsec_rcv: "
-				"ipsec_alg hashing proto=%d... ",
-				irs->said.proto);
-		if(irs->said.proto == IPPROTO_ESP) {
-			ipsec_alg_sa_esp_hash(irs->ipsp,
-					(caddr_t)espp, irs->ilen,
-					irs->hash, AHHMAC_HASHLEN);
-			return IPSEC_RCV_OK;
-		}
-		return IPSEC_RCV_BADPROTO;
-	}
-#endif
 	aa = irs->authfuncs;
 
 	/* copy the initialized keying material */
@@ -386,7 +379,7 @@ ipsec_rcv_esp_authcalc(struct ipsec_rcv_state *irs,
 
 	memcpy(&tctx, irs->octx, irs->octx_len);
 
-	(*aa->update)((void *)&tctx, irs->hash, AHMD596_ALEN);
+	(*aa->update)((void *)&tctx, irs->hash, aa->hashlen);
 	(*aa->final)(irs->hash, (void *)&tctx);
 
 	return IPSEC_RCV_OK;
@@ -400,38 +393,22 @@ ipsec_rcv_esp_decrypt(struct ipsec_rcv_state *irs)
 	struct esphdr *espp = irs->protostuff.espstuff.espp;
 	int esphlen = 0;
 	__u8 *idat;	/* pointer to content to be decrypted/authenticated */
-#ifdef CONFIG_IPSEC_ENC_3DES
 	__u32 iv[2];
-#endif /* !CONFIG_IPSEC_ENC_3DES */
 	int pad = 0, padlen;
 	int badpad = 0;
 	int i;
 	struct sk_buff *skb;
-#ifdef CONFIG_IPSEC_ALG
-	struct ipsec_alg_enc *ixt_e=NULL;
-#endif /* CONFIG_IPSEC_ALG */
 
 	skb=irs->skb;
 
 	idat = skb->data + irs->iphlen;
 
-#ifdef CONFIG_IPSEC_ALG
-	if ((ixt_e=ipsp->ips_alg_enc)) {
-		esphlen = ESP_HEADER_LEN + ixt_e->ixt_ivlen/8;
-		KLIPS_PRINT(debug_rcv,
-				"klips_debug:ipsec_rcv: "
-				"encalg=%d esphlen=%d\n",
-				ipsp->ips_encalg, esphlen);
-	} else
-#endif /* CONFIG_IPSEC_ALG */
 	switch(ipsp->ips_encalg) {
-#ifdef CONFIG_IPSEC_ENC_3DES
 	case ESP_3DES:
 		iv[0] = *((__u32 *)(espp->esp_iv)    );
 		iv[1] = *((__u32 *)(espp->esp_iv) + 1);
 		esphlen = sizeof(struct esphdr);
 		break;
-#endif /* !CONFIG_IPSEC_ENC_3DES */
 	default:
 		ipsp->ips_errs.ips_alg_errs += 1;
 		if(irs->stats) {
@@ -443,30 +420,7 @@ ipsec_rcv_esp_decrypt(struct ipsec_rcv_state *irs)
 	idat += esphlen;
 	irs->ilen -= esphlen;
 
-#ifdef CONFIG_IPSEC_ALG
-	if (ixt_e)
-	{
-		if (ipsec_alg_esp_encrypt(ipsp, 
-					idat, irs->ilen, espp->esp_iv, 
-					IPSEC_ALG_DECRYPT) <= 0)
-		{
-			printk("klips_error:ipsec_rcv: "
-					"got packet with esplen = %d "
-					"from %s -- should be on "
-					"ENC(%d) octet boundary, "
-					"packet dropped\n",
-					irs->ilen,
-					irs->ipsaddr_txt,
-					ipsp->ips_encalg);
-			if(irs->stats) {
-				irs->stats->rx_errors++;
-			}
-			return IPSEC_RCV_BAD_DECRYPT;
-		}
-	} else
-#endif /* CONFIG_IPSEC_ALG */
 	switch(ipsp->ips_encalg) {
-#ifdef CONFIG_IPSEC_ENC_3DES
 	case ESP_3DES:
 		if ((irs->ilen) % 8) {
 			ipsp->ips_errs.ips_encsize_errs += 1;
@@ -487,7 +441,6 @@ ipsec_rcv_esp_decrypt(struct ipsec_rcv_state *irs)
 				     ((struct des_eks *)(ipsp->ips_key_e))[2].ks,
 				     (des_cblock *)iv, 0);
 		break;
-#endif /* !CONFIG_IPSEC_ENC_3DES */
 	}
 
 	rcv_dmp("postdecrypt", skb->data, skb->len);
@@ -907,9 +860,6 @@ ipsec_rcv_decap_once(struct ipsec_rcv_state *irs)
 	struct ipsec_sa *newipsp;
 	struct iphdr *ipp;
 	struct sk_buff *skb;
-#ifdef CONFIG_IPSEC_ALG
-	struct ipsec_alg_auth *ixt_a=NULL;
-#endif /* CONFIG_IPSEC_ALG */
 
 	skb = irs->skb;
 	irs->len = skb->len;
@@ -1069,6 +1019,24 @@ ipsec_rcv_decap_once(struct ipsec_rcv_state *irs)
 		 * we just found matched the back pointer. But, we won't do this check anymore,
 		 * because we want to be able to nest SAs
 		 */
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+		KLIPS_PRINT(debug_rcv,
+			"klips_debug:ipsec_rcv: "
+			"natt_type=%u tdbp->ips_natt_type=%u : %s\n",
+			irs->natt_type, newipsp->ips_natt_type,
+			(irs->natt_type==newipsp->ips_natt_type)?"ok":"bad");
+		if (irs->natt_type != newipsp->ips_natt_type) {
+			KLIPS_PRINT(debug_rcv,
+				    "klips_debug:ipsec_rcv: "
+				    "SA:%s does not agree with expected NAT-T policy.\n",
+				    irs->sa_len ? irs->sa : " (error)");
+			if(irs->stats) {
+				irs->stats->rx_dropped++;
+			}
+			ipsec_sa_put(newipsp);
+			return IPSEC_RCV_FAILEDINBOUND;
+		}
+#endif		 
 	}
 
 	/* okay, SA checks out, so free any previous SA, and record a new one */
@@ -1103,23 +1071,42 @@ ipsec_rcv_decap_once(struct ipsec_rcv_state *irs)
 		return IPSEC_RCV_LIFETIMEFAILED;
 	}
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	if ((irs->natt_type) &&
+		( (irs->ipp->saddr != (((struct sockaddr_in*)(newipsp->ips_addr_s))->sin_addr.s_addr)) ||
+		  (irs->natt_sport != newipsp->ips_natt_sport)
+		)) {
+		struct sockaddr sipaddr;
+		/** Advertise NAT-T addr change to pluto **/
+		sipaddr.sa_family = AF_INET;
+		((struct sockaddr_in*)&sipaddr)->sin_addr.s_addr = irs->ipp->saddr;
+		((struct sockaddr_in*)&sipaddr)->sin_port = htons(irs->natt_sport);
+		pfkey_nat_t_new_mapping(newipsp, &sipaddr, irs->natt_sport);
+		/**
+		 * Then allow or block packet depending on
+		 * sysctl_ipsec_inbound_policy_check.
+		 *
+		 * In all cases, pluto will update SA if new mapping is
+		 * accepted.
+		 */
+		if (sysctl_ipsec_inbound_policy_check) {
+			KLIPS_PRINT(debug_rcv,
+				"klips_debug:ipsec_rcv: "
+				"SA:%s, src=%s:%u of pkt does not agree with expected "
+				"SA source address policy (pluto has been informed).\n",
+				irs->sa_len ? irs->sa : " (error)",
+				irs->ipsaddr_txt, irs->natt_sport);
+			if(irs->stats) {
+				irs->stats->rx_dropped++;
+			}
+			ipsec_sa_put(newipsp);
+			return IPSEC_RCV_FAILEDINBOUND;
+		}
+	}
+#endif
+
 	irs->authfuncs=NULL;
 	/* authenticate, if required */
-#ifdef CONFIG_IPSEC_ALG
-	if ((ixt_a=irs->ipsp->ips_alg_auth)) {
-		irs->authlen = AHHMAC_HASHLEN;
-		irs->authfuncs = NULL;
-		irs->ictx = NULL;
-		irs->octx = NULL;
-		irs->ictx_len = 0;
-		irs->octx_len = 0;
-		KLIPS_PRINT(debug_rcv,
-				"klips_debug:ipsec_rcv: "
-				"authalg=%d authlen=%d\n",
-				irs->ipsp->ips_authalg, 
-				irs->authlen);
-	} else
-#endif /* CONFIG_IPSEC_ALG */
 	switch(irs->ipsp->ips_authalg) {
 #ifdef CONFIG_IPSEC_AUTH_HMAC_MD5
 	case AH_MD5:
@@ -1152,11 +1139,7 @@ ipsec_rcv_decap_once(struct ipsec_rcv_state *irs)
 		return IPSEC_RCV_BADAUTH;
 	}
 
-#ifdef CONFIG_IPSEC_ALG
-	if(irs->authfuncs || ixt_a) {
-#else
 	if(irs->authfuncs) {
-#endif
 		unsigned char *authenticator = NULL;
 
 		irs->ilen = irs->len - iphlen - irs->authlen;
@@ -1444,6 +1427,76 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 		goto rcvleave;
 	}
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	if (skb->sk && skb->nh.iph && skb->nh.iph->protocol==IPPROTO_UDP) {
+		/**
+		 * Packet comes from udp_queue_rcv_skb so it is already defrag,
+		 * checksum verified, ... (ie safe to use)
+		 *
+		 * If the packet is not for us, return -1 and udp_queue_rcv_skb
+		 * will continue to handle it (do not kfree skb !!).
+		 */
+		struct udp_opt *tp =  &(skb->sk->tp_pinfo.af_udp);
+		struct iphdr *ip = (struct iphdr *)skb->nh.iph;
+		struct udphdr *udp = (struct udphdr *)((__u32 *)ip+ip->ihl);
+		__u8 *udpdata = (__u8 *)udp + sizeof(struct udphdr);
+		__u32 *udpdata32 = (__u32 *)udpdata;
+
+		irs.natt_sport = ntohs(udp->source);
+		irs.natt_dport = ntohs(udp->dest);
+
+		KLIPS_PRINT(debug_rcv,
+		    "klips_debug:ipsec_rcv: "
+		    "suspected ESPinUDP packet (NAT-Traversal) [%d].\n",
+			tp->esp_in_udp);
+		KLIPS_IP_PRINT(debug_rcv, ip);
+
+		if (udpdata < skb->tail) {
+			unsigned int len = skb->tail - udpdata;
+			if ((len==1) && (udpdata[0]==0xff)) {
+				KLIPS_PRINT(debug_rcv,
+				    "klips_debug:ipsec_rcv: "
+					/* not IPv6 compliant message */
+				    "NAT-keepalive from %d.%d.%d.%d.\n", NIPQUAD(ip->saddr));
+				goto rcvleave;
+			}
+			else if ( (tp->esp_in_udp == ESPINUDP_WITH_NON_IKE) &&
+				(len > (2*sizeof(__u32) + sizeof(struct esphdr))) &&
+				(udpdata32[0]==0) && (udpdata32[1]==0) ) {
+				/* ESP Packet with Non-IKE header */
+				KLIPS_PRINT(debug_rcv, 
+					"klips_debug:ipsec_rcv: "
+					"ESPinUDP pkt with Non-IKE - spi=0x%x\n",
+					udpdata32[2]);
+				irs.natt_type = ESPINUDP_WITH_NON_IKE;
+				irs.natt_len = sizeof(struct udphdr)+(2*sizeof(__u32));
+			}
+			else if ( (tp->esp_in_udp == ESPINUDP_WITH_NON_ESP) &&
+				(len > sizeof(struct esphdr)) &&
+				(udpdata32[0]!=0) ) {
+				/* ESP Packet without Non-ESP header */
+				irs.natt_type = ESPINUDP_WITH_NON_ESP;
+				irs.natt_len = sizeof(struct udphdr);
+				KLIPS_PRINT(debug_rcv, 
+					"klips_debug:ipsec_rcv: "
+					"ESPinUDP pkt without Non-ESP - spi=0x%x\n",
+					udpdata32[0]);
+			}
+			else {
+				KLIPS_PRINT(debug_rcv,
+				    "klips_debug:ipsec_rcv: "
+					"IKE packet - not handled here\n");
+				MOD_DEC_USE_COUNT;
+				return -1;
+			}
+		}
+		else {
+			MOD_DEC_USE_COUNT;
+			return -1;
+		}
+	}
+#endif
+
 #ifdef IPH_is_SKB_PULLED
 	/* In Linux 2.4.4, the IP header has been skb_pull()ed before the
 	   packet is passed to us. So we'll skb_push() to get back to it. */
@@ -1504,6 +1557,50 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 	}
 #endif /* IP_FRAGMENT_LINEARIZE */
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	if (irs.natt_len) {
+		/**
+		 * Now, we are sure packet is ESPinUDP. Remove natt_len bytes from
+		 * packet and modify protocol to ESP.
+		 */
+		if (((unsigned char *)skb->data > (unsigned char *)skb->nh.iph) &&
+			((unsigned char *)skb->nh.iph > (unsigned char *)skb->head)) {
+			unsigned int _len = (unsigned char *)skb->data -
+				(unsigned char *)skb->nh.iph;
+			KLIPS_PRINT(debug_rcv,
+				"klips_debug:ipsec_rcv: adjusting skb: skb_push(%u)\n",
+				_len);
+			skb_push(skb, _len);
+		}
+		KLIPS_PRINT(debug_rcv,
+		    "klips_debug:ipsec_rcv: "
+			"removing %d bytes from ESPinUDP packet\n", irs.natt_len);
+		ipp = (struct iphdr *)skb->data;
+		irs.iphlen = ipp->ihl << 2;
+		ipp->tot_len = htons(ntohs(ipp->tot_len) - irs.natt_len);
+		if (skb->len < irs.iphlen + irs.natt_len) {
+			printk(KERN_WARNING
+		       "klips_error:ipsec_rcv: "
+		       "ESPinUDP packet is too small (%d < %d+%d). "
+			   "This should never happen, please report.\n",
+		       (int)(skb->len), irs.iphlen, irs.natt_len);
+			goto rcvleave;
+		}
+		memmove(skb->data + irs.natt_len, skb->data, irs.iphlen);
+		skb_pull(skb, irs.natt_len);
+
+		/* update nh.iph */
+		ipp = skb->nh.iph = (struct iphdr *)skb->data;
+
+		/* modify protocol */
+		ipp->protocol = IPPROTO_ESP;
+
+		skb->sk = NULL;
+
+		KLIPS_IP_PRINT(debug_rcv, skb->nh.iph);
+	}
+#endif
+
 	ipp = skb->nh.iph;
 	ipsaddr.s_addr = ipp->saddr;
 	addrtoa(ipsaddr, 0, irs.ipsaddr_txt, sizeof(irs.ipsaddr_txt));
@@ -1561,7 +1658,7 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 					    "Info -- pkt already proc'ed a group of ipsec headers, processing next group of ipsec headers.\n");
 				break;
 			}
-			if((ipsecdev = ipsec_dev_get(name)) == NULL) {
+			if((ipsecdev = __ipsec_dev_get(name)) == NULL) {
 				KLIPS_PRINT(debug_rcv,
 					    "klips_error:ipsec_rcv: "
 					    "device %s does not exist\n",
@@ -1597,14 +1694,13 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 			    "device supplied with skb is NULL\n");
 	}
 
-	if(!stats) {
-		ipsecdev = NULL;
+	if(stats == NULL) {
+		KLIPS_PRINT((debug_rcv),
+			    "klips_error:ipsec_rcv: "
+			    "packet received from physical I/F (%s) not connected to ipsec I/F.  Cannot record stats.  May not have SA for decoding.  Is IPSEC traffic expected on this I/F?  Check routing.\n",
+			    skb->dev ? (skb->dev->name ? skb->dev->name : "NULL") : "NULL");
 	}
-	KLIPS_PRINT((debug_rcv && !stats),
-		    "klips_error:ipsec_rcv: "
-		    "packet received from physical I/F (%s) not connected to ipsec I/F.  Cannot record stats.  May not have SA for decoding.  Is IPSEC traffic expected on this I/F?  Check routing.\n",
-		    skb->dev ? (skb->dev->name ? skb->dev->name : "NULL") : "NULL");
-
+		
 	KLIPS_IP_PRINT(debug_rcv, ipp);
 
 	/* begin decapsulating loop here */
@@ -1669,6 +1765,91 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 	}
 #endif /* CONFIG_IPSEC_IPCOMP */
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	if ((irs.natt_type) && (ipp->protocol != IPPROTO_IPIP)) {
+		/**
+		 * NAT-Traversal and Transport Mode:
+		 *   we need to correct TCP/UDP checksum
+		 *
+		 * If we've got NAT-OA, we can fix checksum without recalculation.
+		 */
+		__u32 natt_oa = ipsp->ips_natt_oa ?
+			((struct sockaddr_in*)(ipsp->ips_natt_oa))->sin_addr.s_addr : 0;
+		__u16 pkt_len = skb->tail - (unsigned char *)ipp;
+		__u16 data_len = pkt_len - (ipp->ihl << 2);
+
+		switch (ipp->protocol) {
+			case IPPROTO_TCP:
+				if (data_len >= sizeof(struct tcphdr)) {
+					struct tcphdr *tcp = (struct tcphdr *)((__u32 *)ipp+ipp->ihl);
+					if (natt_oa) {
+						__u32 buff[2] = { ~natt_oa, ipp->saddr };
+						KLIPS_PRINT(debug_rcv,
+				    		"klips_debug:ipsec_rcv: "
+							"NAT-T & TRANSPORT: "
+							"fix TCP checksum using NAT-OA\n");
+						tcp->check = csum_fold(
+							csum_partial((unsigned char *)buff, sizeof(buff),
+							tcp->check^0xffff));
+					}
+					else {
+						KLIPS_PRINT(debug_rcv,
+			    			"klips_debug:ipsec_rcv: "
+							"NAT-T & TRANSPORT: recalc TCP checksum\n");
+						if (pkt_len > (ntohs(ipp->tot_len)))
+							data_len -= (pkt_len - ntohs(ipp->tot_len));
+						tcp->check = 0;
+						tcp->check = csum_tcpudp_magic(ipp->saddr, ipp->daddr,
+							data_len, IPPROTO_TCP,
+							csum_partial((unsigned char *)tcp, data_len, 0));
+					}
+				}
+				else {
+					KLIPS_PRINT(debug_rcv,
+			    		"klips_debug:ipsec_rcv: "
+						"NAT-T & TRANSPORT: can't fix TCP checksum\n");
+				}
+				break;
+			case IPPROTO_UDP:
+				if (data_len >= sizeof(struct udphdr)) {
+					struct udphdr *udp = (struct udphdr *)((__u32 *)ipp+ipp->ihl);
+					if (udp->check == 0) {
+						KLIPS_PRINT(debug_rcv,
+				    		"klips_debug:ipsec_rcv: "
+							"NAT-T & TRANSPORT: UDP checksum already 0\n");
+					}
+					else if (natt_oa) {
+						__u32 buff[2] = { ~natt_oa, ipp->saddr };
+						KLIPS_PRINT(debug_rcv,
+				    		"klips_debug:ipsec_rcv: "
+							"NAT-T & TRANSPORT: "
+							"fix UDP checksum using NAT-OA\n");
+						udp->check = csum_fold(
+							csum_partial((unsigned char *)buff, sizeof(buff),
+							udp->check^0xffff));
+					}
+					else {
+						KLIPS_PRINT(debug_rcv,
+				    		"klips_debug:ipsec_rcv: "
+							"NAT-T & TRANSPORT: zero UDP checksum\n");
+						udp->check = 0;
+					}
+				}
+				else {
+					KLIPS_PRINT(debug_rcv,
+			    		"klips_debug:ipsec_rcv: "
+						"NAT-T & TRANSPORT: can't fix UDP checksum\n");
+				}
+				break;
+			default:
+				KLIPS_PRINT(debug_rcv,
+			    	"klips_debug:ipsec_rcv: "
+					"NAT-T & TRANSPORT: non TCP/UDP packet -- do nothing\n");
+				break;
+		}
+	}
+#endif
+
 	/*
 	 * XXX this needs to be locked from when it was first looked
 	 * up in the decapsulation loop.  Perhaps it is better to put
@@ -1878,11 +2059,7 @@ ipsec_rcv(struct sk_buff *skb, struct device *dev, struct options *opt,
 
  rcvleave:
 	if(skb) {
-#ifdef NET_21
-		kfree_skb(skb);
-#else /* NET_21 */
-		kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(skb);
 	}
 
 	MOD_DEC_USE_COUNT;
@@ -1893,22 +2070,30 @@ struct inet_protocol ah_protocol =
 {
 	ipsec_rcv,				/* AH handler */
 	NULL,				/* TUNNEL error control */
+#ifdef NETDEV_25
+	1,				/* no policy */
+#else
 	0,				/* next */
 	IPPROTO_AH,			/* protocol ID */
 	0,				/* copy */
 	NULL,				/* data */
 	"AH"				/* name */
+#endif
 };
 
 struct inet_protocol esp_protocol =
 {
 	ipsec_rcv,			/* ESP handler		*/
 	NULL,				/* TUNNEL error control */
+#ifdef NETDEV_25
+	1,				/* no policy */
+#else
 	0,				/* next */
 	IPPROTO_ESP,			/* protocol ID */
 	0,				/* copy */
 	NULL,				/* data */
 	"ESP"				/* name */
+#endif
 };
 
 #if 0
@@ -1920,22 +2105,34 @@ struct inet_protocol comp_protocol =
 {
 	ipsec_rcv,			/* COMP handler		*/
 	NULL,				/* COMP error control	*/
+#ifdef NETDEV_25
+	1,				/* no policy */
+#else
 	0,				/* next */
 	IPPROTO_COMP,			/* protocol ID */
 	0,				/* copy */
 	NULL,				/* data */
 	"COMP"				/* name */
+#endif
 };
 #endif /* CONFIG_IPSEC_IPCOMP */
 #endif
 
 /*
  * $Log: ipsec_rcv.c,v $
- * Revision 1.2  2003/09/15 12:57:30  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:34  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:56  ken
- * Stock 2.02
+ * Stock 2.03
+ *
+ * Revision 1.132  2003/09/02 19:51:48  mcr
+ * 	fixes for PR#252.
+ *
+ * Revision 1.131  2003/07/31 22:47:16  mcr
+ * 	preliminary (untested by FS-team) 2.5 patches.
+ *
+ * Revision 1.130  2003/04/03 17:38:25  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
+ * Clarified logic for non-connected devices.
  *
  * Revision 1.129  2003/02/06 02:21:34  rgb
  *
