@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_sa.c,v 1.2 2003/09/15 12:57:30 jjo Exp $
+ * RCSID $Id: ipsec_sa.c,v 1.1.1.1 2003/10/31 17:56:34 ken Exp $
  *
  * This is the file formerly known as "ipsec_xform.h"
  *
@@ -74,7 +74,6 @@
 #include <pfkey.h>
 
 #include "freeswan/ipsec_proto.h"
-#include "freeswan/ipsec_alg.h"
 
 
 #ifdef CONFIG_IPSEC_DEBUG
@@ -967,6 +966,14 @@ ipsec_sa_wipe(struct ipsec_sa *ips)
 	}
 	ips->ips_addr_p = NULL;
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+	if(ips->ips_natt_oa) {
+		memset((caddr_t)(ips->ips_natt_oa), 0, ips->ips_natt_oa_size);
+		kfree(ips->ips_natt_oa);
+	}
+	ips->ips_natt_oa = NULL;
+#endif
+
 	if(ips->ips_key_a != NULL) {
 		memset((caddr_t)(ips->ips_key_a), 0, ips->ips_key_a_size);
 		kfree(ips->ips_key_a);
@@ -974,17 +981,8 @@ ipsec_sa_wipe(struct ipsec_sa *ips)
 	ips->ips_key_a = NULL;
 
 	if(ips->ips_key_e != NULL) {
-#ifdef CONFIG_IPSEC_ALG
-		if (ips->ips_alg_enc&&ips->ips_alg_enc->ixt_e_destroy_key) {
-			ips->ips_alg_enc->ixt_e_destroy_key(ips->ips_alg_enc, 
-					ips->ips_key_e);
-		} else {
-#endif /* CONFIG_IPSEC_ALG */
 		memset((caddr_t)(ips->ips_key_e), 0, ips->ips_key_e_size);
 		kfree(ips->ips_key_e);
-#ifdef CONFIG_IPSEC_ALG
-		}
-#endif /* CONFIG_IPSEC_ALG */
 	}
 	ips->ips_key_e = NULL;
 
@@ -1009,12 +1007,6 @@ ipsec_sa_wipe(struct ipsec_sa *ips)
 		kfree(ips->ips_ident_d.data);
         }
 	ips->ips_ident_d.data = NULL;
-
-#ifdef CONFIG_IPSEC_ALG
-	if (ips->ips_alg_enc||ips->ips_alg_auth) {
-		ipsec_alg_sa_wipe(ips);
-	}
-#endif /* CONFIG_IPSEC_ALG */
 	
 	memset((caddr_t)ips, 0, sizeof(*ips));
 	kfree(ips);
@@ -1025,11 +1017,9 @@ ipsec_sa_wipe(struct ipsec_sa *ips)
 
 /*
  * $Log: ipsec_sa.c,v $
- * Revision 1.2  2003/09/15 12:57:30  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:34  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:02:56  ken
- * Stock 2.02
+ * Stock 2.03
  *
  * Revision 1.20  2003/02/06 01:50:34  rgb
  * Fixed initialisation bug for first sadb hash bucket that would only manifest itself on platforms where NULL != 0.
