@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.1.1.1 2003/09/12 19:03:00 ken Exp $";
+char ipsec_xmit_c_version[] = "RCSID $Id: ipsec_xmit.c,v 1.1.1.1 2003/10/31 17:56:37 ken Exp $";
 
 #define __NO_VERSION__
 #include <linux/module.h>
@@ -118,9 +118,129 @@ static __u32 zeroes[64];
 int sysctl_ipsec_debug_verbose = 0;
 #endif /* CONFIG_IPSEC_DEBUG */
 
+int ipsec_xmit_trap_count = 0;
+int ipsec_xmit_trap_sendcount = 0;
+
 int sysctl_ipsec_icmp = 0;
 int sysctl_ipsec_tos = 0;
 
+/*
+ * If the IP packet (iph) is a carrying TCP/UDP, then set the encaps
+ * source and destination ports to those from the TCP/UDP header.
+ */
+void extract_ports(struct iphdr * iph, struct sockaddr_encap * er)
+{
+	struct udphdr *udp;
+
+	switch (iph->protocol) {
+	case IPPROTO_UDP:
+	case IPPROTO_TCP:
+		/*
+		 * The ports are at the same offsets in a TCP and UDP
+		 * header so hack it ...
+		 */
+		udp = (struct udphdr*)(((char*)iph)+(iph->ihl<<2));
+		er->sen_sport = udp->source;
+		er->sen_dport = udp->dest;
+		break;
+	default:
+		er->sen_sport = 0;
+		er->sen_dport = 0;
+		break;
+	}
+}
+
+/*
+ * A TRAP eroute is installed and we want to replace it with a HOLD
+ * eroute.
+ */
+static int create_hold_eroute(struct sk_buff * skb, struct iphdr * iph,
+			      uint32_t eroute_pid)
+{
+	struct eroute hold_eroute;
+	struct sa_id hold_said;
+	struct sk_buff *first, *last;
+	int error;
+
+	first = last = NULL;
+	memset((caddr_t)&hold_eroute, 0, sizeof(hold_eroute));
+	memset((caddr_t)&hold_said, 0, sizeof(hold_said));
+	
+	hold_said.proto = IPPROTO_INT;
+	hold_said.spi = htonl(SPI_HOLD);
+	hold_said.dst.s_addr = INADDR_ANY;
+
+	hold_eroute.er_eaddr.sen_len = sizeof(struct sockaddr_encap);
+	hold_eroute.er_emask.sen_len = sizeof(struct sockaddr_encap);
+	hold_eroute.er_eaddr.sen_family = AF_ENCAP;
+	hold_eroute.er_emask.sen_family = AF_ENCAP;
+	hold_eroute.er_eaddr.sen_type = SENT_IP4;
+	hold_eroute.er_emask.sen_type = 255;
+	
+	hold_eroute.er_eaddr.sen_ip_src.s_addr = iph->saddr;
+	hold_eroute.er_eaddr.sen_ip_dst.s_addr = iph->daddr;
+	hold_eroute.er_emask.sen_ip_src.s_addr = INADDR_BROADCAST;
+	hold_eroute.er_emask.sen_ip_dst.s_addr = INADDR_BROADCAST;
+	hold_eroute.er_emask.sen_sport = ~0;
+	hold_eroute.er_emask.sen_dport = ~0;
+	hold_eroute.er_pid = eroute_pid;
+	hold_eroute.er_count = 0;
+	hold_eroute.er_lasttime = jiffies/HZ;
+
+	hold_eroute.er_eaddr.sen_proto = iph->protocol;
+	extract_ports(iph, &hold_eroute.er_eaddr);
+
+#ifdef CONFIG_IPSEC_DEBUG
+	if (debug_pfkey) {
+		char buf1[64], buf2[64];
+		subnettoa(hold_eroute.er_eaddr.sen_ip_src,
+			  hold_eroute.er_emask.sen_ip_src, 0, buf1, sizeof(buf1));
+		subnettoa(hold_eroute.er_eaddr.sen_ip_dst,
+			  hold_eroute.er_emask.sen_ip_dst, 0, buf2, sizeof(buf2));
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:ipsec_tunnel_start_xmit: "
+			    "calling breakeroute and makeroute for %s:%d->%s:%d %d HOLD eroute.\n",
+			    buf1, ntohs(hold_eroute.er_eaddr.sen_sport),
+			    buf2, ntohs(hold_eroute.er_eaddr.sen_dport),
+			    hold_eroute.er_eaddr.sen_proto);
+	}
+#endif /* CONFIG_IPSEC_DEBUG */
+
+	if (ipsec_breakroute(&(hold_eroute.er_eaddr), &(hold_eroute.er_emask),
+			     &first, &last)) {
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:ipsec_tunnel_start_xmit: "
+			    "HOLD breakeroute found nothing.\n");
+	} else {
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:ipsec_tunnel_start_xmit: "
+			    "HOLD breakroute deleted %u.%u.%u.%u:%u -> %u.%u.%u.%u:%u %u\n",
+			    NIPQUAD(hold_eroute.er_eaddr.sen_ip_src),
+			    ntohs(hold_eroute.er_eaddr.sen_sport),
+			    NIPQUAD(hold_eroute.er_eaddr.sen_ip_dst),
+			    ntohs(hold_eroute.er_eaddr.sen_dport),
+			    hold_eroute.er_eaddr.sen_proto);
+	}
+	if (first != NULL)
+		kfree_skb(first);
+	if (last != NULL)
+		kfree_skb(last);
+
+	error = ipsec_makeroute(&(hold_eroute.er_eaddr),
+				&(hold_eroute.er_emask),
+				hold_said, eroute_pid, skb, NULL, NULL);
+	if (error) {
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:ipsec_tunnel_start_xmit: "
+			    "HOLD makeroute returned %d, failed.\n", error);
+	} else {
+		KLIPS_PRINT(debug_pfkey,
+			    "klips_debug:ipsec_tunnel_start_xmit: "
+			    "HOLD makeroute call successful.\n");
+	}
+	return (error == 0);
+}
+
 #ifdef CONFIG_IPSEC_DEBUG_
 DEBUG_NO_STATIC void
 dmp(char *s, caddr_t bb, int len)
@@ -999,10 +1119,7 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 #ifdef CONFIG_IPSEC_DEBUG
 			char bufsrc[ADDRTOA_BUF], bufdst[ADDRTOA_BUF];
 #endif /* CONFIG_IPSEC_DEBUG */
-			struct eroute hold_eroute;
-			struct sa_id hold_said;
-			struct sk_buff *first = NULL, *last = NULL;
-				
+
 			/* Signal all listening KMds with a PF_KEY ACQUIRE */
 			ixs->ips.ips_said.proto = ixs->iph->protocol;
 			src.sin_family = AF_INET;
@@ -1043,7 +1160,13 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 				    ntohs(((struct sockaddr_in*)(ixs->ips.ips_addr_d))->sin_port),
 				    ixs->ips.ips_said.proto);
 				
+			/* increment count of total traps needed */
+			ipsec_xmit_trap_count++;
+
 			if (pfkey_acquire(&ixs->ips) == 0) {
+
+				/* note that we succeeded */
+			        ipsec_xmit_trap_sendcount++;
 					
 				if (ixs->outgoing_said.spi==htonl(SPI_TRAPSUBNET)) {
 					/*
@@ -1060,106 +1183,8 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 						ixs->skb = NULL;
 					}
 					spin_unlock(&eroute_lock);
-				} else {
-					/* install HOLD eroute */
-					memset((caddr_t)&hold_eroute, 0, sizeof(hold_eroute));
-					memset((caddr_t)&hold_said, 0, sizeof(hold_said));
-						
-					hold_said.proto = IPPROTO_INT;
-					hold_said.spi = htonl(SPI_HOLD);
-					hold_said.dst.s_addr = INADDR_ANY;
-						
-					hold_eroute.er_eaddr.sen_len = sizeof(struct sockaddr_encap);
-					hold_eroute.er_emask.sen_len = sizeof(struct sockaddr_encap);
-					hold_eroute.er_eaddr.sen_family = AF_ENCAP;
-					hold_eroute.er_emask.sen_family = AF_ENCAP;
-					hold_eroute.er_eaddr.sen_type = SENT_IP4;
-					hold_eroute.er_emask.sen_type = 255;
-						
-					hold_eroute.er_eaddr.sen_ip_src.s_addr = ixs->iph->saddr;
-					hold_eroute.er_eaddr.sen_ip_dst.s_addr = ixs->iph->daddr;
-					hold_eroute.er_emask.sen_ip_src.s_addr = INADDR_BROADCAST;
-					hold_eroute.er_emask.sen_ip_dst.s_addr = INADDR_BROADCAST;
-						
-					hold_eroute.er_pid = ixs->eroute_pid;
-					hold_eroute.er_count = 0;
-					hold_eroute.er_lasttime = jiffies/HZ;
-						
-#ifdef IPSEC_CONFIG_FULL_SELECTOR_LIST
-					/* These are ficticious.  Don't uncomment these until
-					   proto, sport and dport exist in the SPDB */
-					hold_eroute.er_proto = ixs->iph->protocol;
-					hold_eroute.er_src_port = 
-						(ixs->iph->protocol == IPPROTO_UDP
-						 ? ((struct udphdr*) (((caddr_t)ixs->iph) + (ixs->iph->ihl << 2)))->source
-						 : (ixs->iph->protocol == IPPROTO_TCP
-						    ? ((struct tcphdr*)((caddr_t)ixs->iph + (ixs->iph->ihl << 2)))->source
-						    : 0));
-					hold_eroute.er_dst_port = 
-						(ixs->iph->protocol == IPPROTO_UDP
-						 ? ((struct udphdr*) (((caddr_t)ixs->iph) + (ixs->iph->ihl << 2)))->dest
-						 : (ixs->iph->protocol == IPPROTO_TCP
-						    ? ((struct tcphdr*)((caddr_t)ixs->iph + (ixs->iph->ihl << 2)))->dest
-						    : 0));
-#endif /* IPSEC_CONFIG_FULL_SELECTOR_LIST */
-						
-#ifdef CONFIG_IPSEC_DEBUG
-					if (debug_pfkey) {
-						char buf1[64], buf2[64];
-						subnettoa(hold_eroute.er_eaddr.sen_ip_src,
-							  hold_eroute.er_emask.sen_ip_src, 0, buf1, sizeof(buf1));
-						subnettoa(hold_eroute.er_eaddr.sen_ip_dst,
-							  hold_eroute.er_emask.sen_ip_dst, 0, buf2, sizeof(buf2));
-						KLIPS_PRINT(debug_pfkey,
-							    "klips_debug:ipsec_xmit_encap_bundle: "
-							    "calling breakeroute and makeroute for %s->%s HOLD eroute.\n",
-							    buf1, buf2);
-					}
-#endif /* CONFIG_IPSEC_DEBUG */
-
-					ixs->error = ipsec_breakroute(&(hold_eroute.er_eaddr),
-							 &(hold_eroute.er_emask),
-							 &first, &last);
-					if (ixs->error != EINVAL) {
-						KLIPS_PRINT(debug_pfkey,
-							    "klips_debug:ipsec_xmit_encap_bundle: "
-							    "breakeroute should have failed.  first=0p%p, last=0p%p\n",
-							    first, last);
-					} else {
-						KLIPS_PRINT(debug_pfkey,
-							    "klips_debug:ipsec_xmit_encap_bundle: "
-							    "HOLD breakeroute found nothing as expected.\n");
-					}
-					if(first != NULL) {
-						ipsec_kfree_skb(first);
-					}
-					if(last != NULL) {
-						ipsec_kfree_skb(last);
-					}
-#if 0
-					if (ixs->error != EINVAL) {
-						SENDERR(-error);
-					}
-#endif
-						
-					if ((ixs->error = ipsec_makeroute(&(hold_eroute.er_eaddr),
-									  &(hold_eroute.er_emask),
-									  hold_said,
-									  ixs->eroute_pid,
-									  ixs->skb,
-									  NULL,
-									  NULL))) {
-						KLIPS_PRINT(debug_pfkey,
-							    "klips_debug:ipsec_xmit_encap_bundle: "
-							    "HOLD makeroute returned %d, failed.\n",
-							    ixs->error);
-						/* SENDERR(-ixs->error); */
-					} else {
-						KLIPS_PRINT(debug_pfkey,
-							    "klips_debug:ipsec_xmit_encap_bundle: "
-							    "HOLD makeroute call successful.\n");
-						ixs->skb = NULL;
-					}
+				} else if (create_hold_eroute(ixs->skb, ixs->iph, ixs->eroute_pid)) {
+					ixs->skb = NULL;
 				}
 			}
 			ixs->stats->tx_dropped++;
@@ -1327,6 +1352,25 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 				goto cleanup;
 			}			
 			ixs->tailroom += ((8 - ((ixs->pyldsz + 2 * sizeof(unsigned char)) % 8)) % 8) + 2;
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+		if ((ixs->ipsp->ips_natt_type) && (!ixs->natt_type)) {
+			ixs->natt_type = ixs->ipsp->ips_natt_type;
+			ixs->natt_sport = ixs->ipsp->ips_natt_sport;
+			ixs->natt_dport = ixs->ipsp->ips_natt_dport;
+			switch (ixs->natt_type) {
+				case ESPINUDP_WITH_NON_IKE:
+					ixs->natt_head = sizeof(struct udphdr)+(2*sizeof(__u32));
+					break;
+				case ESPINUDP_WITH_NON_ESP:
+					ixs->natt_head = sizeof(struct udphdr);
+					break;
+				default:
+					ixs->natt_head = 0;
+					break;
+			}
+			ixs->tailroom += ixs->natt_head;
+		}
+#endif			
 			break;
 #endif /* !CONFIG_IPSEC_ESP */
 #ifdef CONFIG_IPSEC_IPIP
@@ -1470,6 +1514,85 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 	}
 #endif /* MSS_HACK */
 
+#ifdef CONFIG_IPSEC_NAT_TRAVERSAL
+      if ((ixs->natt_type) && (ixs->outgoing_said.proto != IPPROTO_IPIP)) {
+	      /**
+	       * NAT-Traversal and Transport Mode:
+	       *   we need to correct TCP/UDP checksum
+	       *
+	       * If we've got NAT-OA, we can fix checksum without recalculation.
+	       * If we don't we can zero udp checksum.
+	       */
+	      __u32 natt_oa = ixs->ipsp->ips_natt_oa ?
+		      ((struct sockaddr_in*)(ixs->ipsp->ips_natt_oa))->sin_addr.s_addr : 0;
+	      __u16 pkt_len = ixs->skb->tail - (unsigned char *)ixs->iph;
+	      __u16 data_len = pkt_len - (ixs->iph->ihl << 2);
+	      switch (ixs->iph->protocol) {
+		      case IPPROTO_TCP:
+			      if (data_len >= sizeof(struct tcphdr)) {
+				      struct tcphdr *tcp = (struct tcphdr *)((__u32 *)ixs->iph+ixs->iph->ihl);
+				      if (natt_oa) {
+					      __u32 buff[2] = { ~ixs->iph->daddr, natt_oa };
+					      KLIPS_PRINT(debug_tunnel,
+						      "klips_debug:ipsec_tunnel_start_xmit: "
+						      "NAT-T & TRANSPORT: "
+						      "fix TCP checksum using NAT-OA\n");
+					      tcp->check = csum_fold(
+						      csum_partial((unsigned char *)buff, sizeof(buff),
+						      tcp->check^0xffff));
+				      }
+				      else {
+					      KLIPS_PRINT(debug_tunnel,
+						      "klips_debug:ipsec_tunnel_start_xmit: "
+						      "NAT-T & TRANSPORT: do not recalc TCP checksum\n");
+				      }
+			      }
+			      else {
+				      KLIPS_PRINT(debug_tunnel,
+					      "klips_debug:ipsec_tunnel_start_xmit: "
+					      "NAT-T & TRANSPORT: can't fix TCP checksum\n");
+			      }
+			      break;
+		      case IPPROTO_UDP:
+			      if (data_len >= sizeof(struct udphdr)) {
+				      struct udphdr *udp = (struct udphdr *)((__u32 *)ixs->iph+ixs->iph->ihl);
+				      if (udp->check == 0) {
+					      KLIPS_PRINT(debug_tunnel,
+						      "klips_debug:ipsec_tunnel_start_xmit: "
+						      "NAT-T & TRANSPORT: UDP checksum already 0\n");
+				      }
+				      else if (natt_oa) {
+					      __u32 buff[2] = { ~ixs->iph->daddr, natt_oa };
+					      KLIPS_PRINT(debug_tunnel,
+						      "klips_debug:ipsec_tunnel_start_xmit: "
+						      "NAT-T & TRANSPORT: "
+						      "fix UDP checksum using NAT-OA\n");
+					      udp->check = csum_fold(
+						      csum_partial((unsigned char *)buff, sizeof(buff),
+						      udp->check^0xffff));
+				      }
+				      else {
+					      KLIPS_PRINT(debug_tunnel,
+						      "klips_debug:ipsec_tunnel_start_xmit: "
+						      "NAT-T & TRANSPORT: zero UDP checksum\n");
+					      udp->check = 0;
+				      }
+			      }
+			      else {
+				      KLIPS_PRINT(debug_tunnel,
+					      "klips_debug:ipsec_tunnel_start_xmit: "
+					      "NAT-T & TRANSPORT: can't fix UDP checksum\n");
+			      }
+			      break;
+		      default:
+			      KLIPS_PRINT(debug_tunnel,
+				      "klips_debug:ipsec_tunnel_start_xmit: "
+				      "NAT-T & TRANSPORT: non TCP/UDP packet -- do nothing\n");
+			      break;
+	      }
+      }
+#endif /* CONFIG_IPSEC_NAT_TRAVERSAL */
+
 	if(!ixs->hard_header_stripped) {
 		KLIPS_PRINT(debug_tunnel & DB_TN_XMIT,
 			    "klips_debug:ipsec_xmit_encap_bundle: "
@@ -1583,8 +1706,16 @@ ipsec_xmit_encap_bundle(struct ipsec_xmit_state *ixs)
 
 /*
  * $Log: ipsec_xmit.c,v $
- * Revision 1.1.1.1  2003/09/12 19:03:00  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:37  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.4  2003/06/20 02:28:10  mcr
+ * 	misstype of variable name, not detected by module build.
+ *
+ * Revision 1.3  2003/06/20 01:42:21  mcr
+ * 	added counters to measure how many ACQUIREs we send to pluto,
+ * 	and how many are successfully sent.
  *
  * Revision 1.2  2003/04/03 17:38:35  rgb
  * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
