@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2.c,v 1.2 2003/09/15 12:57:31 jjo Exp $
+ * RCSID $Id: pfkey_v2.c,v 1.1.1.1 2003/10/31 17:56:38 ken Exp $
  */
 
 /*
@@ -434,20 +434,12 @@ pfkey_destroy_socket(struct sock *sk)
 			printk("\n");
 		}
 #endif /* CONFIG_IPSEC_DEBUG */
+#endif /* NET_21 */
 		KLIPS_PRINT(debug_pfkey,
 			    "klips_debug:pfkey_destroy_socket: "
 			    "skb=0p%p freed.\n",
 			    skb);
-		kfree_skb(skb);
-
-#else /* NET_21 */
-		KLIPS_PRINT(debug_pfkey,
-			    "klips_debug:pfkey_destroy_socket: "
-			    "skb=0p%p dequeued and freed.\n",
-			    skb);
-		kfree_skb(skb, FREE_WRITE);
-
-#endif /* NET_21 */
+		ipsec_kfree_skb(skb);
 	}
 
 	sk->dead = 1;
@@ -513,11 +505,7 @@ pfkey_upmsg(struct socket *sock, struct sadb_msg *pfkey_msg)
 		       "tried to skb_put %ld, %d available.  This should never happen, please report.\n",
 		       (unsigned long int)pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN,
 		       skb_tailroom(skb));
-#ifdef NET_21
-		kfree_skb(skb);
-#else /* NET_21 */
-		kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
+		ipsec_kfree_skb(skb);
 		return -ENOBUFS;
 	}
 	skb->h.raw = skb_put(skb, pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN);
@@ -529,16 +517,12 @@ pfkey_upmsg(struct socket *sock, struct sadb_msg *pfkey_msg)
 
 	if((error = sock_queue_rcv_skb(sk, skb)) < 0) {
 		skb->sk=NULL;
-#ifdef NET_21
-		kfree_skb(skb);
-#else /* NET_21 */
-		kfree_skb(skb, FREE_WRITE);
-#endif /* NET_21 */
 		KLIPS_PRINT(debug_pfkey,
 			    "klips_debug:pfkey_upmsg: "
 			    "error=%d calling sock_queue_rcv_skb with skb=0p%p.\n",
 			    error,
 			    skb);
+		ipsec_kfree_skb(skb);
 		return error;
 	}
 	return error;
@@ -1626,23 +1610,13 @@ pfkey_init(void)
 	int i;
 	
 	static struct supported supported_init_ah[] = {
-#ifdef CONFIG_IPSEC_AUTH_HMAC_MD5
 		{SADB_EXT_SUPPORTED_AUTH, SADB_AALG_MD5HMAC, 0, 128, 128},
-#endif /* CONFIG_IPSEC_AUTH_HMAC_MD5 */
-#ifdef CONFIG_IPSEC_AUTH_HMAC_SHA1
 		{SADB_EXT_SUPPORTED_AUTH, SADB_AALG_SHA1HMAC, 0, 160, 160}
-#endif /* CONFIG_IPSEC_AUTH_HMAC_SHA1 */
 	};
 	static struct supported supported_init_esp[] = {
-#ifdef CONFIG_IPSEC_AUTH_HMAC_MD5
 		{SADB_EXT_SUPPORTED_AUTH, SADB_AALG_MD5HMAC, 0, 128, 128},
-#endif /* CONFIG_IPSEC_AUTH_HMAC_MD5 */
-#ifdef CONFIG_IPSEC_AUTH_HMAC_SHA1
 		{SADB_EXT_SUPPORTED_AUTH, SADB_AALG_SHA1HMAC, 0, 160, 160},
-#endif /* CONFIG_IPSEC_AUTH_HMAC_SHA1 */
-#ifdef CONFIG_IPSEC_ENC_3DES
-		{SADB_EXT_SUPPORTED_ENCRYPT, SADB_EALG_3DESCBC, 64, 168, 168},
-#endif /* CONFIG_IPSEC_ENC_3DES */
+		{SADB_EXT_SUPPORTED_ENCRYPT, SADB_EALG_3DESCBC, 128, 168, 168}
 	};
 	static struct supported supported_init_ipip[] = {
 		{SADB_EXT_SUPPORTED_ENCRYPT, SADB_X_TALG_IPv4_in_IPv4, 0, 32, 32}
@@ -1770,11 +1744,12 @@ pfkey_proto_init(struct net_proto *pro)
 
 /*
  * $Log: pfkey_v2.c,v $
- * Revision 1.2  2003/09/15 12:57:31  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:38  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:03:00  ken
- * Stock 2.02
+ * Stock 2.03
+ *
+ * Revision 1.78  2003/04/03 17:38:09  rgb
+ * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
  *
  * Revision 1.77  2002/10/17 16:49:36  mcr
  * 	sock->ops should reference the unwrapped options so that
