@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.2 2003/09/12 19:23:32 ken Exp $";
+char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.1.1.1 2003/10/31 17:56:46 ken Exp $";
 
 
 #include <sys/types.h>
@@ -786,7 +786,7 @@ main(int argc, char **argv)
 	if((error = write(pfkey_sock,
 			  pfkey_msg,
 			  pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) !=
-	   pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN) {
+	   (ssize_t)(pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) {
 		fprintf(stderr, "%s: pfkey write failed, returning %d with errno=%d.\n",
 			program_name, error, errno);
 		pfkey_extensions_free(extensions);
@@ -881,11 +881,12 @@ main(int argc, char **argv)
 }
 /*
  * $Log: eroute.c,v $
- * Revision 1.2  2003/09/12 19:23:32  ken
- * Import X.509 1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:56:46  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:03:09  ken
- * Stock 2.02
+ * Stock 2.03
+ *
+ * Revision 1.56  2003/09/10 00:01:25  mcr
+ * 	fixes for gcc 3.3 from Matthias Bethke <Matthias.Bethke@gmx.net>
  *
  * Revision 1.55  2003/01/30 02:33:07  rgb
  *
