@@ -15,7 +15,7 @@
  * for more details.
  */
 
-char klipsdebug_c_version[] = "RCSID $Id: klipsdebug.c,v 1.1.1.1 2003/09/12 19:03:09 ken Exp $";
+char klipsdebug_c_version[] = "RCSID $Id: klipsdebug.c,v 1.1.1.1 2003/10/31 17:56:46 ken Exp $";
 
 
 #include <sys/types.h>
@@ -374,7 +374,7 @@ main(int argc, char **argv)
 	if((error = write(pfkey_sock,
 			  pfkey_msg,
 			  pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) !=
-	   pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN) {
+	   (ssize_t)(pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) {
 		fprintf(stderr,
 			"%s: pfkey write failed, tried to write %u octets, returning %d with errno=%d.\n",
 			program_name,
@@ -442,8 +442,12 @@ main(int argc, char **argv)
 }
 /*
  * $Log: klipsdebug.c,v $
- * Revision 1.1.1.1  2003/09/12 19:03:09  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:46  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.53  2003/09/10 00:01:27  mcr
+ * 	fixes for gcc 3.3 from Matthias Bethke <Matthias.Bethke@gmx.net>
  *
  * Revision 1.52  2003/01/30 02:33:07  rgb
  *
