@@ -13,7 +13,7 @@
  * for more details.
  */
 
-char tncfg_c_version[] = "RCSID $Id: lwdnsq.c,v 1.1.1.1 2003/09/12 19:03:10 ken Exp $";
+char tncfg_c_version[] = "RCSID $Id: lwdnsq.c,v 1.1.1.1 2003/10/31 17:56:48 ken Exp $";
 
 
 #include <stdio.h>
@@ -29,6 +29,19 @@ char tncfg_c_version[] = "RCSID $Id: lwdnsq.c,v 1.1.1.1 2003/09/12 19:03:10 ken
 #include <ctype.h>
 #include <signal.h>
 
+#include <isc/lang.h>
+#include <isc/magic.h>
+#include <isc/types.h>
+#include <isc/result.h>
+#include <isc/mem.h>
+#include <isc/buffer.h>
+#include <isc/region.h>
+#include <dns/name.h>
+#include <dns/rdata.h>
+#include <dns/rdatastruct.h>
+#include <lwres/netdb.h>
+#include <lwres/async.h>
+
 #include "lwdnsq.h"
 
 static void
@@ -45,6 +58,7 @@ static struct option const longopts[] =
 	{"serial", 0, 0, 's'},
 	{"debug",  0, 0, 'g'},
 	{"regress",0, 0, 'X'},
+	{"ignoreeof",0, 0, 'Z'},
 	{0, 0, 0, 0}
 };
 
@@ -114,6 +128,12 @@ int cmdparse(dnskey_glob *gs,
 	const struct cmd_entry *ce = cmds;
 
 	argc=0;
+	
+	/* skip initial spaces */
+	while(cmdline && isspace(*cmdline)) {
+		cmdline++;
+	}
+
 	while(cmdline && *cmdline!='\0' &&
 	      (arg=strsep(&cmdline, " \t\n"))!=NULL) {
 	  if (argc < sizeof(argv)/sizeof(*argv - 1)) {
@@ -199,6 +219,8 @@ main(int argc, char *argv[])
 	char *program_name;
 	dnskey_glob gs;
 	int c;
+	static int ignoreeof=0;  /* static to avoid longjmp clobber */
+	int ineof;
 
 	memset(&gs, 0, sizeof(dnskey_glob));
 
@@ -210,8 +232,27 @@ main(int argc, char *argv[])
 	program_name = argv[0];
 	gs.concurrent = 1;
 
-	while((c = getopt_long_only(argc, argv, "gsiX", longopts, 0)) != EOF) {
+	if(lwres_async_init(&gs.lwctx) != ERRSET_SUCCESS) {
+		fprintf(stderr, "Can not initialize async context\n");
+		exit(3);
+	}
+
+	if(isc_mem_create(0,0,&gs.iscmem) != ISC_R_SUCCESS) {
+		fprintf(stderr, "Can not initialize isc memory allocator\n");
+		exit(4);
+	}
+
+	if(isc_buffer_allocate(gs.iscmem, &gs.iscbuf, LWDNSQ_RESULT_LEN_MAX)) {
+		fprintf(stderr, "Can not allocate a result buffer\n");
+		exit(5);
+	}
+
+	while((c = getopt_long_only(argc, argv, "dgsiXZ", longopts, 0)) != EOF) {
 		switch(c) {
+		case 'd':
+			gs.debug+=2;
+			break;
+
 		case 'g':
 			gs.debug++;
 			break;
@@ -225,12 +266,20 @@ main(int argc, char *argv[])
 			gs.regress++;
 			break;
 
+		case 'Z':
+			ignoreeof=1;
+			break;
+
 		default:
 			usage(program_name);
 			break;
 		}
 	}
 
+	if(gs.debug && ignoreeof) {
+		fprintf(stderr, "Ignoring end of file\n");
+	}
+
 	if(isatty(0)) {
 		gs.prompt=1;
 	}
@@ -253,13 +302,18 @@ main(int argc, char *argv[])
 	
 	cmdprompt(&gs);
 
+	ineof = 0;
 	gs.done = 0;
 	gs.cmdproto_out = stdout;
-	gs.l_fds[0].events=POLLIN;
+	gs.l_fds[0].events = POLLIN|POLLHUP;
 	gs.l_fds[0].fd=0;
-	gs.l_nfds= 1;
 
-	while(!gs.done)
+	gs.l_fds[1].events = POLLIN|POLLHUP|POLLERR;
+	gs.l_fds[1].fd = lwres_async_fd(gs.lwctx);
+
+	gs.l_nfds= 2;
+
+	while(!gs.done) 
 	{
 		int    timeout;
 		char   buf[128];
@@ -268,31 +322,115 @@ main(int argc, char *argv[])
 
 		timeout=-1;
 
+		gs.l_fds[0].revents = 0;
+
+		gs.l_fds[1].events = POLLIN|POLLHUP|POLLERR;
+		gs.l_fds[1].revents = 0;
+		gs.l_fds[1].fd = lwres_async_fd(gs.lwctx);
+
 		if(gs.debug > 1) {
-			fprintf(stderr, "invoking poll(,%d,) with %s",
+			fprintf(stderr, "=== invoking poll(,%d,) with %s\n",
 				gs.l_nfds,
 				timeout>0 ? "waittime" : "no wait");
-
+			for(n = 0; n < gs.l_nfds; n++) {
+				fprintf(stderr, "=== waiting on fd#%d\n",
+					gs.l_fds[n].fd);
+			}
+			fprintf(stderr, "=== inflight: %d\n", gs.dns_inflight);
 		}
 
 		n = poll(gs.l_fds, gs.l_nfds, timeout);
 
+		if(n == 0) {
+			/* timeout! */
+		}
+
+		if(n < 0) {
+			perror("poll");
+		}
+
+		if(gs.debug > 1) {
+			fprintf(stderr, "=== poll returned with %d\n", n);
+		}
+				
 		while(n>0) {
+			if((gs.l_fds[0].revents & POLLERR) == POLLERR ||
+			   (gs.l_fds[1].revents & POLLERR) == POLLERR)
+			{
+				break;
+			}
+
+			/* see if there are DNS events coming back */
+			if((gs.l_fds[1].revents & POLLIN) == POLLIN) {
+				if(gs.debug > 1) {
+					fprintf(stderr,
+						"=== new responses from lwdnsd\n");
+				}
+
+				process_dns_reply(&gs);
+				fflush(stdout);
+				n--;
+			}
+
+			if(!ignoreeof &&
+			   (gs.l_fds[0].revents & POLLHUP) == POLLHUP)
+			{
+				break;
+			}
+
 			if((gs.l_fds[0].revents & POLLIN) == POLLIN) {
+				
 				rlen=read(0, buf, sizeof(buf));
+
+				if(gs.debug > 1) {
+					if(rlen > 0) {
+						buf[rlen]='\0';
+					}
+					fprintf(stderr,
+						"=== new commands on fd 0: %d: %s\n",
+						rlen, buf);
+				}
+
 				if(rlen > 0) {
 					cmdread(&gs, buf, rlen);
 				} else if(rlen == 0) {
-					/* EOF, die */
-					gs.done=1;
+					ineof = 1;
+					if(!ignoreeof) {
+						/* EOF, die */
+						gs.done=1;
+					}
 				}
 				n--;
 			} 
-			if((gs.l_fds[0].revents & POLLHUP) == POLLHUP) {
+
+		}
+
+		if((gs.l_fds[0].revents & POLLHUP) == POLLHUP)
+		{
+			ineof = 1;
+			if(!ignoreeof)
+			{
 				gs.done=1;
-				break;
 			}
 		}
+
+		if(ignoreeof) {
+			/* if we have exhausted the input,
+			 * and there are none in flight,
+			 * then exit, finally.
+			 */
+			if(ineof) { 
+				if(gs.dns_inflight == 0) {
+					gs.done=1;
+				}
+			}
+		}
+
+		if(gs.debug) {
+			fprintf(stderr, "=== ineof: %d inflight: %d\n",
+				ineof, gs.dns_inflight);
+		}
+
 	}
 
 	signal(SIGINT,  SIG_DFL);
@@ -303,8 +441,19 @@ main(int argc, char *argv[])
 	
 /*
  * $Log: lwdnsq.c,v $
- * Revision 1.1.1.1  2003/09/12 19:03:10  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:48  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.12  2003/09/16 05:01:14  mcr
+ * 	prefix all debugging with === so that it can be easily removed.
+ *
+ * Revision 1.11  2003/09/10 04:43:52  mcr
+ * 	final fixes to lwdnsq to exit only when all requests are done,
+ * 	and we have been told to wait, *OR* if there is an EOF in stdin.
+ *
+ * Revision 1.10  2003/09/03 01:13:24  mcr
+ * 	first attempt at async capable lwdnsq.
  *
  * Revision 1.9  2003/04/02 07:37:57  dhr
  *
