@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pf_key.c,v 1.1.1.1 2003/09/12 19:03:11 ken Exp $
+ * RCSID $Id: pf_key.c,v 1.1.1.1 2003/10/31 17:56:49 ken Exp $
  *
  */
 
@@ -88,7 +88,7 @@ pfkey_register(uint8_t satype) {
 	}
 	if(write(pfkey_sock, pfkey_msg,
 		 pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN) !=
-	   pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN) {
+	   (ssize_t)(pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) {
 		/* cleanup code here */
 		fprintf(stderr, "%s: Trouble writing to channel PF_KEY.\n", progname);
 		pfkey_extensions_free(extensions);
@@ -113,7 +113,7 @@ int
 main(int argc, char *argv[])
 {
 	int opt;
-	int readlen;
+	ssize_t readlen;
 	unsigned char pfkey_buf[256];
 	struct sadb_msg *msg;
 	int fork_after_register;
@@ -227,7 +227,7 @@ main(int argc, char *argv[])
 		msg = (struct sadb_msg *)pfkey_buf;
 		
 		/* first, see if we got enough for an sadb_msg */
-		if(readlen < sizeof(struct sadb_msg)) {
+		if((size_t)readlen < sizeof(struct sadb_msg)) {
 			printf("%s: runt packet of size: %d (<%lu)\n",
 			       progname, readlen, (unsigned long)sizeof(struct sadb_msg));
 			continue;
@@ -245,7 +245,7 @@ main(int argc, char *argv[])
 		       msg->sadb_msg_satype,
 		       satype2name(msg->sadb_msg_satype));
 		
-		if(readlen != msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)
+		if((size_t)readlen != msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)
 		{
 			printf("%s: packet size read from socket=%d doesn't equal sadb_msg_len %d * %u; message not decoded\n",
 			       progname,
@@ -270,8 +270,12 @@ main(int argc, char *argv[])
 	
 /*
  * $Log: pf_key.c,v $
- * Revision 1.1.1.1  2003/09/12 19:03:11  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:56:49  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.15  2003/09/10 00:01:30  mcr
+ * 	fixes for gcc 3.3 from Matthias Bethke <Matthias.Bethke@gmx.net>
  *
  * Revision 1.14  2002/10/09 03:12:05  dhr
  *
