@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: connections.h,v 1.3 2003/09/15 12:57:38 jjo Exp $
+ * RCSID $Id: connections.h,v 1.1.1.1 2003/10/31 17:56:53 ken Exp $
  */
 
 /* There are two kinds of connections:
@@ -115,6 +115,10 @@ typedef unsigned long policy_prio_t;
 #define POLICY_PRIO_BUF	(3+1+3+1)
 extern void fmt_policy_prio(policy_prio_t pp, char buf[POLICY_PRIO_BUF]);
 
+#ifdef VIRTUAL_IP
+struct virtual_t;
+#endif
+
 struct end {
     struct id id;
     ip_address
@@ -133,6 +137,9 @@ struct end {
     cert_t cert;		/* end certificate */
     chunk_t ca;			/* CA distinguished name */
     smartcard_t *sc;		/* smartcard reader and key info */
+#ifdef VIRTUAL_IP
+    struct virtual_t *virt;
+#endif    
 };
 
 struct spd_route {
@@ -141,6 +148,7 @@ struct spd_route {
     struct end that;
     so_serial_t eroute_owner;
     enum routing_t routing;	/* level of routing in place */
+    uint32_t reqid;
 };
 
 struct connection {
@@ -152,6 +160,11 @@ struct connection {
     unsigned long sa_rekey_fuzz;
     unsigned long sa_keying_tries;
 
+    char              *log_file_name;       /* name of log file */
+    FILE              *log_file;            /* possibly open FILE */
+    CIRCLEQ_ENTRY(connection) log_link;     /* linked list of open conns */
+    bool               log_file_err;        /* only bitch once */
+
     struct spd_route spd;
 
     /* internal fields: */
@@ -179,8 +192,6 @@ struct connection {
 				       next one to apply */
 
     struct gw_info *gw_info;
-    struct alg_info_esp *alg_info_esp;
-    struct alg_info_ike *alg_info_ike;
 
     struct host_pair *host_pair;
     struct connection *hp_next;	/* host pair list link */
@@ -246,7 +257,8 @@ extern struct connection
 	, const u_int8_t our_protocol
 	, const u_int16_t out_port
 	, const u_int8_t peer_protocol
-	, const u_int16_t peer_port);
+	, const u_int16_t peer_port),
+    *find_connection_by_reqid(uint32_t reqid);
 
 extern struct connection *
 find_connection_for_clients(struct spd_route **srp
@@ -259,9 +271,14 @@ find_connection_for_clients(struct spd_route **srp
  * is looking through state objects.
  */
 struct gw_info;	/* forward declaration of tag (defined in dnskey.h) */
-struct alg_info;	/* forward declaration of tag (defined in alg_info.h) */
 extern struct connection *rw_instantiate(struct connection *c
 					 , const ip_address *him
+#ifdef NAT_TRAVERSAL
+					 , u_int16_t his_port
+#endif
+#ifdef VIRTUAL_IP
+					 , const ip_subnet *his_net
+#endif					 
 					 , const struct id *his_id);
 
 extern struct connection *oppo_instantiate(struct connection *c
@@ -318,3 +335,9 @@ extern struct connection *eclipsed(struct connection *c, struct spd_route **);
 extern void show_connections_status(void);
 extern int  connection_compare(const struct connection *ca
 			       , const struct connection *cb);
+#ifdef NAT_TRAVERSAL
+void
+update_host_pair(const char *why, struct connection *c,
+       const ip_address *myaddr, u_int16_t myport ,
+       const ip_address *hisaddr, u_int16_t hisport);
+#endif /* NAT_TRAVERSAL */
