@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: constants.c,v 1.3 2003/09/15 12:57:38 jjo Exp $
+ * RCSID $Id: constants.c,v 1.1.1.1 2003/10/31 17:56:53 ken Exp $
  */
 
 /*
@@ -85,10 +85,17 @@ static const char *const timer_event_name[] = {
 	"EVENT_SA_REPLACE",
 	"EVENT_SA_REPLACE_IF_USED",
 	"EVENT_SA_EXPIRE",
+#ifdef NAT_TRAVERSAL
+	"EVENT_NAT_T_KEEPALIVE",
+#endif
     };
 
 enum_names timer_event_names =
+#ifdef NAT_TRAVERSAL
+    { EVENT_NULL, EVENT_NAT_T_KEEPALIVE, timer_event_name, NULL };
+#else
     { EVENT_NULL, EVENT_SA_EXPIRE, timer_event_name, NULL };
+#endif
 
 /* Domain of Interpretation */
 
@@ -222,11 +229,25 @@ const char *const payload_name[] = {
 	"ISAKMP_NEXT_N",
 	"ISAKMP_NEXT_D",
 	"ISAKMP_NEXT_VID",
+#ifdef NAT_TRAVERSAL
+	"ISAKMP_NEXT_14",
+	"ISAKMP_NEXT_NAT-D",
+	"ISAKMP_NEXT_NAT-OA",
+#endif	
 	NULL
     };
 
+#ifdef NAT_TRAVERSAL
+const char *const payload_name_nat_d[] = { "ISAKMP_NEXT_NAT-D",
+	"ISAKMP_NEXT_NAT-OA", NULL };
+static enum_names payload_names_nat_d =
+	{ ISAKMP_NEXT_NATD_DRAFTS, ISAKMP_NEXT_NATOA_DRAFTS, payload_name_nat_d, NULL };
+enum_names payload_names =
+    { ISAKMP_NEXT_NONE, ISAKMP_NEXT_NATOA_RFC, payload_name, &payload_names_nat_d };
+#else
 enum_names payload_names =
     { ISAKMP_NEXT_NONE, ISAKMP_NEXT_VID, payload_name, NULL };
+#endif
 
 
 /* Exchange types (note: two discontinuous ranges) */
@@ -317,24 +338,11 @@ static const char *const esp_transform_name[] = {
 	"ESP_DES_IV32",
 	"ESP_RC4",
 	"ESP_NULL",
-	"ESP_AES"
-};
-
-/*
- * ipsec drafts suggest "high" ESP ids values for testing,
- * assign generic ESP_ID<num> if not officially defined 
- */
-static const char *const esp_transform_name_high[] = {
-	/* id=248 */	"ESP_ID248","ESP_MARS","ESP_RC6","ESP_ID251",
-	/* id=252 */	"ESP_SERPENT", "ESP_TWOFISH", "ESP_CAMELLIA", "ESP_ID255",
-	/* id=256 */	"ESP_ID256"
+	"ESP_AES",
     };
 
-enum_names esp_transformid_names_high =
-    { 248, 256, esp_transform_name_high, NULL };
-
 enum_names esp_transformid_names =
-    { ESP_DES_IV64, ESP_AES, esp_transform_name, &esp_transformid_names_high };
+    { ESP_DES_IV64, ESP_AES, esp_transform_name, NULL };
 
 /* IPCOMP transform values */
 
@@ -557,10 +565,28 @@ enum_names sa_lifetime_names =
 static const char *const enc_mode_name[] = {
 	"ENCAPSULATION_MODE_TUNNEL",
 	"ENCAPSULATION_MODE_TRANSPORT",
+#ifdef NAT_TRAVERSAL
+	"ENCAPSULATION_MODE_UDP_TUNNEL",
+	"ENCAPSULATION_MODE_UDP_TRANSPORT",
+#endif	
     };
 
+#ifdef NAT_TRAVERSAL
+static const char *const enc_udp_mode_name[] = {
+	"ENCAPSULATION_MODE_UDP_TUNNEL",
+	"ENCAPSULATION_MODE_UDP_TRANSPORT",
+    };
+#endif
+
+#ifdef NAT_TRAVERSAL
+static enum_names enc_udp_mode_names =
+    { ENCAPSULATION_MODE_UDP_TUNNEL_DRAFTS, ENCAPSULATION_MODE_UDP_TRANSPORT_DRAFTS, enc_udp_mode_name, NULL };
+enum_names enc_mode_names =
+    { ENCAPSULATION_MODE_TUNNEL, ENCAPSULATION_MODE_UDP_TRANSPORT_RFC, enc_mode_name, &enc_udp_mode_names };
+#else
 enum_names enc_mode_names =
     { ENCAPSULATION_MODE_TUNNEL, ENCAPSULATION_MODE_TRANSPORT, enc_mode_name, NULL };
+#endif
 
 /* Auth Algorithm attribute */
 
@@ -570,22 +596,11 @@ static const char *const auth_alg_name[] = {
 	"AUTH_ALGORITHM_HMAC_SHA1",
 	"AUTH_ALGORITHM_DES_MAC",
 	"AUTH_ALGORITHM_KPDK",
-	"AUTH_ALGORITHM_HMAC_SHA2_256",
-	"AUTH_ALGORITHM_HMAC_SHA2_384",
-	"AUTH_ALGORITHM_HMAC_SHA2_512",
-	"AUTH_ALGORITHM_HMAC_RIPEMD",
-	"AUTH_ALGORITHM_ID9",
-	"AUTH_ALGORITHM_ID10",
-	"AUTH_ALGORITHM_ID11",
-	"AUTH_ALGORITHM_ID12",
-	"AUTH_ALGORITHM_ID13",
-	"AUTH_ALGORITHM_ID14",
-	"AUTH_ALGORITHM_ID15",
     };
 
 enum_names
     auth_alg_names =
-	{ AUTH_ALGORITHM_HMAC_MD5, 15 /* AUTH_ALGORITHM_HMAC_RIPEMD */, auth_alg_name + 1, NULL },
+	{ AUTH_ALGORITHM_HMAC_MD5, AUTH_ALGORITHM_KPDK, auth_alg_name + 1, NULL },
     extended_auth_alg_names =
 	{ AUTH_ALGORITHM_NONE, AUTH_ALGORITHM_KPDK, auth_alg_name, NULL };
 
@@ -616,27 +631,8 @@ static const char *const oakley_enc_name[] = {
 	"OAKLEY_AES_CBC",
     };
 
-#ifdef NO_EXTRA_IKE
 enum_names oakley_enc_names =
     { OAKLEY_DES_CBC, OAKLEY_AES_CBC, oakley_enc_name, NULL };
-#else
-static const char *const oakley_enc_name_draft_aes_cbc_02[] = {
-	"OAKLEY_MARS_CBC"	/*	65001	*/,
-	"OAKLEY_RC6_CBC"     	/*	65002	*/,
-	"OAKLEY_ID_65003"	/*	65003	*/,
-	"OAKLEY_SERPENT_CBC"	/*	65004	*/,
-	"OAKLEY_TWOFISH_CBC"	/*	65005	*/,
-};
-static const char *const oakley_enc_name_ssh[] = {
-	"OAKLEY_SSH_PRIVATE_65289",
-};
-enum_names oakley_enc_names_ssh =
-    { 65289, 65289, oakley_enc_name_ssh, NULL };
-enum_names oakley_enc_names_draft_aes_cbc_02 =
-    { 65001, 65005, oakley_enc_name_draft_aes_cbc_02, &oakley_enc_names_ssh };
-enum_names oakley_enc_names =
-    { OAKLEY_DES_CBC, OAKLEY_AES_CBC, oakley_enc_name, &oakley_enc_names_draft_aes_cbc_02 };
-#endif
 
 /* Oakley Hash Algorithm attribute */
 
@@ -703,23 +699,11 @@ static const char *const oakley_group_name[] = {
 	"OAKLEY_GROUP_MODP1024",
 	"OAKLEY_GROUP_GP155",
 	"OAKLEY_GROUP_GP185",
-	"OAKLEY_GROUP_MODP1536",
+	"OAKLEY_GROUP_MODP1536 (extension)",
     };
 
-static const char *const oakley_group_name_rfc3526[] = {
-	"OAKLEY_GROUP_MODP2048",
-	"OAKLEY_GROUP_MODP3072",
-	"OAKLEY_GROUP_MODP4096",
-	"OAKLEY_GROUP_MODP6144",
-	"OAKLEY_GROUP_MODP8192"
-};
-enum_names oakley_group_names_rfc3526 =
-    { OAKLEY_GROUP_MODP2048, OAKLEY_GROUP_MODP8192,
-	    oakley_group_name_rfc3526, NULL };
-
 enum_names oakley_group_names =
-    { OAKLEY_GROUP_MODP768, OAKLEY_GROUP_MODP1536, 
-	    oakley_group_name, &oakley_group_names_rfc3526 };
+    { OAKLEY_GROUP_MODP768, OAKLEY_GROUP_MODP1536, oakley_group_name, NULL };
 
 /* Oakley Group Type attribute */
 
@@ -952,23 +936,6 @@ enum_show(enum_names *ed, unsigned long val)
 
 static char bitnamesbuf[200];   /* only one!  I hope that it is big enough! */
 
-int 
-enum_search(enum_names *ed, const char *str) 
-{
-    enum_names	*p;
-    const char *ptr;
-    unsigned en;
-
-    for (p = ed; p != NULL; p = p->en_next_range)
-	for (en=p->en_first;en<=p->en_last;en++) {
-	    ptr=p->en_names[en - p->en_first];
-	    if (ptr==0) continue;
-	    /* if (strncmp(ptr, str, strlen(ptr))==0) */
-	    if (strcmp(ptr, str)==0)
-		    return en;
-	}
-    return -1;
-}
 /* construct a string to name the bits on in a set
  * Result may be in STATIC buffer!
  * Note: prettypolicy depends on internal details.
@@ -995,7 +962,7 @@ bitnamesof(const char *const table[], lset_t val)
 		/* no name for this bit, so use hex */
 		static char flagbuf[sizeof("0x80000000")];
 
-		snprintf(flagbuf, sizeof(flagbuf), "0x%llx", bit);
+		snprintf(flagbuf, sizeof(flagbuf), "0x%lx", bit);
 		n = flagbuf;
 	    }
 
