@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: crypto.h,v 1.2 2003/09/15 12:57:38 jjo Exp $
+ * RCSID $Id: crypto.h,v 1.1.1.1 2003/10/31 17:56:54 ken Exp $
  */
 
 #include <gmp.h>    /* GNU MP library */
@@ -31,14 +31,6 @@ struct oakley_group_desc {
 extern const struct oakley_group_desc unset_group;	/* magic signifier */
 extern const struct oakley_group_desc *lookup_group(u_int16_t group);
 
-/*
- * unfortunately fixed, not easy to automate this without creating
- * high header coupling
- */
-#define OAKLEY_GROUP_SIZE 7
-
-extern const struct oakley_group_desc oakley_group[OAKLEY_GROUP_SIZE];
-
 /* unification of cryptographic encoding/decoding algorithms
  * The IV is taken from and returned to st->st_new_iv.
  * This allows the old IV to be retained.
@@ -46,29 +38,38 @@ extern const struct oakley_group_desc oakley_group[OAKLEY_GROUP_SIZE];
  * been validated).
  */
 
-#define MAX_OAKLEY_KEY_LEN0  (3 * DES_CBC_BLOCK_SIZE)
-#define MAX_OAKLEY_KEY_LEN  (256/BITS_PER_BYTE)
+#define MAX_OAKLEY_KEY_LEN  (3 * DES_CBC_BLOCK_SIZE)
 
 struct state;	/* forward declaration, dammit */
 
-struct encrypt_desc;
-struct hash_desc;
-struct encrypt_desc *crypto_get_encrypter(int alg);
-struct hash_desc *crypto_get_hasher(int alg);
-void crypto_cbc_encrypt(const struct encrypt_desc *e, bool enc, u_int8_t *buf, size_t size, struct state *st);
+struct encrypt_desc {
+    size_t blocksize;
+    size_t keysize;
+    void (*crypt)(bool enc, void *buf, size_t buf_len, struct state *st);
+};
+
+const struct encrypt_desc oakley_encrypter[OAKLEY_CAST_CBC + 1];
+
 #define update_iv(st)	memcpy((st)->st_iv, (st)->st_new_iv \
     , (st)->st_iv_len = (st)->st_new_iv_len)
 
 /* unification of cryptographic hashing mechanisms */
 
-#ifndef NO_HASH_CTX
 union hash_ctx {
 	MD5_CTX ctx_md5;
 	SHA1_CTX ctx_sha1;
-	char ctx_sha256[108];	/* This is _ugly_ [TM], but avoids */
-	char ctx_sha512[212];	/* header coupling (is checked at runtime */
     };
 
+struct hash_desc {
+    size_t hash_digest_len; /* length of digest */
+    void (*hash_init)(union hash_ctx *);	/* initialize context */
+    void (*hash_update)(union hash_ctx *, const u_char *input, unsigned int len);   /* add input to hash */
+    void (*hash_final)(u_char *output, union hash_ctx *);   /* finalize hash */
+};
+
+extern const struct hash_desc oakley_hasher[OAKLEY_TIGER+1];
+
+
 /* HMAC package
  * Note that hmac_ctx can be (and is) copied since there are
  * no persistent pointers into it.
@@ -76,7 +77,7 @@ union hash_ctx {
 
 struct hmac_ctx {
     const struct hash_desc *h;	/* underlying hash function */
-    size_t hmac_digest_size;	/* copy of h->hash_digest_size */
+    size_t hmac_digest_len;	/* copy of h->hash_digest_len */
     union hash_ctx hash_ctx;	/* ctx for hash function */
     u_char buf1[HMAC_BUFSIZE], buf2[HMAC_BUFSIZE];
     };
@@ -102,8 +103,7 @@ extern void hmac_final(u_char *output, struct hmac_ctx *ctx);
 
 #define hmac_final_chunk(ch, name, ctx) { \
 	pfreeany((ch).ptr); \
-	(ch).len = (ctx)->hmac_digest_size; \
+	(ch).len = (ctx)->hmac_digest_len; \
 	(ch).ptr = alloc_bytes((ch).len, name); \
 	hmac_final((ch).ptr, (ctx)); \
     }
-#endif
