@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: demux.c,v 1.3 2003/09/15 12:57:38 jjo Exp $
+ * RCSID $Id: demux.c,v 1.1.1.1 2003/10/31 17:56:56 ken Exp $
  */
 
 /* Ordering Constraints on Payloads
@@ -115,6 +115,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <sys/queue.h>
 
 #if defined(IP_RECVERR) && defined(MSG_ERRQUEUE)
 #  include <asm/types.h>	/* for __u8, __u32 */
@@ -138,13 +139,16 @@
 #include "md5.h"
 #include "sha1.h"
 #include "crypto.h" /* requires sha1.h and md5.h */
-#include "ike_alg.h"
 #include "log.h"
 #include "demux.h"	/* needs packet.h */
 #include "ipsec_doi.h"	/* needs demux.h and state.h */
 #include "timer.h"
 #include "whack.h"	/* requires connections.h */
 #include "server.h"
+#ifdef NAT_TRAVERSAL
+#include "nat_traversal.h"
+#endif
+#include "vendor.h"
 
 /* This file does basic header checking and demux of
  * incoming packets.
@@ -271,7 +275,11 @@ static const struct state_microcode state_microcode_table[] = {
      */
     { STATE_MAIN_R1, STATE_MAIN_R2
     , SMF_PSK_AUTH | SMF_DS_AUTH | SMF_REPLY
+#ifdef NAT_TRAVERSAL
+    , P(KE) | P(NONCE), P(VID) | P(CR) | P(NATD_RFC), PT(KE)
+#else
     , P(KE) | P(NONCE), P(VID) | P(CR), PT(KE)
+#endif    
     , EVENT_RETRANSMIT, main_inI2_outR2 },
 
     { STATE_MAIN_R1, STATE_UNDEFINED
@@ -296,7 +304,11 @@ static const struct state_microcode state_microcode_table[] = {
      */
     { STATE_MAIN_I2, STATE_MAIN_I3
     , SMF_PSK_AUTH | SMF_DS_AUTH | SMF_INITIATOR | SMF_OUTPUT_ENCRYPTED | SMF_REPLY
+#ifdef NAT_TRAVERSAL
+    , P(KE) | P(NONCE), P(VID) | P(CR) | P(NATD_RFC), PT(ID)
+#else
     , P(KE) | P(NONCE), P(VID) | P(CR), PT(ID)
+#endif    
     , EVENT_RETRANSMIT, main_inR2_outI3 },
 
     { STATE_MAIN_I2, STATE_UNDEFINED
@@ -387,7 +399,11 @@ static const struct state_microcode state_microcode_table[] = {
      */
     { STATE_QUICK_R0, STATE_QUICK_R1
     , SMF_ALL_AUTH | SMF_ENCRYPTED | SMF_REPLY
+#ifdef NAT_TRAVERSAL
+    , P(HASH) | P(SA) | P(NONCE), /* P(SA) | */ P(KE) | P(ID) | P(NATOA_RFC), PT(NONE)
+#else
     , P(HASH) | P(SA) | P(NONCE), /* P(SA) | */ P(KE) | P(ID), PT(NONE)
+#endif
     , EVENT_RETRANSMIT, quick_inI1_outR1 },
 
     /* STATE_QUICK_I1:
@@ -398,7 +414,11 @@ static const struct state_microcode state_microcode_table[] = {
      */
     { STATE_QUICK_I1, STATE_QUICK_I2
     , SMF_ALL_AUTH | SMF_INITIATOR | SMF_ENCRYPTED | SMF_REPLY
+#ifdef NAT_TRAVERSAL
+    , P(HASH) | P(SA) | P(NONCE), /* P(SA) | */ P(KE) | P(ID) | P(NATOA_RFC), PT(HASH)
+#else
     , P(HASH) | P(SA) | P(NONCE), /* P(SA) | */ P(KE) | P(ID), PT(HASH)
+#endif
     , EVENT_SA_REPLACE, quick_inR1_outI2 },
 
     /* STATE_QUICK_R1: HDR*, HASH(3) --> done
@@ -697,6 +717,18 @@ check_msg_errqueue(const struct iface *ifp, short interest)
 		    /* note dirty trick to suppress ~ at start of format
 		     * if we know what state to blame.
 		     */
+#ifdef NAT_TRAVERSAL
+		    if ((packet_len == 1) && (buffer[0] = 0xff)
+#ifdef DEBUG
+			&& ((cur_debugging & DBG_NATT) == 0)
+#endif
+			) {
+			    /* don't log NAT-T keepalive related errors unless NATT debug is
+			     * enabled
+			     */
+		    }
+		    else
+#endif		     
 		    plog((sender != NULL) + "~"
 			"ERROR: asynchronous network error report on %s"
 			"%s"
@@ -734,12 +766,40 @@ check_msg_errqueue(const struct iface *ifp, short interest)
 #endif /* defined(IP_RECVERR) && defined(MSG_ERRQUEUE) */
 
 bool
+#ifdef NAT_TRAVERSAL
+_send_packet(struct state *st, const char *where, bool verbose)
+#else
 send_packet(struct state *st, const char *where)
+#endif
 {
     struct connection *c = st->st_connection;
     int port_buf;
     bool err;
 
+#ifdef NAT_TRAVERSAL
+    u_int8_t ike_pkt[MAX_OUTPUT_UDP_SIZE];
+    u_int8_t *ptr;
+    unsigned long len;
+
+    if ((c->interface->ike_float == TRUE) && (st->st_tpacket.len != 1)) {
+	if ((unsigned long) st->st_tpacket.len >
+	    (MAX_OUTPUT_UDP_SIZE-sizeof(u_int32_t))) {
+	    DBG_log("send_packet(): really too big");
+	    return FALSE;
+	}
+	ptr = ike_pkt;
+	/** Add Non-ESP marker **/
+	memset(ike_pkt, 0, sizeof(u_int32_t));
+	memcpy(ike_pkt + sizeof(u_int32_t), st->st_tpacket.ptr,
+	    (unsigned long)st->st_tpacket.len);
+	len = (unsigned long) st->st_tpacket.len + sizeof(u_int32_t);
+    }
+    else {
+	ptr = st->st_tpacket.ptr;
+	len = (unsigned long) st->st_tpacket.len;
+    }
+#endif
+
     DBG(DBG_RAW,
 	{
 	    DBG_log("sending %lu bytes for %s through %s to %s:%u:"
@@ -763,16 +823,28 @@ send_packet(struct state *st, const char *where)
     (void) check_msg_errqueue(c->interface, POLLOUT);
 #endif /* defined(IP_RECVERR) && defined(MSG_ERRQUEUE) */
 
+#ifdef NAT_TRAVERSAL
     err = sendto(c->interface->fd
-    , st->st_tpacket.ptr, st->st_tpacket.len, 0
-    , sockaddrof(&c->spd.that.host_addr)
-    , sockaddrlenof(&c->spd.that.host_addr)) != (ssize_t)st->st_tpacket.len;
-    
+    	, ptr, len, 0
+    	, sockaddrof(&c->spd.that.host_addr)
+    	, sockaddrlenof(&c->spd.that.host_addr)) != (ssize_t)len;
+#else
+    err = sendto(c->interface->fd
+    	, st->st_tpacket.ptr, st->st_tpacket.len, 0
+    	, sockaddrof(&c->spd.that.host_addr)
+    	, sockaddrlenof(&c->spd.that.host_addr)) != (ssize_t)st->st_tpacket.len;
+#endif
+
     /* restore port */
     setportof(port_buf, &c->spd.that.host_addr);
 
     if (err)
     {
+#ifdef NAT_TRAVERSAL
+        /* do not log NAT-T Keep Alive packets */
+        if (!verbose)
+	    return FALSE; 
+#endif    	
 	log_errno((e, "sendto on %s to %s:%u failed in %s"
 	    , c->interface->rname
 	    , ip_str(&c->spd.that.host_addr)
@@ -917,6 +989,9 @@ read_packet(struct msg_digest *md)
     int packet_len;
     /* ??? this buffer seems *way* too big */
     u_int8_t bigbuffer[MAX_INPUT_UDP_SIZE];
+#ifdef NAT_TRAVERSAL
+    u_int8_t *_buffer = bigbuffer;
+#endif    
     union
     {
 	struct sockaddr sa;
@@ -1012,11 +1087,34 @@ read_packet(struct msg_digest *md)
     cur_from = &md->sender;
     cur_from_port = md->sender_port;
 
+#ifdef NAT_TRAVERSAL
+    if (ifp->ike_float == TRUE) {
+	u_int32_t non_esp;
+	if (packet_len < (int)sizeof(u_int32_t)) {
+	    plog("recvfrom %s:%u too small packet (%d)"
+		, ip_str(cur_from), (unsigned) cur_from_port, packet_len);
+	    return FALSE;
+	}
+	memcpy(&non_esp, _buffer, sizeof(u_int32_t));
+	if (non_esp != 0) {
+	    plog("recvfrom %s:%u has no Non-ESP marker"
+		, ip_str(cur_from), (unsigned) cur_from_port);
+	    return FALSE;
+	}
+	_buffer += sizeof(u_int32_t);
+	packet_len -= sizeof(u_int32_t);
+    }
+#endif
+
     /* Clone actual message contents
      * and set up md->packet_pbs to describe it.
      */
     init_pbs(&md->packet_pbs
+#ifdef NAT_TRAVERSAL
+	, clone_bytes(_buffer, packet_len, "message buffer in comm_handle()")
+#else
 	, clone_bytes(bigbuffer, packet_len, "message buffer in comm_handle()")
+#endif    
 	, packet_len, "packet");
 
     DBG(DBG_RAW | DBG_CRYPT | DBG_PARSING | DBG_CONTROL,
@@ -1031,6 +1129,22 @@ read_packet(struct msg_digest *md)
     DBG(DBG_RAW,
 	DBG_dump("", md->packet_pbs.start, pbs_room(&md->packet_pbs)));
 
+#ifdef NAT_TRAVERSAL
+	if ((pbs_room(&md->packet_pbs)==1) && (md->packet_pbs.start[0]==0xff)) {
+		/**
+		 * NAT-T Keep-alive packets should be discared by kernel ESPinUDP
+		 * layer. But boggus keep-alive packets (sent with a non-esp marker)
+		 * can reach this point. Complain and discard them.
+		 */
+		DBG(DBG_NATT,
+			DBG_log("NAT-T keep-alive (boggus ?) should not reach this point. "
+				"Ignored. Sender: %s:%u", ip_str(cur_from),
+				(unsigned) cur_from_port);
+			);
+		return FALSE;
+	}
+#endif
+
     return TRUE;
 }
 
@@ -1413,7 +1527,7 @@ process_packet(struct msg_digest **mdp)
 	{
 	    const struct encrypt_desc *e = st->st_oakley.encrypter;
 
-	    if (pbs_left(&md->message_pbs) % e->enc_blocksize != 0)
+	    if (pbs_left(&md->message_pbs) % e->blocksize != 0)
 	    {
 		loglog(RC_LOG_SERIOUS, "malformed message: not a multiple of encryption blocksize");
 		/* XXX Could send notification back */
@@ -1434,8 +1548,8 @@ process_packet(struct msg_digest **mdp)
 		st->st_new_iv_len = st->st_iv_len;
 		memcpy(st->st_new_iv, st->st_iv, st->st_new_iv_len);
 	    }
-	    crypto_cbc_encrypt(e, FALSE, md->message_pbs.cur, 
-			    pbs_left(&md->message_pbs) , st);
+	    e->crypt(FALSE, md->message_pbs.cur, pbs_left(&md->message_pbs)
+		, st);
 	}
 
 	DBG_cond_dump(DBG_CRYPT, "decrypted:\n", md->message_pbs.cur
@@ -1481,6 +1595,22 @@ process_packet(struct msg_digest **mdp)
 		return;
 	    }
 
+#ifdef NAT_TRAVERSAL
+	    switch (np)
+	    {
+		case ISAKMP_NEXT_NATD_RFC:
+		case ISAKMP_NEXT_NATOA_RFC:
+		    if ((!st) || (!(st->nat_traversal & NAT_T_WITH_RFC_VALUES))) {
+			/*
+			 * don't accept NAT-D/NAT-OA reloc directly in message, unless
+			 * we're using NAT-T RFC
+			 */
+			sd = NULL;
+		    }
+		    break;
+	    }
+#endif
+
 	    if (sd == NULL)
 	    {
 		/* payload type is out of range or requires special handling */
@@ -1490,6 +1620,16 @@ process_packet(struct msg_digest **mdp)
 		    sd = IS_PHASE1(from_state)
 			? &isakmp_identification_desc : &isakmp_ipsec_identification_desc;
 		    break;
+#ifdef NAT_TRAVERSAL
+		case ISAKMP_NEXT_NATD_DRAFTS:
+		    np = ISAKMP_NEXT_NATD_RFC;  /* NAT-D relocated */
+		    sd = payload_descs[np];
+		    break;
+		case ISAKMP_NEXT_NATOA_DRAFTS:
+		    np = ISAKMP_NEXT_NATOA_RFC;  /* NAT-OA relocated */
+		    sd = payload_descs[np];
+		    break;
+#endif		    
 		default:
 		    loglog(RC_LOG_SERIOUS, "%smessage ignored because it contains an unknown or"
 			" unexpected payload type (%s) at the outermost level"
@@ -1661,6 +1801,7 @@ process_packet(struct msg_digest **mdp)
 
 	for (p = md->chain[ISAKMP_NEXT_VID]; p != NULL; p = p->next)
 	{
+#if 0
 	    char vid_string[48];
 	    size_t vid_len = sizeof(vid_string) - 1 < pbs_left(&p->pbs)
 		? sizeof(vid_string) - 1 : pbs_left(&p->pbs);
@@ -1674,6 +1815,8 @@ process_packet(struct msg_digest **mdp)
 	    loglog(RC_LOG, "received Vendor ID Payload; ASCII hash: %s"
 		, vid_string);
 	    DBG_cond_dump(DBG_PARSING, "VID:", p->pbs.cur, pbs_left(&p->pbs));
+#endif
+	    handle_vendorid(md, p->pbs.cur, pbs_left(&p->pbs));
 	}
     }
     md->from_state = from_state;
@@ -1747,6 +1890,12 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 		clonetochunk(st->st_tpacket, md->reply.start
 		    , pbs_offset(&md->reply), "reply packet");
 
+#ifdef NAT_TRAVERSAL
+		if (nat_traversal_enabled) {
+		    nat_traversal_change_port_lookup(md, md->st);
+		}
+#endif
+
 		/* actually send the packet
 		 * Note: this is a great place to implement "impairments"
 		 * for testing purposes.  Suppress or duplicate the
@@ -1877,20 +2026,70 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 	    {
 		const char *story = state_story[st->st_state - STATE_MAIN_R0];
 		enum rc_type w = RC_NEW_STATE + st->st_state;
+		char sadetails[128];
+		
+		sadetails[0]='\0';
+
+		if(IS_IPSEC_SA_ESTABLISHED(st->st_state))
+		{
+		    char *b = sadetails;
+		    const char *ini = " {";
+		    const char *fin = "";
+
+		    /* -1 is to leave space for "fin" */
+
+		    if(st->st_esp.present)
+		    {
+			snprintf(b, sizeof(sadetails)-(b-sadetails)-1
+				 , "%sESP=>0x%08x <0x%08x"
+				 , ini
+				 , ntohl(st->st_esp.attrs.spi)
+				 , ntohl(st->st_esp.our_spi));
+			ini = " ";
+			fin = "}";
+		    }
+		    /* advance b to end of string */
+		    b = b + strlen(b);
+		    
+		    if(st->st_ah.present)
+		    {
+			snprintf(b, sizeof(sadetails)-(b-sadetails)-1
+				 , "%sAH=>0x%08x <0x%08x"
+				 , ini
+				 , ntohl(st->st_ah.attrs.spi)
+				 , ntohl(st->st_ah.our_spi));
+			ini = " ";
+			fin = "}";
+		    }
+		    /* advance b to end of string */
+		    b = b + strlen(b);
+		    
+		    if(st->st_ipcomp.present)
+		    {
+			snprintf(b, sizeof(sadetails)-(b-sadetails)-1
+				 , "%sIPCOMP=>0x%08x <0x%08x"
+				 , ini
+				 , ntohl(st->st_ipcomp.attrs.spi)
+				 , ntohl(st->st_ipcomp.our_spi));
+			ini = " ";
+			fin = "}";
+		    }
+		    strcat(b, fin);
+		}
 
 		if (IS_ISAKMP_SA_ESTABLISHED(st->st_state)
 		|| IS_IPSEC_SA_ESTABLISHED(st->st_state))
 		{
 		    /* log our success */
-		    plog("%s", story);
+		    plog("%s%s", story, sadetails);
 		    w = RC_SUCCESS;
 		}
 
 		/* tell whack our progress */
 		whack_log(w
-		    , "%s: %s"
+		    , "%s: %s%s"
 		    , enum_name(&state_names, st->st_state)
-		    , story);
+		    , story, sadetails);
 	    }
 
 	    if (smc->flags & SMF_RELEASE_PENDING_P2)
