@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: dnskey.c,v 1.2 2003/09/12 19:23:32 ken Exp $
+ * RCSID $Id: dnskey.c,v 1.1.1.1 2003/10/31 17:56:57 ken Exp $
  */
 
 #include <stdlib.h>
@@ -27,6 +27,7 @@
 #include <arpa/nameser.h>
 #include <resolv.h>
 #include <netdb.h>	/* ??? for h_errno */
+#include <sys/queue.h>
 
 #include <freeswan.h>
 #include <freeswan/ipsec_policy.h>
@@ -56,6 +57,9 @@ int adns_qfd = NULL_FD,	/* file descriptor for sending queries to adns (O_NONBLO
 static pid_t adns_pid = 0;
 const char *pluto_adns_option = NULL;	/* path from --pluto_adns */
 
+int adns_restart_count;
+#define ADNS_RESTART_MAX 20
+
 void
 init_adns(void)
 {
@@ -430,9 +434,16 @@ process_txt_rr_body(u_char *str
 
 		idtoa(client_id, cidb, sizeof(cidb));
 		idtoa(&gi.gw_id, gwidb, sizeof(gwidb));
-		/* should print key, but it is too long */
-		DBG_log("gateway for %s is %s"
-		    , cidb, gwidb);
+		if (gi.gw_key_present)
+		{
+		    DBG_log("gateway for %s is %s with key %s"
+			, cidb, gwidb, gi.key->u.rsa.keyid);
+		}
+		else
+		{
+		    DBG_log("gateway for %s is %s; no key specified"
+			, cidb, gwidb);
+		}
 	    });
 
 	gi.next = *gwip;
@@ -1420,6 +1431,14 @@ start_adns_query(const struct id *id	/* domain to query */
     const char *typename = rr_typename(type);
     char gwidb[IDTOA_BUF];
 
+    if(adns_pid == 0
+       && adns_restart_count < ADNS_RESTART_MAX)
+    {
+	plog("ADNS helper was not running. Restarting attempt %d",adns_restart_count);
+	init_adns();
+    }
+
+
     /* Splice this in at head of doubly-linked list of continuations.
      * Note: this must be done before any release_adns_continuation().
      */
@@ -1724,6 +1743,10 @@ process_lwdnsq_answer(char *ts)
     {
 	/* ignore */
     }
+    else if (strcaseeq(atype, "CNAMEFROM"))
+    {
+	/* ignore */
+    }
     else if (strcaseeq(atype, "PTR"))
     {
 	/* ignore */
@@ -1753,6 +1776,41 @@ process_lwdnsq_answer(char *ts)
 }
 #endif /* USE_LWRES */
 
+static void
+recover_adns_die(void)
+{
+    struct adns_continuation *cr = NULL;
+    
+    adns_pid = 0;
+    if(adns_restart_count < ADNS_RESTART_MAX) {
+	adns_restart_count++;
+
+	/* next DNS query will restart it */
+
+	/* we have to walk the list of the outstanding requests,
+	 * and redo them!
+	 */
+
+	cr = continuations;
+
+	/* find the head of the list */
+	if(continuations != NULL) {
+	    for (; cr->previous != NULL; cr = cr->previous);
+	}
+	    
+	next_query = cr;
+
+	if(next_query != NULL) {
+	    unsent_ADNS_queries = TRUE;
+	}
+    }
+}
+
+void reset_adns_restart_count(void)
+{
+    adns_restart_count=0;
+}
+
 void
 handle_adns_answer(void)
 {
@@ -1762,6 +1820,7 @@ handle_adns_answer(void)
     static struct adns_answer buf;
 #else /* USE_LWRES */
     static char buf[LWDNSQ_RESULT_LEN_MAX];
+    static char buf_copy[LWDNSQ_RESULT_LEN_MAX];
 #endif /* USE_LWRES */
 
     ssize_t n;
@@ -1783,16 +1842,20 @@ handle_adns_answer(void)
 	/* EOF */
 	if (adns_in_flight != 0)
 	{
-	    plog("EOF from adns with %d queries outstanding", adns_in_flight);
-	    /* ??? how can we recover? */
+	    plog("EOF from ADNS with %d queries outstanding (restarts %d)"
+		 , adns_in_flight, adns_restart_count);
+	    recover_adns_die();
 	}
 	if (buflen != 0)
 	{
-	    plog("EOF from adns with %lu bytes of a partial answer outstanding"
-		, (unsigned long)buflen);
-	    /* ??? how can we recover? */
+	    plog("EOF from ADNS with %lu bytes of a partial answer outstanding"
+		 "(restarts %d)"
+		 , (unsigned long)buflen
+		 ,  adns_restart_count);
+	    recover_adns_die();
 	}
 	stop_adns();
+	return;
     }
     else
     {
@@ -1881,10 +1944,14 @@ handle_adns_answer(void)
 	DBG(DBG_RAW | DBG_CRYPT | DBG_PARSING | DBG_CONTROL | DBG_DNS
 	    , DBG_log("lwdns: %s", buf));
 
-	ugh = process_lwdnsq_answer(buf);
-	if (ugh != NULL)
-	    plog("failure processing lwdnsq output: %s; record: %s", ugh, buf);
+	/* process lwdnsq_answer may modify buf, so make a copy. */
+	buf_copy[0]='\0';
+	strncat(buf_copy, buf, sizeof(buf_copy));
 
+	ugh = process_lwdnsq_answer(buf_copy);
+	if (ugh != NULL)
+	    plog("failure processing lwdnsq output: %s; record: %s"
+		 , ugh, buf);
 
 	passert(GLOBALS_ARE_RESET());
 	reset_globals();
