@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: id.c,v 1.3 2003/09/15 12:57:38 jjo Exp $
+ * RCSID $Id: id.c,v 1.1.1.1 2003/10/31 17:56:58 ken Exp $
  */
 
 #include <stdlib.h>
@@ -25,6 +25,7 @@
 #ifndef HOST_NAME_MAX	/* POSIX 1003.1-2001 says <unistd.h> defines this */
 # define HOST_NAME_MAX	255 /* upper bound, according to SUSv2 */
 #endif
+#include <sys/queue.h>
 
 #include <freeswan.h>
 #include <freeswan/ipsec_policy.h>
@@ -262,7 +263,7 @@ int
 keyidtoa(char *dst, size_t dstlen, chunk_t keyid)
 {
     int n = datatot(keyid.ptr, keyid.len, 'x', dst, dstlen);
-    return (((size_t)n < dstlen)? n : (int)dstlen) - 1;
+    return (((size_t)n < dstlen)? n : dstlen) - 1;
 }
 
 void
