@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_doi.h,v 1.1.1.1 2003/09/12 19:03:21 ken Exp $
+ * RCSID $Id: ipsec_doi.h,v 1.1.1.1 2003/10/31 17:56:59 ken Exp $
  */
 
 extern void echo_hdr(struct msg_digest *md, bool enc, u_int8_t np);
@@ -42,8 +42,8 @@ extern state_transition_fn
     quick_inI2;
 
 extern void send_delete(struct state *st);
-extern void accept_delete(struct state *st, struct msg_digest *md,
-     struct payload_digest *p);
+extern void accept_delete(struct state *st, struct msg_digest *md
+    , struct payload_digest *p);
 
 
 extern const char *init_pluto_vendorid(void);
