@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: keys.c,v 1.3 2003/10/02 19:46:30 ken Exp $
+ * RCSID $Id: keys.c,v 1.1.1.1 2003/10/31 17:57:02 ken Exp $
  */
 
 #include <stddef.h>
@@ -26,6 +26,7 @@
 #include <arpa/inet.h>
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
+#include <sys/queue.h>
 
 #include <glob.h>
 #ifndef GLOB_ABORTED
@@ -57,6 +58,11 @@
 /* Maximum length of filename and passphrase buffer */
 #define BUF_LEN		256
 
+#ifdef NAT_TRAVERSAL
+#define PB_STREAM_UNDEFINED
+#include "nat_traversal.h"
+#endif
+
 struct fld {
     const char *name;
     size_t offset;
@@ -335,6 +341,18 @@ get_secret(const struct connection *c, enum PrivateKeyKind kind, bool asym)
 	happy(anyaddr(addrtypeof(&c->spd.that.host_addr), &rw_id.ip_addr));
 	his_id = &rw_id;
     }
+#ifdef NAT_TRAVERSAL
+    else if ((nat_traversal_enabled) && (c->policy & POLICY_PSK) &&
+       (kind == PPK_PSK) && (
+	((c->kind == CK_TEMPLATE) && (c->spd.that.id.kind == ID_NONE)) ||
+	((c->kind == CK_INSTANCE) && (id_is_ipaddr(&c->spd.that.id)))))
+    {
+	    /* roadwarrior: replace him with 0.0.0.0 */
+	    rw_id.kind = ID_IPV4_ADDR;
+	    happy(anyaddr(addrtypeof(&c->spd.that.host_addr), &rw_id.ip_addr));
+	    his_id = &rw_id;
+    }
+#endif
 
     for (s = secrets; s != NULL; s = s->next)
     {
@@ -1122,6 +1140,7 @@ public_key_from_rsa(const struct RSA_public_key *k)
     p->issuer = empty_chunk;
     p->alg = PUBKEY_ALG_RSA;
 
+    memcpy(p->u.rsa.keyid, k->keyid, sizeof(p->u.rsa.keyid));
     p->u.rsa.k = k->k;
     mpz_init_set(&p->u.rsa.e, &k->e);
     mpz_init_set(&p->u.rsa.n, &k->n);
@@ -1343,13 +1362,10 @@ unreference_key(struct pubkey **pkp)
 
     passert(pk->refcnt != 0);
     pk->refcnt--;
-	
-    /* we are going to free the key as the refcount will hit zero */
     if (pk->refcnt == 0)
- 	free_public_key(pk);
+	free_public_key(pk);
 }
 
-
 err_t
 add_public_key(const struct id *id
 , enum dns_auth_level dns_auth_level
