@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: log.c,v 1.3 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: log.c,v 1.1.1.1 2003/10/31 17:57:02 ken Exp $
  */
 
 #include <stdio.h>
@@ -24,6 +24,10 @@
 #include <string.h>
 #include <unistd.h>
 #include <signal.h>	/* used only if MSG_NOSIGNAL not defined */
+#include <sys/queue.h>
+#include <libgen.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include <freeswan.h>
 
@@ -42,12 +46,17 @@
 #include "whack.h"	/* needs connections.h */
 #include "timer.h"
 
-bool
-    log_to_stderr = TRUE,	/* should log go to stderr? */
-    log_to_syslog = TRUE;	/* should log go to syslog? */
+/* close one per-peer log */
+static void perpeer_logclose(struct connection *c);	/* forward */
+
 
 bool
-   logged_txt_warning = FALSE;  /* should we complain about finding KEY? */
+    log_to_stderr = TRUE,	/* should log go to stderr? */
+    log_to_syslog = TRUE,	/* should log go to syslog? */
+    log_to_perpeer= FALSE;	/* should log go to per-IP file? */
+
+bool
+    logged_txt_warning = FALSE;  /* should we complain about finding KEY? */
 
 /* should we complain when we find no local id */
 bool
@@ -56,6 +65,13 @@ bool
     logged_myid_fqdn_key_warning = FALSE,
     logged_myid_ip_key_warning   = FALSE;
 
+/* may include trailing / */
+const char *base_perpeer_logdir = PERPEERLOGDIR;
+static int perpeer_count = 0;
+
+/* from sys/queue.h */
+static CIRCLEQ_HEAD(,connection) perpeer_list;
+
 
 /* Context for logging.
  *
@@ -76,6 +92,20 @@ init_log(void)
 	setbuf(stderr, NULL);
     if (log_to_syslog)
 	openlog("pluto", LOG_CONS | LOG_NDELAY | LOG_PID, LOG_AUTHPRIV);
+
+    CIRCLEQ_INIT(&perpeer_list);
+}
+
+void
+close_peerlog(void)
+{
+    /* exit if the circular queue has not been initialized */
+    if (perpeer_list.cqh_first == NULL)
+	return;
+
+    /* end of circular queue is given by pointer to "HEAD" */
+    while (perpeer_list.cqh_first != (void *)&perpeer_list)
+	perpeer_logclose(perpeer_list.cqh_first);
 }
 
 void
@@ -83,6 +113,8 @@ close_log(void)
 {
     if (log_to_syslog)
 	closelog();
+
+    close_peerlog();
 }
 
 /* Sanitize character string in situ: turns dangerous characters into \OOO.
@@ -196,6 +228,194 @@ fmt_log(char *buf, size_t buf_len, const char *fmt, va_list ap)
 	(void)sanitize(buf, buf_len);
 }
 
+static void
+perpeer_logclose(struct connection *c)
+{
+    /* only free/close things if we had used them! */
+    if (c->log_file != NULL)
+    {
+	passert(perpeer_count > 0);
+
+	CIRCLEQ_REMOVE(&perpeer_list, c, log_link);
+	perpeer_count--;
+	fclose(c->log_file);
+	c->log_file=NULL;
+    }
+}
+
+void
+perpeer_logfree(struct connection *c)
+{
+    perpeer_logclose(c);
+    if (c->log_file_name != NULL)
+    {
+	pfree(c->log_file_name);
+	c->log_file_name = NULL;
+	c->log_file_err = FALSE;
+    }
+}
+
+/* open the per-peer log */
+static void
+open_peerlog(struct connection *c)
+{
+    syslog(LOG_INFO, "opening log file for conn %s", c->name);
+
+    if (c->log_file_name == NULL)
+    {
+	char peername[ADDRTOT_BUF], dname[ADDRTOT_BUF];
+	int  peernamelen, lf_len;
+
+	addrtot(&c->spd.that.host_addr, 'Q', peername, sizeof(peername));
+	peernamelen = strlen(peername);
+
+	/* copy IP address, turning : and . into / */
+	{
+	    char c, *p, *q;
+
+	    p = peername;
+	    q = dname;
+	    do {
+		c = *p++;
+		if (c == '.' || c == ':')
+		    c = '/';
+		*q++ = c;
+	    } while (c != '\0');
+	}
+
+	lf_len = peernamelen * 2
+	    + strlen(base_perpeer_logdir)
+	    + sizeof("//.log")
+	    + 1;
+	c->log_file_name = alloc_bytes(lf_len, "per-peer log file name");
+
+	fprintf(stderr, "base dir |%s| dname |%s| peername |%s|"
+		, base_perpeer_logdir, dname, peername);
+	snprintf(c->log_file_name, lf_len, "%s/%s/%s.log"
+		 , base_perpeer_logdir, dname, peername);
+
+	syslog(LOG_DEBUG, "conn %s logfile is %s", c->name, c->log_file_name);
+    }
+
+    /* now open the file, creating directories if necessary */
+
+    {  /* create the directory */
+	char *dname;
+	int   bpl_len = strlen(base_perpeer_logdir);
+	char *slashloc;
+
+	dname = clone_str(c->log_file_name, "temp copy of file name");
+	dname = dirname(dname);
+
+	if (access(dname, W_OK) != 0)
+	{
+	    if (errno != ENOENT)
+	    {
+		if (c->log_file_err)
+		{
+		    syslog(LOG_CRIT, "can not write to %s: %s"
+			   , dname, strerror(errno));
+		    c->log_file_err = TRUE;
+		    pfree(dname);
+		    return;
+		}
+	    }
+
+	    /* directory does not exist, walk path creating dirs */
+	    /* start at base_perpeer_logdir */
+	    slashloc = dname + bpl_len;
+	    slashloc++;    /* since, by construction there is a slash
+			      right there */
+
+	    while (*slashloc != '\0')
+	    {
+		char saveslash;
+
+		/* look for next slash */
+		while (*slashloc != '\0' && *slashloc != '/') slashloc++;
+
+		saveslash = *slashloc;
+
+		*slashloc = '\0';
+
+		if (mkdir(dname, 0750) != 0 && errno != EEXIST)
+		{
+		    syslog(LOG_CRIT, "can not create dir %s: %s"
+			   , dname, strerror(errno));
+		    c->log_file_err = TRUE;
+		    pfree(dname);
+		    return;
+		}
+		syslog(LOG_DEBUG, "created new directory %s", dname);
+		*slashloc = saveslash;
+		slashloc++;
+	    }
+	}
+
+	pfree(dname);
+    }
+
+    c->log_file = fopen(c->log_file_name, "a");
+    if (c->log_file == NULL)
+    {
+	if (c->log_file_err)
+	{
+	    syslog(LOG_CRIT, "logging system can not open %s: %s"
+		   , c->log_file_name, strerror(errno));
+	    c->log_file_err = TRUE;
+	}
+	return;
+    }
+
+    /* look for a connection to close! */
+    while (perpeer_count >= MAX_PEERLOG_COUNT)
+    {
+	/* can not be NULL because perpeer_count > 0 */
+	passert(perpeer_list.cqh_last != (void *)&perpeer_list);
+
+	perpeer_logclose(perpeer_list.cqh_last);
+    }
+
+    /* insert this into the list */
+    CIRCLEQ_INSERT_HEAD(&perpeer_list, c, log_link);
+    passert(c->log_file != NULL);
+    perpeer_count++;
+}
+
+/* log a line to cur_connection's log */
+static void
+peerlog(const char *prefix, const char *m)
+{
+    if (cur_connection == NULL)
+    {
+	/* we can not log it in this case. Oh well. */
+	return;
+    }
+
+    if (cur_connection->log_file == NULL)
+    {
+	open_peerlog(cur_connection);
+    }
+
+    /* despite our attempts above, we may not be able to open the file. */
+    if (cur_connection->log_file != NULL)
+    {
+	char datebuf[32];
+	time_t n;
+	struct tm *t;
+
+	time(&n);
+	t = localtime(&n);
+
+	strftime(datebuf, sizeof(datebuf), "%Y-%m-%d %T", t);
+	fprintf(cur_connection->log_file, "%s %s%s\n", datebuf, prefix, m);
+
+	/* now move it to the front of the list */
+	CIRCLEQ_REMOVE(&perpeer_list, cur_connection, log_link);
+	CIRCLEQ_INSERT_HEAD(&perpeer_list, cur_connection, log_link);
+    }
+}
+
 void
 plog(const char *message, ...)
 {
@@ -210,6 +430,8 @@ plog(const char *message, ...)
 	fprintf(stderr, "%s\n", m);
     if (log_to_syslog)
 	syslog(LOG_WARNING, "%s", m);
+    if (log_to_perpeer)
+	peerlog("", m);
 
     whack_log(RC_LOG, "~%s", m);
 }
@@ -228,6 +450,8 @@ loglog(int mess_no, const char *message, ...)
 	fprintf(stderr, "%s\n", m);
     if (log_to_syslog)
 	syslog(LOG_WARNING, "%s", m);
+    if (log_to_perpeer)
+	peerlog("", m);
 
     whack_log(mess_no, "~%s", m);
 }
@@ -246,6 +470,10 @@ log_errno_routine(int e, const char *message, ...)
 	fprintf(stderr, "ERROR: %s. Errno %d: %s\n", m, e, strerror(e));
     if (log_to_syslog)
 	syslog(LOG_ERR, "ERROR: %s. Errno %d: %s", m, e, strerror(e));
+    if (log_to_perpeer)
+    {
+	peerlog(strerror(e), m);
+    }
 
     whack_log(RC_LOG_SERIOUS
 	, "~ERROR: %s. Errno %d: %s", m, e, strerror(e));
@@ -265,6 +493,8 @@ exit_log(const char *message, ...)
 	fprintf(stderr, "FATAL ERROR: %s\n", m);
     if (log_to_syslog)
 	syslog(LOG_ERR, "FATAL ERROR: %s", m);
+    if (log_to_perpeer)
+	peerlog("FATAL ERROR: ", m);
 
     whack_log(RC_LOG_SERIOUS, "~FATAL ERROR: %s", m);
 
@@ -285,6 +515,8 @@ exit_log_errno_routine(int e, const char *message, ...)
 	fprintf(stderr, "FATAL ERROR: %s. Errno %d: %s\n", m, e, strerror(e));
     if (log_to_syslog)
 	syslog(LOG_ERR, "FATAL ERROR: %s. Errno %d: %s", m, e, strerror(e));
+    if (log_to_perpeer)
+	peerlog(strerror(e), m);
 
     whack_log(RC_LOG_SERIOUS
 	, "~FATAL ERROR: %s. Errno %d: %s", m, e, strerror(e));
@@ -332,6 +564,8 @@ whack_log(int mess_no, const char *message, ...)
 		fprintf(stderr, "%s\n", m + prelen);
 	    if (log_to_syslog)
 		syslog(LOG_WARNING, "%s", m + prelen);
+	    if (log_to_perpeer)
+		peerlog("", m);
 	}
 #endif
 
@@ -416,6 +650,13 @@ passert_fail(const char *pred_str, const char *file_str, unsigned long line_no)
     abort();	/* exiting correctly doesn't always work */
 }
 
+void
+pexpect_log(const char *pred_str, const char *file_str, unsigned long line_no)
+{
+    /* we will get a possibly unplanned prefix.  Hope it works */
+    loglog(RC_LOG_SERIOUS, "EXPECTATION FAILED at %s:%lu: %s", file_str, line_no, pred_str);
+}
+
 lset_t
     base_debugging = DBG_NONE,	/* default to reporting nothing */
     cur_debugging =  DBG_NONE;
@@ -423,7 +664,13 @@ lset_t
 void
 extra_debugging(const struct connection *c)
 {
-    if (c->extra_debugging != 0)
+    if(c == NULL)
+    {
+	reset_debugging();
+	return;
+    }
+
+    if (c!= NULL && c->extra_debugging != 0)
     {
 	plog("enabling for connection: %s"
 	    , bitnamesof(debug_bit_names, c->extra_debugging & ~cur_debugging));
@@ -449,6 +696,8 @@ DBG_log(const char *message, ...)
 	fprintf(stderr, "| %s\n", m);
     if (log_to_syslog)
 	syslog(LOG_DEBUG, "| %s", m);
+    if (log_to_perpeer)
+	peerlog("| ", m);
 }
 
 /* dump raw bytes in hex to stderr (for lack of any better destination) */
@@ -524,18 +773,6 @@ show_status(void)
     show_ifaces_status();
     show_myid_status();
     show_debug_status();
-#ifndef NO_KERNEL_ALG
-    kernel_alg_show_status();
-    whack_log(RC_COMMENT, BLANK_FORMAT);    /* spacer */
-#endif
-#ifndef NO_IKE_ALG
-    ike_alg_show_status();
-    whack_log(RC_COMMENT, BLANK_FORMAT);    /* spacer */
-#endif
-#ifndef NO_DB_OPS_STATS
-    db_ops_show_status();
-    whack_log(RC_COMMENT, BLANK_FORMAT);    /* spacer */
-#endif
     whack_log(RC_COMMENT, BLANK_FORMAT);	/* spacer */
     show_connections_status();
     whack_log(RC_COMMENT, BLANK_FORMAT);	/* spacer */
