@@ -11,13 +11,17 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: log.h,v 1.1.1.1 2003/09/12 19:03:25 ken Exp $
+ * RCSID $Id: log.h,v 1.1.1.1 2003/10/31 17:57:03 ken Exp $
  */
 
 #include <freeswan.h>
 
 #define LOG_WIDTH   1024    /* roof of number of chars in log line */
 
+#ifndef PERPERRLOGDIR
+#define PERPERRLOGDIR "/var/log/pluto/peer"
+#endif
+
 /* our versions of assert: log result */
 
 #ifdef DEBUG
@@ -25,6 +29,9 @@
 extern void passert_fail(const char *pred_str
     , const char *file_str, unsigned long line_no) NEVER_RETURNS;
 
+extern void pexpect_log(const char *pred_str
+			, const char *file_str, unsigned long line_no);
+
 # define impossible() passert_fail("impossible", __FILE__, __LINE__)
 
 extern void switch_fail(int n
@@ -37,6 +44,11 @@ extern void switch_fail(int n
 	    passert_fail(#pred, __FILE__, __LINE__); \
     }
 
+# define pexpect(pred) { \
+	if (!(pred)) \
+	    pexpect_log(#pred, __FILE__, __LINE__); \
+    }
+
 /* assert that an err_t is NULL; evaluate exactly once */
 # define happy(x) { \
 	err_t ugh = x; \
@@ -56,7 +68,13 @@ extern void switch_fail(int n
 
 extern bool
     log_to_stderr,	/* should log go to stderr? */
-    log_to_syslog;	/* should log go to syslog? */
+    log_to_syslog,	/* should log go to syslog? */
+    log_to_perpeer;     /* should log go to per-IP file? */
+
+extern const char *base_perpeer_logdir;
+
+/* maximum number of files to keep open for per-peer log files */
+#define MAX_PEERLOG_COUNT 16
 
 /* Context for logging.
  *
@@ -133,6 +151,14 @@ extern void close_log(void);
 extern void plog(const char *message, ...) PRINTF_LIKE(1);
 extern void exit_log(const char *message, ...) PRINTF_LIKE(1) NEVER_RETURNS;
 
+/* close of all per-peer logging */
+extern void close_peerlog(void);
+
+/* free all per-peer log resources */
+extern void perpeer_logfree(struct connection *c);
+
+
+
 /* the following routines do a dance to capture errno before it is changed
  * A call must doubly parenthesize the argument list (no varargs macros).
  * The first argument must be "e", the local variable that captures errno.
