@@ -11,22 +11,31 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.c,v 1.2 2003/07/21 02:34:32 ken Exp $
+ * RCSID $Id: nat_traversal.c,v 1.16 2003/01/13 17:57:15 mathieu Exp $
  */
 
 #ifdef NAT_TRAVERSAL
 
+#include <stdio.h>
 #include <stdlib.h>
+#include <ctype.h>
+#include <stdarg.h>
+#include <syslog.h>
 #include <errno.h>
 #include <string.h>
+#include <unistd.h>
+#include <signal.h>     /* used only if MSG_NOSIGNAL not defined */
+#include <sys/queue.h>
 
 #include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 #include <pfkeyv2.h>
 #include <pfkey.h>
-
 #include "constants.h"
 #include "defs.h"
 #include "log.h"
+#include "server.h"
+#include "state.h"
 #include "id.h"
 #include "x509.h"
 #include "pgp.h"
@@ -35,21 +44,19 @@
 #include "connections.h"
 #include "packet.h"
 #include "demux.h"
+#include "kernel.h"
 #include "whack.h"
-#include "state.h"
-#include "server.h"
 #include "timer.h"
+
+
+#include "cookie.h"
 #include "sha1.h"
 #include "md5.h"
 #include "crypto.h"
 #include "vendor.h"
-#include "cookie.h"
-#include "kernel.h"
 
 #include "nat_traversal.h"
 
-#include "ike_alg.h"
-
 /* #define FORCE_NAT_TRAVERSAL */
 #define NAT_D_DEBUG
 #define NAT_T_SUPPORT_LAST_DRAFTS
@@ -76,7 +83,7 @@ static unsigned int _kap = 0;
 static unsigned int _ka_evt = 0;
 static bool _force_ka = 0;
 
-static const char *natt_version = "0.6";
+static const char *natt_version = "0.6b";
 
 static const char *natt_methods[] = {
 	"draft-ietf-ipsec-nat-t-ike-00/01",
@@ -225,7 +232,7 @@ void nat_traversal_natd_lookup(struct msg_digest *md)
 	 */
 	p = md->chain[ISAKMP_NEXT_NATD_RFC];
 	_natd_hash(st->st_oakley.hasher, hash, st->st_icookie, st->st_rcookie,
-		&(md->iface->addr), ntohs(st->st_connection->this.host_port));
+		&(md->iface->addr), ntohs(st->st_connection->spd.this.host_port));
 	if (!( (pbs_left(&p->pbs) == st->st_oakley.hasher->hash_digest_len) &&
 		(memcmp(p->pbs.cur, hash, st->st_oakley.hasher->hash_digest_len)==0)
 		)) {
@@ -316,7 +323,7 @@ bool nat_traversal_add_natd(u_int8_t np, pb_stream *outs,
 #ifdef FORCE_NAT_TRAVERSAL
 		0
 #else
-		ntohs(st->st_connection->this.host_port)
+		ntohs(st->st_connection->spd.this.host_port)
 #endif
 	);
 	return (out_generic_raw(np, &isakmp_nat_d, outs,
@@ -430,7 +437,7 @@ bool nat_traversal_add_natoa(u_int8_t np, pb_stream *outs,
 			__FILE__, __LINE__);
 		return FALSE;
 	}
-	ip = &(st->st_connection->this.host_addr);
+	ip = &(st->st_connection->spd.this.host_addr);
 
 	if (!out_modify_previous_np((st->nat_traversal & NAT_T_WITH_RFC_VALUES
 		? ISAKMP_NEXT_NATOA_RFC : ISAKMP_NEXT_NATOA_DRAFTS), outs)) {
@@ -542,8 +549,8 @@ static void nat_traversal_send_ka (struct state *st)
 
 	DBG(DBG_NATT,
 		DBG_log("ka_event: send NAT-KA to %s:%d",
-			ip_str(&st->st_connection->that.host_addr),
-			st->st_connection->that.host_port);
+			ip_str(&st->st_connection->spd.that.host_addr),
+			st->st_connection->spd.that.host_port);
 	);
 
 	/** save state chunk */
@@ -623,13 +630,13 @@ static void nat_traversal_find_new_mapp_state (struct state *st, void *data)
 	struct connection *c = st->st_connection;
 	struct _new_mapp_nfo *nfo = (struct _new_mapp_nfo *)data;
 
-	if ((c) && sameaddr(&c->that.host_addr, &(nfo->addr)) &&
-		(c->that.host_port == nfo->sport)) {
+	if ((c) && sameaddr(&c->spd.that.host_addr, &(nfo->addr)) &&
+		(c->spd.that.host_port == nfo->sport)) {
 
 		/**
 		 * Change host port
 		 */
-		c->that.host_port = nfo->dport;
+		c->spd.that.host_port = nfo->dport;
 
 		if (IS_IPSEC_SA_ESTABLISHED(st->st_state) ||
 			IS_ONLY_INBOUND_IPSEC_SA_ESTABLISHED(st->st_state)) {
@@ -638,7 +645,7 @@ static void nat_traversal_find_new_mapp_state (struct state *st, void *data)
 				 * If ipsec update failed, restore old port or we'll
 				 * not be able to update anymore.
 				 */
-				c->that.host_port = nfo->sport;
+				c->spd.that.host_port = nfo->sport;
 			}
 		}
 	}
@@ -690,22 +697,22 @@ void nat_traversal_change_port_lookup(struct msg_digest *md, struct state *st)
 		 * If source port has changed, update (including other states and
 		 * established kernel SA)
 		 */
-		if (c->that.host_port != md->sender_port) {
-			nat_traversal_new_mapping(&c->that.host_addr, c->that.host_port,
-				&c->that.host_addr, md->sender_port);
+		if (c->spd.that.host_port != md->sender_port) {
+			nat_traversal_new_mapping(&c->spd.that.host_addr, c->spd.that.host_port,
+				&c->spd.that.host_addr, md->sender_port);
 		}
 
 		/**
 		 * If interface type has changed, update local port (500/4500)
 		 */
-		if (((c->this.host_port == NAT_T_IKE_FLOAT_PORT) &&
+		if (((c->spd.this.host_port == NAT_T_IKE_FLOAT_PORT) &&
 			 (md->iface->ike_float == FALSE)) ||
-			((c->this.host_port != NAT_T_IKE_FLOAT_PORT) &&
+			((c->spd.this.host_port != NAT_T_IKE_FLOAT_PORT) &&
 			 (md->iface->ike_float == TRUE))) {
-			c->this.host_port = (md->iface->ike_float == TRUE)
+			c->spd.this.host_port = (md->iface->ike_float == TRUE)
 				? NAT_T_IKE_FLOAT_PORT : pluto_port;
 			DBG(DBG_NATT,
-				DBG_log("NAT-T: updating local port to %d", c->this.host_port);
+				DBG_log("NAT-T: updating local port to %d", c->spd.this.host_port);
 			);
 		}
 	}
@@ -717,12 +724,12 @@ void nat_traversal_change_port_lookup(struct msg_digest *md, struct state *st)
 	if (((st->st_state == STATE_MAIN_I3) || (st->st_state == STATE_QUICK_I1)) &&
 		(st->nat_traversal & NAT_T_WITH_PORT_FLOATING) &&
 		(st->nat_traversal & NAT_T_DETECTED) &&
-		(c->this.host_port != NAT_T_IKE_FLOAT_PORT)) {
+		(c->spd.this.host_port != NAT_T_IKE_FLOAT_PORT)) {
 		DBG(DBG_NATT,
 			DBG_log("NAT-T: floating to port %d", NAT_T_IKE_FLOAT_PORT);
 		);
-		c->this.host_port = NAT_T_IKE_FLOAT_PORT;
-		c->that.host_port = NAT_T_IKE_FLOAT_PORT;
+		c->spd.this.host_port = NAT_T_IKE_FLOAT_PORT;
+		c->spd.that.host_port = NAT_T_IKE_FLOAT_PORT;
 		/*
 		 * Also update pending connections or they will be deleted if uniqueids
 		 * option is set.
@@ -733,9 +740,9 @@ void nat_traversal_change_port_lookup(struct msg_digest *md, struct state *st)
 	/**
 	 * Find valid interface according to local port (500/4500)
 	 */
-	if (((c->this.host_port == NAT_T_IKE_FLOAT_PORT) &&
+	if (((c->spd.this.host_port == NAT_T_IKE_FLOAT_PORT) &&
 		 (c->interface->ike_float == FALSE)) ||
-		((c->this.host_port != NAT_T_IKE_FLOAT_PORT) &&
+		((c->spd.this.host_port != NAT_T_IKE_FLOAT_PORT) &&
 		 (c->interface->ike_float == TRUE))) {
 		for (i = interfaces; i !=  NULL; i = i->next) {
 			if ((sameaddr(&c->interface->addr, &i->addr)) &&
@@ -763,9 +770,9 @@ static void nat_t_new_klips_mapp (struct state *st, void *data)
 	struct _new_klips_mapp_nfo *nfo = (struct _new_klips_mapp_nfo *)data;
 
 	if ((c) && (st->st_esp.present) &&
-		sameaddr(&c->that.host_addr, &(nfo->src)) &&
+		sameaddr(&c->spd.that.host_addr, &(nfo->src)) &&
 		(st->st_esp.our_spi == nfo->sa->sadb_sa_spi)) {
-		nat_traversal_new_mapping(&c->that.host_addr, c->that.host_port,
+		nat_traversal_new_mapping(&c->spd.that.host_addr, c->spd.that.host_port,
 			&(nfo->dst), nfo->dport);
 	}
 }
