@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: packet.c,v 1.1.1.1 2003/09/12 19:03:26 ken Exp $
+ * RCSID $Id: packet.c,v 1.1.1.1 2003/10/31 17:57:04 ken Exp $
  */
 
 #include <stdio.h>
@@ -517,6 +517,42 @@ struct_desc isakmp_delete_desc = { "ISAKMP Delete Payload", isad_fields, sizeof(
  */
 struct_desc isakmp_vendor_id_desc = { "ISAKMP Vendor ID Payload", isag_fields, sizeof(struct isakmp_generic) };
 
+#ifdef NAT_TRAVERSAL
+/* ISAKMP NAT-Traversal NAT-D
+ * layout from draft-ietf-ipsec-nat-t-ike-01.txt section 3.2
+ *
+ *  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * ! Next Payload  !   RESERVED    !         Payload Length        !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * !                 HASH of the address and port                  !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ */
+struct_desc isakmp_nat_d = { "ISAKMP NAT-D Payload", isag_fields, sizeof(struct isakmp_generic) };
+
+/* ISAKMP NAT-Traversal NAT-OA
+ * layout from draft-ietf-ipsec-nat-t-ike-01.txt section 4.2
+ *
+ *  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * ! Next Payload  !   RESERVED    !         Payload Length        !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * !   ID Type     !   RESERVED    !            RESERVED           !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ * !         IPv4 (4 octets) or IPv6 address (16 octets)           !
+ * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ */
+static field_desc isanat_oa_fields[] = {
+    { ft_enum, 8/BITS_PER_BYTE, "next payload type", &payload_names },
+    { ft_mbz, 8/BITS_PER_BYTE, NULL, NULL },
+    { ft_len, 16/BITS_PER_BYTE, "length", NULL },
+    { ft_enum, 8/BITS_PER_BYTE, "ID type", &ident_names },
+    { ft_mbz, 24/BITS_PER_BYTE, NULL, NULL },
+    { ft_end, 0, NULL, NULL }
+};
+
+struct_desc isakmp_nat_oa = { "ISAKMP NAT-OA Payload", isanat_oa_fields, sizeof(struct isakmp_nat_oa) };
+#endif
 
 /* descriptor for each payload type
  *
@@ -541,6 +577,11 @@ struct_desc *const payload_descs[ISAKMP_NEXT_ROOF] = {
     &isakmp_notification_desc,		/* 11 ISAKMP_NEXT_N (Notification) */
     &isakmp_delete_desc,		/* 12 ISAKMP_NEXT_D (Delete) */
     &isakmp_vendor_id_desc,		/* 13 ISAKMP_NEXT_VID (Vendor ID) */
+#ifdef NAT_TRAVERSAL
+	NULL,
+	&isakmp_nat_d,              /* 15=130 ISAKMP_NEXT_NATD (NAT-D) */
+	&isakmp_nat_oa,             /* 16=131 ISAKMP_NEXT_NATOA (NAT-OA) */
+#endif
 };
 
 void
@@ -1085,6 +1126,38 @@ out_generic_raw(u_int8_t np, struct_desc *sd
     return TRUE;
 }
 
+#if 1
+bool
+out_modify_previous_np(u_int8_t np, pb_stream *outs)
+{
+	size_t len = (outs->cur - outs->start), offset;
+	if (len < sizeof(struct isakmp_hdr)) {
+		return FALSE;
+	}
+	else if (len == sizeof(struct isakmp_hdr)) {
+		struct isakmp_hdr *hdr = (struct isakmp_hdr *)outs->start;
+		hdr->isa_np = np;
+		return TRUE;
+	}
+	else {
+		struct isakmp_generic *hdr;
+		for (offset = sizeof(struct isakmp_hdr); offset < len ;
+			offset += ntohs(hdr->isag_length)) {
+			if ((len - offset) < sizeof(struct isakmp_generic))
+				return FALSE;
+			hdr = (struct isakmp_generic *)(outs->start+offset);
+			if ((len - offset) < ntohs(hdr->isag_length))
+				return FALSE;
+			if ((len - offset) == ntohs(hdr->isag_length)) {
+				hdr->isag_np = np;
+				return TRUE;
+			}
+		}
+	}
+	return FALSE;
+}
+#endif
+
 bool
 out_raw(const void *bytes, size_t len, pb_stream *outs, const char *name)
 {
