@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: packet.h,v 1.1.1.1 2003/09/12 19:03:26 ken Exp $
+ * RCSID $Id: packet.h,v 1.1.1.1 2003/10/31 17:57:04 ken Exp $
  */
 
 /* a struct_desc describes a structure for the struct I/O routines.
@@ -93,6 +93,9 @@ extern bool out_generic(u_int8_t np, struct_desc *sd,
     pb_stream *outs, pb_stream *obj_pbs);
 extern bool out_generic_raw(u_int8_t np, struct_desc *sd,
     pb_stream *outs, void *bytes, size_t len, const char *name);
+#if 1
+extern bool out_modify_previous_np(u_int8_t np, pb_stream *outs);
+#endif
 #define out_generic_chunk(np, sd, outs, ch, name) \
 	out_generic_raw(np, sd, outs, (ch).ptr, (ch).len, name)
 extern bool out_zero(size_t len, pb_stream *outs, const char *name);
@@ -580,6 +583,21 @@ extern struct_desc isakmp_delete_desc;
  */
 extern struct_desc isakmp_vendor_id_desc;
 
+#ifdef NAT_TRAVERSAL
+struct isakmp_nat_oa
+{
+    u_int8_t    isanoa_np;
+    u_int8_t    isanoa_reserved_1;
+    u_int16_t   isanoa_length;
+    u_int8_t    isanoa_idtype;
+    u_int8_t    isanoa_reserved_2;
+    u_int16_t   isanoa_reserved_3;
+};
+
+extern struct_desc isakmp_nat_d;
+extern struct_desc isakmp_nat_oa;
+#endif
+
 /* union of all payloads */
 
 union payload {
@@ -593,6 +611,9 @@ union payload {
     struct isakmp_ipsec_id ipsec_id;	/* Quick Mode */
     struct isakmp_notification notification;
     struct isakmp_delete delete;
+#ifdef NAT_TRAVERSAL
+    struct isakmp_nat_oa nat_oa;
+#endif
 };
 
 /* descriptor for each payload type
