@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: plutomain.c,v 1.2 2003/09/12 19:23:33 ken Exp $
+ * RCSID $Id: plutomain.c,v 1.1.1.1 2003/10/31 17:57:06 ken Exp $
  */
 
 #include <stdio.h>
@@ -28,6 +28,7 @@
 #include <getopt.h>
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
+#include <sys/queue.h>
 
 #include <freeswan.h>
 
@@ -45,7 +46,7 @@
 #include "connections.h"	/* needs id.h */
 #include "foodgroups.h"
 #include "packet.h"
-#include "demux.h"  /* needs packet.h */
+#include "demux.h"	/* needs packet.h */
 #include "server.h"
 #include "kernel.h"	/* needs connections.h */
 #include "log.h"
@@ -61,6 +62,14 @@
 #include "md5.h"
 #include "crypto.h"	/* requires sha1.h and md5.h */
 
+#ifdef VIRTUAL_IP
+#include "virtual.h"
+#endif
+
+#ifdef NAT_TRAVERSAL
+#include "nat_traversal.h"
+#endif
+
 static void
 usage(const char *mess)
 {
@@ -85,6 +94,8 @@ usage(const char *mess)
 	    " \\\n\t"
 	    "[--ctlbase <path>]"
 	    " \\\n\t"
+	    "[--perpeerlogbase <path>] [--perpeerlog]"
+	    " \\\n\t"
 	    "[--secretsfile <secrets-file>]"
 	    " [--policygroupsdir <policygroups-dir>]"
 	    " \\\n\t"
@@ -103,6 +114,17 @@ usage(const char *mess)
 	    " [--debug-klips]"
 	    " [--debug-dns]"
 	    " [ --debug-private]"
+#endif
+#ifdef NAT_TRAVERSAL
+	    " [ --debug-nat_t]"
+	    " \\\n\t"
+	    "[--nat_traversal] [--keep_alive <delay_sec>]"
+	    " \\\n\t"
+	        "[--force_keepalive] [--disable_port_floating]"
+#endif
+#ifdef VIRTUAL_IP
+	   " \\\n\t"
+	   "[--virtual_private <network_list>]"
 #endif
 	    "\n"
 	"FreeS/WAN %s\n"
@@ -184,6 +206,15 @@ main(int argc, char **argv)
     bool fork_desired = TRUE;
     bool log_to_stderr_desired = FALSE;
     int lockfd;
+#ifdef NAT_TRAVERSAL
+    bool nat_traversal = FALSE;
+    bool nat_t_spf = TRUE;  /* support port floating */
+    unsigned int keep_alive = 0;
+    bool force_keepalive = FALSE;
+#endif
+#ifdef VIRTUAL_IP
+    char *virtual_private = NULL;
+#endif
 
     /* handle arguments */
     for (;;)
@@ -206,12 +237,24 @@ main(int argc, char **argv)
 	    { "ctlbase", required_argument, NULL, 'b' },
 	    { "secretsfile", required_argument, NULL, 's' },
 	    { "foodgroupsdir", required_argument, NULL, 'f' },
+	    { "perpeerlogbase", required_argument, NULL, 'P' },
+	    { "perpeerlog", no_argument, NULL, 'l' },
 	    { "policygroupsdir", required_argument, NULL, 'f' },
 #ifdef USE_LWRES
 	    { "lwdnsq", required_argument, NULL, 'a' },
 #else /* !USE_LWRES */
 	    { "adns", required_argument, NULL, 'a' },
 #endif /* !USE_LWRES */
+#ifdef NAT_TRAVERSAL
+	    { "nat_traversal", no_argument, NULL, '1' },
+	    { "keep_alive", required_argument, NULL, '2' },
+	    { "force_keepalive", no_argument, NULL, '3' },
+	    { "disable_port_floating", no_argument, NULL, '4' },
+	    { "debug-nat_t", no_argument, NULL, '5' },
+#endif
+#ifdef VIRTUAL_IP
+	    { "virtual_private", required_argument, NULL, '6' },
+#endif
 #ifdef DEBUG
 	    { "debug-none", no_argument, NULL, 'N' },
 	    { "debug-all]", no_argument, NULL, 'A' },
@@ -372,6 +415,37 @@ main(int argc, char **argv)
 	    continue;
 #endif
 
+	case 'P':       /* --perpeerlogbase */
+	    base_perpeer_logdir = optarg;
+	    continue;
+
+	case 'l':
+	    log_to_perpeer = TRUE;
+	    continue;
+
+#ifdef NAT_TRAVERSAL
+	case '1':	/* --nat_traversal */
+	    nat_traversal = TRUE;
+	    continue;
+	case '2':	/* --keep_alive */
+	    keep_alive = atoi(optarg);
+	    continue;
+	case '3':	/* --force_keepalive */
+	    force_keepalive = TRUE;
+	    continue;
+	case '4':	/* --disable_port_floating */
+	    nat_t_spf = FALSE;
+	    continue;
+	case '5':	/* --debug-nat_t */
+	    base_debugging |= DBG_NATT;
+	    continue;
+#endif
+#ifdef VIRTUAL_IP
+	case '6':	/* --virtual_private */
+	    virtual_private = optarg;
+	    continue;
+#endif
+
 	default:
 #ifdef DEBUG
 	    if (c >= DBG_OFFSET)
@@ -520,6 +594,13 @@ main(int argc, char **argv)
 #endif
     }
 
+#ifdef NAT_TRAVERSAL
+    init_nat_traversal(nat_traversal, keep_alive, force_keepalive, nat_t_spf);
+#endif
+
+#ifdef VIRTUAL_IP
+    init_virtual_ip(virtual_private);
+#endif
     init_rnd_pool();
     init_secret();
     init_states();
