@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: rcv_whack.c,v 1.3 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: rcv_whack.c,v 1.1.1.1 2003/10/31 17:57:06 ken Exp $
  */
 
 #include <stdio.h>
@@ -28,6 +28,7 @@
 #include <arpa/inet.h>
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
+#include <sys/queue.h>
 
 #include <freeswan.h>
 
@@ -54,8 +55,6 @@
 #include "server.h"
 #include "fetch.h"
 
-#include "kernel_alg.h"
-#include "ike_alg.h"
 /* helper variables and function to decode strings from whack message */
 
 static char *next_str
@@ -310,14 +309,18 @@ whack_handle(int whackctlfd)
 	|| !unpack_str(&msg.left.cert)		/* string  3 */
 	|| !unpack_str(&msg.left.ca)		/* string  4 */
 	|| !unpack_str(&msg.left.updown)	/* string  5 */
+#ifdef VIRTUAL_IP
+	|| !unpack_str(&msg.left.virt)
+#endif
 	|| !unpack_str(&msg.right.id)		/* string  6 */
 	|| !unpack_str(&msg.right.cert)		/* string  7 */
 	|| !unpack_str(&msg.right.ca)		/* string  8 */
 	|| !unpack_str(&msg.right.updown)	/* string  9 */
+#ifdef VIRTUAL_IP
+	|| !unpack_str(&msg.right.virt)
+#endif
 	|| !unpack_str(&msg.keyid)		/* string 10 */
 	|| !unpack_str(&msg.myid)		/* string 11 */
-	|| !unpack_str(&msg.ike)		/* string 12 */
-	|| !unpack_str(&msg.esp)		/* string 13 */
 	|| str_roof - next_str != (ptrdiff_t)msg.keyval.len)	/* check chunk */
 	{
 	    ugh = "message from whack contains bad string";
@@ -392,15 +395,20 @@ whack_handle(int whackctlfd)
 	}
     }
 
+    if (msg.whack_crash)
+	delete_states_by_peer(&msg.whack_crash_peer);
+
     if (msg.whack_connection)
 	add_connection(&msg);
 
     /* process "listen" before any operation that could require it */
     if (msg.whack_listen)
     {
+	close_peerlog();    /* close any open per-peer logs */
 	plog("listening for IKE messages");
 	listening = TRUE;
 	daily_log_reset();
+	reset_adns_restart_count();
 	set_myFQDN();
 	find_ifaces();
 	load_preshared_secrets(NULL_FD);
