@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: server.c,v 1.2 2003/09/12 19:23:33 ken Exp $
+ * RCSID $Id: server.c,v 1.1.1.1 2003/10/31 17:57:07 ken Exp $
  */
 
 #include <stdio.h>
@@ -39,6 +39,7 @@
 #include <sys/ioctl.h>
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
+#include <sys/queue.h>
 
 #include <freeswan.h>
 
@@ -66,6 +67,11 @@
 
 #include <pfkeyv2.h>
 #include <pfkey.h>
+#include "kameipsec.h"
+
+#ifdef NAT_TRAVERSAL
+#include "nat_traversal.h"
+#endif
 
 /*
  *  Server main loop and socket initialization routines.
@@ -449,6 +455,86 @@ find_raw_ifaces6(void)
     return rifaces;
 }
 
+#if 1
+static int
+create_socket(struct raw_iface *ifp, const char *v_name, int port)
+{
+    int fd = socket(addrtypeof(&ifp->addr), SOCK_DGRAM, IPPROTO_UDP);
+    int fcntl_flags;
+
+    if (fd < 0)
+    {
+	log_errno((e, "socket() in process_raw_ifaces()"));
+	return -1;
+    }
+
+#if 1
+    /* Set socket Nonblocking */
+    if ((fcntl_flags=fcntl(fd, F_GETFL)) >= 0) {
+	if (!(fcntl_flags & O_NONBLOCK)) {
+	    fcntl_flags |= O_NONBLOCK;
+	    fcntl(fd, F_SETFL, fcntl_flags);
+	}
+    }
+#endif
+
+    if (fcntl(fd, F_SETFD, FD_CLOEXEC) == -1)
+    {
+	log_errno((e, "fcntl(,, FD_CLOEXEC) in process_raw_ifaces()"));
+	close(fd);
+	return -1;
+    }
+
+    if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR
+    , (const void *)&on, sizeof(on)) < 0)
+    {
+	log_errno((e, "setsockopt SO_REUSEADDR in process_raw_ifaces()"));
+	close(fd);
+	return -1;
+    }
+
+    /* To improve error reporting.  See ip(7). */
+#if defined(IP_RECVERR) && defined(MSG_ERRQUEUE)
+    if (setsockopt(fd, SOL_IP, IP_RECVERR
+    , (const void *)&on, sizeof(on)) < 0)
+    {
+	log_errno((e, "setsockopt IP_RECVERR in process_raw_ifaces()"));
+	close(fd);
+	return -1;
+    }
+#endif
+
+    /* With IPv6, there is no fragmentation after
+     * it leaves our interface.  PMTU discovery
+     * is mandatory but doesn't work well with IKE (why?).
+     * So we must set the IPV6_USE_MIN_MTU option.
+     * See draft-ietf-ipngwg-rfc2292bis-01.txt 11.1
+     */
+#ifdef IPV6_USE_MIN_MTU	/* YUCK: not always defined */
+    if (addrtypeof(&ifp->addr) == AF_INET6
+    && setsockopt(fd, SOL_SOCKET, IPV6_USE_MIN_MTU
+      , (const void *)&on, sizeof(on)) < 0)
+    {
+	log_errno((e, "setsockopt IPV6_USE_MIN_MTU in process_raw_ifaces()"));
+	close(fd);
+	return -1;
+    }
+#endif
+
+    setportof(htons(port), &ifp->addr);
+    if (bind(fd, sockaddrof(&ifp->addr), sockaddrlenof(&ifp->addr)) < 0)
+    {
+	log_errno((e, "bind() for %s/%s %s:%u in process_raw_ifaces()"
+	    , ifp->name, v_name
+	    , ip_str(&ifp->addr), (unsigned) port));
+	close(fd);
+	return -1;
+    }
+    setportof(htons(pluto_port), &ifp->addr);
+    return fd;
+}
+#endif
+
 static void
 process_raw_ifaces(struct raw_iface *rifaces)
 {
@@ -499,6 +585,17 @@ process_raw_ifaces(struct raw_iface *rifaces)
 		    /* ugh: a second real interface with the same IP address
 		     * "after" allows us to avoid double reporting.
 		     */
+#if defined(linux) && defined(KERNEL26_SUPPORT)
+		    if (!no_klips && kernel_ops->type == KERNEL_TYPE_LINUX)
+		    {
+			if (after)
+			{
+			    bad = TRUE;
+			    break;
+			}
+			continue;
+		    }
+#endif
 		    if (after)
 		    {
 			loglog(RC_LOG_SERIOUS
@@ -513,6 +610,14 @@ process_raw_ifaces(struct raw_iface *rifaces)
 	if (bad)
 	    continue;
 
+#if defined(linux) && defined(KERNEL26_SUPPORT)
+	if (!no_klips && kernel_ops->type == KERNEL_TYPE_LINUX)
+	{
+	    v = ifp;
+	    goto add_entry;
+	}
+#endif
+
 	/* what if we didn't find a virtual interface? */
 	if (v == NULL)
 	{
@@ -539,6 +644,9 @@ process_raw_ifaces(struct raw_iface *rifaces)
 	/* We've got all we need; see if this is a new thing:
 	 * search old interfaces list.
 	 */
+#if defined(linux) && defined(KERNEL26_SUPPORT)
+add_entry:
+#endif
 	{
 	    struct iface **p = &interfaces;
 
@@ -558,6 +666,11 @@ process_raw_ifaces(struct raw_iface *rifaces)
 			break;
 		    }
 
+#ifdef NAT_TRAVERSAL
+		    if (nat_traversal_enabled) {
+			nat_traversal_espinudp_socket(fd, ESPINUDP_WITH_NON_IKE);
+		    }
+#endif
 		    if (fcntl(fd, F_SETFD, FD_CLOEXEC) == -1)
 		    {
 			log_errno((e, "fcntl(,, FD_CLOEXEC) in process_raw_ifaces()"));
@@ -596,6 +709,50 @@ process_raw_ifaces(struct raw_iface *rifaces)
 			break;
 		    }
 #endif
+
+#if defined(linux) && defined(KERNEL26_SUPPORT)
+		    if (!no_klips && kernel_ops->type == KERNEL_TYPE_LINUX)
+		    {
+			struct sadb_x_policy policy;
+			int level, opt;
+
+			policy.sadb_x_policy_len = sizeof(policy) / IPSEC_PFKEYv2_ALIGN;
+			policy.sadb_x_policy_exttype = SADB_X_EXT_POLICY;
+			policy.sadb_x_policy_type = IPSEC_POLICY_BYPASS;
+			policy.sadb_x_policy_dir = IPSEC_DIR_INBOUND;
+			policy.sadb_x_policy_reserved = 0;
+			policy.sadb_x_policy_id = 0;
+			policy.sadb_x_policy_reserved2 = 0;
+
+			if (addrtypeof(&ifp->addr) == AF_INET6)
+			{
+			    level = IPPROTO_IPV6;
+			    opt = IPV6_IPSEC_POLICY;
+			}
+			else
+			{
+			    level = IPPROTO_IP;
+			    opt = IP_IPSEC_POLICY;
+			}
+
+			if (setsockopt(fd, level, opt
+			  , &policy, sizeof(policy)) < 0)
+			{
+			    log_errno((e, "setsockopt IPSEC_POLICY in process_raw_ifaces()"));
+			    break;
+			}
+
+			policy.sadb_x_policy_dir = IPSEC_DIR_OUTBOUND;
+
+			if (setsockopt(fd, level, opt
+			  , &policy, sizeof(policy)) < 0)
+			{
+			    log_errno((e, "setsockopt IPSEC_POLICY in process_raw_ifaces()"));
+			    break;
+			}
+		    }
+#endif
+
 		    setportof(htons(pluto_port), &ifp->addr);
 		    if (bind(fd, sockaddrof(&ifp->addr), sockaddrlenof(&ifp->addr)) < 0)
 		    {
@@ -615,6 +772,27 @@ process_raw_ifaces(struct raw_iface *rifaces)
 		    interfaces = q;
 		    plog("adding interface %s/%s %s"
 			, q->vname, q->rname, ip_str(&q->addr));
+#ifdef NAT_TRAVERSAL
+		    if (nat_traversal_support_port_floating) {
+			fd = create_socket(ifp, v->name, NAT_T_IKE_FLOAT_PORT);
+			if (fd < 0)
+			    break;
+			nat_traversal_espinudp_socket(fd,
+			    ESPINUDP_WITH_NON_ESP);
+			q = alloc_thing(struct iface, "struct iface");
+			q->rname = clone_str(ifp->name, "real device name");
+			q->vname = clone_str(v->name, "virtual device name");
+			q->addr = ifp->addr;
+			setportof(htons(NAT_T_IKE_FLOAT_PORT), &q->addr);
+			q->fd = fd;
+			q->next = interfaces;
+			q->change = IFN_ADD;
+			q->ike_float = TRUE;
+			interfaces = q;
+			plog("adding interface %s/%s %s:%d",
+			q->vname, q->rname, ip_str(&q->addr), NAT_T_IKE_FLOAT_PORT);
+		    }
+#endif
 		    break;
 		}
 
@@ -625,6 +803,16 @@ process_raw_ifaces(struct raw_iface *rifaces)
 		{
 		    /* matches -- rejuvinate old entry */
 		    q->change = IFN_KEEP;
+#ifdef NAT_TRAVERSAL
+		    /* look for other interfaces to keep (due to NAT-T) */
+		    for (q = q->next ; q ; q = q->next) {
+			if (streq(q->rname, ifp->name)
+			    && streq(q->vname, v->name)
+			    && sameaddr(&q->addr, &ifp->addr)) {
+				q->change = IFN_KEEP;
+			}
+		    }
+#endif
 		    break;
 		}
 
@@ -770,11 +958,14 @@ call_server(void)
 #ifdef KLIPS
 	    if (!no_klips)
 	    {
-		pfkey_dequeue();
-		if (maxfd < pfkeyfd)
-		    maxfd = pfkeyfd;
-		passert(!FD_ISSET(pfkeyfd, &readfds));
-		FD_SET(pfkeyfd, &readfds);
+		int fd = *kernel_ops->async_fdp;
+
+		if (kernel_ops->process_queue)
+		    kernel_ops->process_queue();
+		if (maxfd < fd)
+		    maxfd = fd;
+		passert(!FD_ISSET(fd, &readfds));
+		FD_SET(fd, &readfds);
 	    }
 #endif
 
@@ -859,13 +1050,13 @@ call_server(void)
 	    }
 
 #ifdef KLIPS
-	    if (!no_klips && FD_ISSET(pfkeyfd, &readfds))
+	    if (!no_klips && FD_ISSET(*kernel_ops->async_fdp, &readfds))
 	    {
 		passert(ndes > 0);
 		DBG(DBG_CONTROL,
 		    DBG_log(BLANK_FORMAT);
-		    DBG_log("*received pfkey message"));
-		pfkey_event();
+		    DBG_log("*received kernel message"));
+		kernel_ops->process_msg();
 		passert(GLOBALS_ARE_RESET());
 		ndes--;
 	    }
