@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: server.h,v 1.1.1.1 2003/09/12 19:03:29 ken Exp $
+ * RCSID $Id: server.h,v 1.1.1.1 2003/10/31 17:57:07 ken Exp $
  */
 
 extern int ctl_fd;	/* file descriptor of control (whack) socket */
@@ -40,6 +40,9 @@ struct iface {
     ip_address addr;	/* interface IP address */
     int fd;	/* file descriptor of socket for IKE UDP messages */
     struct iface *next;
+#ifdef NAT_TRAVERSAL
+    bool ike_float;
+#endif
     enum { IFN_ADD, IFN_KEEP, IFN_DELETE } change;
 };
 
