@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb.c,v 1.3 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: spdb.c,v 1.1.1.1 2003/10/31 17:57:08 ken Exp $
  */
 
 #include <stdio.h>
@@ -20,6 +20,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <sys/queue.h>
 
 #include <freeswan.h>
 #include <freeswan/ipsec_policy.h>
@@ -44,13 +45,13 @@
 #include "md5.h"
 #include "crypto.h" /* requires sha1.h and md5.h */
 
-#include "alg_info.h"
-#include "kernel_alg.h"
-#include "ike_alg.h"
-#include "db_ops.h"
 #define AD(x) x, elemsof(x)	/* Array Description */
 #define AD_NULL NULL, 0
 
+#ifdef NAT_TRAVERSAL
+#include "nat_traversal.h"
+#endif
+
 /**************** Oakely (main mode) SA database ****************/
 
 /* arrays of attributes for transforms, preshared key */
@@ -378,7 +379,7 @@ out_attr(int type
 		, val, enum_show(d, val)));
     return TRUE;
 }
-#define return_on(var, val) do { var=val;goto return_out; } while(0);
+
 /* Output an SA, as described by a db_sa.
  * This has the side-effect of allocating SPIs for us.
  */
@@ -391,13 +392,9 @@ out_sa(pb_stream *outs
 {
     pb_stream sa_pbs;
     int pcn;
-    bool ret = FALSE;
     bool ah_spi_generated = FALSE
 	, esp_spi_generated = FALSE
 	, ipcomp_cpi_generated = FALSE;
-#if !defined NO_KERNEL_ALG || !defined NO_IKE_ALG
-    struct db_context *db_ctx = NULL;
-#endif
 
     /* SA header out */
     {
@@ -406,13 +403,13 @@ out_sa(pb_stream *outs
 	sa.isasa_np = np;
 	st->st_doi = sa.isasa_doi = ISAKMP_DOI_IPSEC;	/* all we know */
 	if (!out_struct(&sa, &isakmp_sa_desc, outs, &sa_pbs))
-	    return_on(ret, FALSE);
+	    return FALSE;
     }
 
     /* within SA: situation out */
     st->st_situation = SIT_IDENTITY_ONLY;
     if (!out_struct(&st->st_situation, &ipsec_sit_desc, &sa_pbs, NULL))
-	return_on(ret, FALSE);
+	return FALSE;
 
     /* within SA: Proposal Payloads
      *
@@ -438,6 +435,10 @@ out_sa(pb_stream *outs
 	    struct_desc *attr_desc;
 	    enum_names **attr_val_descs;
 	    int tn;
+	    bool tunnel_mode;
+
+	    tunnel_mode = (pn == pc->prop_cnt-1)
+		&& (st->st_policy & POLICY_TUNNEL);
 
 	    /* Proposal header */
 	    proposal.isap_np = pcn == sadb->prop_conj_cnt-1 && pn == pc->prop_cnt-1
@@ -447,58 +448,9 @@ out_sa(pb_stream *outs
 	    proposal.isap_spisize = oakley_mode ? 0
 		: p->protoid == PROTO_IPCOMP ? IPCOMP_CPI_SIZE
 		: IPSEC_DOI_SPI_SIZE;
-#ifndef NO_KERNEL_ALG
-	    /*	
-	     *	In quick mode ONLY, create proposal for
-	     *	runtime kernel algos
-	     *
-	     *  replace ESP proposals
-	     *  with runtime created one
-	     */
-	    if (!oakley_mode && p->protoid==PROTO_IPSEC_ESP) {
-		    DBG(DBG_CONTROL | DBG_CRYPT, 
-			if (st->st_connection->alg_info_esp) {
-			    static char buf[256]="";
-			    alg_info_snprint(buf, sizeof (buf), 
-				    (struct alg_info *)st->st_connection->alg_info_esp);
-			    DBG_log(buf);
-			 }
-		    );
-		    db_ctx=kernel_alg_db_new(st->st_connection->alg_info_esp, st->st_policy);
-		    p = db_prop_get(db_ctx);
-
-		    if (!p || p->trans_cnt==0) {
-			loglog(RC_LOG_SERIOUS, 
-				"empty IPSEC SA proposal to send "
-				"(no kernel algorithms for esp selection)");
-			return_on(ret, FALSE);
-		    }
-	    }
-#endif
-#ifndef NO_IKE_ALG
-	    if (oakley_mode && p->protoid==PROTO_ISAKMP) {
-		    DBG(DBG_CONTROL | DBG_CRYPT, 
-			if (st->st_connection->alg_info_ike) {
-			    static char buf[256]="";
-			    alg_info_snprint(buf, sizeof (buf), 
-				    (struct alg_info *)st->st_connection->alg_info_ike);
-			    DBG_log(buf);
-			 }
-		    );
-		    db_ctx=ike_alg_db_new(st->st_connection->alg_info_ike,
-				st->st_policy);
-		    p = db_prop_get(db_ctx);
-		    if (!p || p->trans_cnt==0) {
-			loglog(RC_LOG_SERIOUS, 
-					"empty ISAKMP SA proposal to send "
-					"(no algorithms for ike selection?)");
-			return_on(ret, FALSE);
-		    }
-	    }
-#endif
 	    proposal.isap_notrans = p->trans_cnt;
 	    if (!out_struct(&proposal, &isakmp_proposal_desc, &sa_pbs, &proposal_pbs))
-		return_on(ret, FALSE);
+		return FALSE;
 
 	    /* Per-protocols stuff:
 	     * Set trans_desc.
@@ -516,6 +468,7 @@ out_sa(pb_stream *outs
 	     */
 	    {
 		ipsec_spi_t *spi_ptr = NULL;
+		int proto = 0;
 		bool *spi_generated;
 
 		switch (p->protoid)
@@ -534,6 +487,7 @@ out_sa(pb_stream *outs
 		    attr_val_descs = ipsec_attr_val_descs;
 		    spi_ptr = &st->st_ah.our_spi;
 		    spi_generated = &ah_spi_generated;
+		    proto = IPPROTO_AH;
 		    break;
 		case PROTO_IPSEC_ESP:
 		    passert(!oakley_mode);
@@ -542,6 +496,7 @@ out_sa(pb_stream *outs
 		    attr_val_descs = ipsec_attr_val_descs;
 		    spi_ptr = &st->st_esp.our_spi;
 		    spi_generated = &esp_spi_generated;
+		    proto = IPPROTO_ESP;
 		    break;
 		case PROTO_IPCOMP:
 		    passert(!oakley_mode);
@@ -554,9 +509,10 @@ out_sa(pb_stream *outs
 		     */
 		    if (!ipcomp_cpi_generated)
 		    {
-			st->st_ipcomp.our_spi = get_my_cpi();
+			st->st_ipcomp.our_spi = get_my_cpi(
+			    &st->st_connection->spd, tunnel_mode);
 			if (st->st_ipcomp.our_spi == 0)
-			    return_on(ret, FALSE);	/* problem generating CPI */
+			    return FALSE;	/* problem generating CPI */
 
 			ipcomp_cpi_generated = TRUE;
 		    }
@@ -567,7 +523,7 @@ out_sa(pb_stream *outs
 		     + IPSEC_DOI_SPI_SIZE - IPCOMP_CPI_SIZE
 		    , IPCOMP_CPI_SIZE
 		    , &proposal_pbs, "CPI"))
-			return_on(ret, FALSE);
+			return FALSE;
 		    break;
 		default:
 		    bad_case(p->protoid);
@@ -576,12 +532,17 @@ out_sa(pb_stream *outs
 		{
 		    if (!*spi_generated)
 		    {
-			*spi_ptr = get_ipsec_spi(0);
+			*spi_ptr = get_ipsec_spi(0
+			    , proto
+			    , &st->st_connection->spd
+			    , tunnel_mode);
+			if (*spi_ptr == 0)
+			    return FALSE;
 			*spi_generated = TRUE;
 		    }
 		    if (!out_raw((u_char *)spi_ptr, IPSEC_DOI_SPI_SIZE
 		    , &proposal_pbs, "SPI"))
-			return_on(ret, FALSE);
+			return FALSE;
 		}
 	    }
 
@@ -598,7 +559,7 @@ out_sa(pb_stream *outs
 		trans.isat_transnum = tn;
 		trans.isat_transid = t->transid;
 		if (!out_struct(&trans, trans_desc, &proposal_pbs, &trans_pbs))
-		    return_on(ret, FALSE);
+		    return FALSE;
 
 		/* Within tranform: Attributes. */
 
@@ -642,9 +603,35 @@ out_sa(pb_stream *outs
 		    if (p->protoid != PROTO_IPCOMP
 		    || st->st_policy & POLICY_TUNNEL)
 		    {
+#ifdef NAT_TRAVERSAL
+#ifndef I_KNOW_TRANSPORT_MODE_HAS_SECURITY_CONCERN_BUT_I_WANT_IT
+			if ((st->nat_traversal & NAT_T_DETECTED) &&
+				(!(st->st_policy & POLICY_TUNNEL))) {
+				/* Inform user that we will not respect policy and only
+				 * propose Tunnel Mode
+				 */
+				loglog(RC_LOG_SERIOUS, "NAT-Traversal: "
+					"Transport Mode not allowed due to security concerns -- "
+					"using Tunnel mode");
+			}
+#endif
+#endif
 			out_attr(ENCAPSULATION_MODE
+#ifdef NAT_TRAVERSAL
+#ifdef I_KNOW_TRANSPORT_MODE_HAS_SECURITY_CONCERN_BUT_I_WANT_IT
+			    , NAT_T_ENCAPSULATION_MODE(st,st->st_policy)
+#else
+				/* If NAT-T is detected, use UDP_TUNNEL as long as Transport
+				 * Mode has security concerns.
+				 *
+				 * User has been informed of that
+				 */
+			    , NAT_T_ENCAPSULATION_MODE(st,POLICY_TUNNEL)
+#endif
+#else /* ! NAT_TRAVERSAL */
 			    , st->st_policy & POLICY_TUNNEL
 			      ? ENCAPSULATION_MODE_TUNNEL : ENCAPSULATION_MODE_TRANSPORT
+#endif
 			    , attr_desc, attr_val_descs
 			    , &trans_pbs);
 		    }
@@ -674,15 +661,7 @@ out_sa(pb_stream *outs
 	/* end of a conjunction of proposals */
     }
     close_output_pbs(&sa_pbs);
-    ret = TRUE;
-
-return_out:
-
-#if !defined NO_KERNEL_ALG || !defined NO_IKE_ALG
-    if (db_ctx)
-	    db_destroy(db_ctx);
-#endif
-    return ret;
+    return TRUE;
 }
 
 /* Handle long form of duration attribute.
@@ -739,9 +718,6 @@ parse_isakmp_sa_body(
     bool selection,	/* if this SA is a selection, only one tranform can appear */
     struct state *st)	/* current state object */
 {
-#ifndef NO_IKE_ALG
-    struct connection *c = st->st_connection;
-#endif
     u_int32_t ipsecdoisit;
     pb_stream proposal_pbs;
     struct isakmp_proposal proposal;
@@ -928,14 +904,6 @@ parse_isakmp_sa_body(
 	    switch (a.isaat_af_type)
 	    {
 		case OAKLEY_ENCRYPTION_ALGORITHM | ISAKMP_ATTR_AF_TV:
-#ifndef NO_IKE_ALG
-		    if (ike_alg_enc_ok(val, 0, c->alg_info_ike, &ugh)) {
-		    /* if (ike_alg_enc_present(val)) { */
-			ta.encrypt = val;
-			ta.encrypter = crypto_get_encrypter(val);
-			ta.enckeylen = ta.encrypter->keydeflen;
-		    } else 
-#endif
 		    switch (val)
 		    {
 #if 0	/* we don't feel DES is safe */
@@ -943,7 +911,7 @@ parse_isakmp_sa_body(
 #endif
 		    case OAKLEY_3DES_CBC:
 			ta.encrypt = val;
-			ta.encrypter = crypto_get_encrypter(val);
+			ta.encrypter = &oakley_encrypter[val];
 			break;
 		    default:
 			ugh = builddiag("%s is not supported"
@@ -952,25 +920,17 @@ parse_isakmp_sa_body(
 		    break;
 
 		case OAKLEY_HASH_ALGORITHM | ISAKMP_ATTR_AF_TV:
-#ifndef NO_IKE_ALG
-		    if (ike_alg_hash_present(val)) {
-			ta.hash = val;
-			ta.hasher = crypto_get_hasher(val);
-		    } else 
-#endif
-/* #else */
 		    switch (val)
 		    {
 		    case OAKLEY_MD5:
 		    case OAKLEY_SHA:
 			ta.hash = val;
-			ta.hasher = crypto_get_hasher(val);
+			ta.hasher = &oakley_hasher[val];
 			break;
 		    default:
 			ugh = builddiag("%s is not supported"
 			    , enum_show(&oakley_hash_names, val));
 		    }
-/* #endif */
 		    break;
 
 		case OAKLEY_AUTHENTICATION_METHOD | ISAKMP_ATTR_AF_TV:
@@ -1038,7 +998,7 @@ parse_isakmp_sa_body(
 		    ta.group = lookup_group(val);
 		    if (ta.group == NULL)
 		    {
-			ugh = "only OAKLEY_GROUP_MODP1024,1536,2048,3072,4096,6144,8192 supported";
+			ugh = "only OAKLEY_GROUP_MODP1024 and OAKLEY_GROUP_MODP1536 supported";
 			break;
 		    }
 		    break;
@@ -1094,33 +1054,10 @@ parse_isakmp_sa_body(
 		    }
 		    break;
 
-#ifndef NO_IKE_ALG
-		case OAKLEY_KEY_LENGTH | ISAKMP_ATTR_AF_TV:
-		    if ((seen_attrs & LELEM(OAKLEY_ENCRYPTION_ALGORITHM)) == 0)
-		    {
-			ugh = "OAKLEY_KEY_LENGTH attribute not preceded by OAKLEY_ENCRYPTION_ALGORITHM attribute";
-			break;
-		    }
-		    if (ta.encrypter == NULL)
-		    {
-			ugh = "NULL encrypter with seen OAKLEY_ENCRYPTION_ALGORITHM";
-		        break;
-		    }
-		    /*
-		     * check if this keylen is compatible with 
-		     * specified alg_info_ike
-		     */
-		    if (!ike_alg_enc_ok(ta.encrypt, val, c->alg_info_ike, &ugh)) {
-			ugh = "peer proposed key_len not valid for encrypt algo setup specified";
-		    }
-		    ta.enckeylen=val;
-		    break;
-#else
-		case OAKLEY_KEY_LENGTH | ISAKMP_ATTR_AF_TV:
-#endif
 #if 0 /* not yet supported */
 		case OAKLEY_GROUP_TYPE | ISAKMP_ATTR_AF_TV:
 		case OAKLEY_PRF | ISAKMP_ATTR_AF_TV:
+		case OAKLEY_KEY_LENGTH | ISAKMP_ATTR_AF_TV:
 		case OAKLEY_FIELD_SIZE | ISAKMP_ATTR_AF_TV:
 
 		case OAKLEY_GROUP_PRIME | ISAKMP_ATTR_AF_TV:
@@ -1149,20 +1086,6 @@ parse_isakmp_sa_body(
 	    }
 	}
 
-#ifndef NO_IKE_ALG
-	/* 
-	 * ML: at last check for allowed transforms in alg_info_ike 
-	 *     (ALG_INFO_F_STRICT flag)
-	 */
-	if (ugh == NULL)
-	{
-		if (!ike_alg_ok_final(ta.encrypt, ta.enckeylen, ta.hash,
-			ta.group ? ta.group->group : -1, c->alg_info_ike)) {
-			ugh = "OAKLEY proposal refused";
-		}
-	}
-#endif
-
 	if (ugh == NULL)
 	{
 	    /* a little more checking is in order */
@@ -1444,13 +1367,95 @@ parse_ipsec_transform(struct isakmp_transform *trans
 		pfs_group = lookup_group(val);
 		if (pfs_group == NULL)
 		{
-		    loglog(RC_LOG_SERIOUS, "only OAKLEY_GROUP_MODP1024,1536,2048,3072,4096,6144,8192 supported for PFS");
+		    loglog(RC_LOG_SERIOUS, "only OAKLEY_GROUP_MODP1024 and OAKLEY_GROUP_MODP1536 supported for PFS");
 		    return FALSE;
 		}
 		break;
 	    case ENCAPSULATION_MODE | ISAKMP_ATTR_AF_TV:
 		ipcomp_inappropriate = FALSE;
+#ifdef NAT_TRAVERSAL
+		switch (val) {
+			case ENCAPSULATION_MODE_TUNNEL:
+			case ENCAPSULATION_MODE_TRANSPORT:
+				if (st->nat_traversal & NAT_T_DETECTED) {
+					loglog(RC_LOG_SERIOUS,
+						"%s must only be used if "
+						"NAT-Traversal is not detected",
+						enum_name(&enc_mode_names, val));
+					/*
+					 * Accept it anyway because SSH-Sentinel does not
+					 * use UDP_TUNNEL or UDP_TRANSPORT for the diagnostic.
+					 *
+					 * remove when SSH-Sentinel is fixed
+					 */
+#ifdef I_DONT_CARE_OF_SSH_SENTINEL
+					return FALSE;
+#endif
+				}
+				attrs->encapsulation = val;
+				break;
+			case ENCAPSULATION_MODE_UDP_TRANSPORT_DRAFTS:
+#ifndef I_KNOW_TRANSPORT_MODE_HAS_SECURITY_CONCERN_BUT_I_WANT_IT
+				loglog(RC_LOG_SERIOUS,
+					"NAT-Traversal: Transport mode disabled due "
+					"to security concerns");
+				return FALSE;
+				break;
+#endif
+			case ENCAPSULATION_MODE_UDP_TUNNEL_DRAFTS:
+				if (st->nat_traversal & NAT_T_WITH_RFC_VALUES) {
+					loglog(RC_LOG_SERIOUS,
+						"%s must only be used with old IETF drafts",
+						enum_name(&enc_mode_names, val));
+					return FALSE;
+				}
+				else if (st->nat_traversal & NAT_T_DETECTED) {
+					attrs->encapsulation = val - ENCAPSULATION_MODE_UDP_TUNNEL_DRAFTS + ENCAPSULATION_MODE_TUNNEL;
+				}
+				else {
+					loglog(RC_LOG_SERIOUS,
+						"%s must only be used if "
+						"NAT-Traversal is detected",
+						enum_name(&enc_mode_names, val));
+					return FALSE;
+				}
+				break;
+			case ENCAPSULATION_MODE_UDP_TRANSPORT_RFC:
+#ifndef I_KNOW_TRANSPORT_MODE_HAS_SECURITY_CONCERN_BUT_I_WANT_IT
+				loglog(RC_LOG_SERIOUS,
+					"NAT-Traversal: Transport mode disabled due "
+					"to security concerns");
+				return FALSE;
+				break;
+#endif
+			case ENCAPSULATION_MODE_UDP_TUNNEL_RFC:
+				if ((st->nat_traversal & NAT_T_DETECTED) &&
+					(st->nat_traversal & NAT_T_WITH_RFC_VALUES)) {
+					attrs->encapsulation = val - ENCAPSULATION_MODE_UDP_TUNNEL_RFC + ENCAPSULATION_MODE_TUNNEL;
+				}
+				else if (st->nat_traversal & NAT_T_DETECTED) {
+					loglog(RC_LOG_SERIOUS,
+						"%s must only be used with NAT-T RFC",
+						enum_name(&enc_mode_names, val));
+					return FALSE;
+				}
+				else {
+					loglog(RC_LOG_SERIOUS,
+						"%s must only be used if "
+						"NAT-Traversal is detected",
+						enum_name(&enc_mode_names, val));
+					return FALSE;
+				}
+				break;
+			default:
+				loglog(RC_LOG_SERIOUS,
+					"unknown ENCAPSULATION_MODE %d in IPSec SA", val);
+				return FALSE;
+				break;
+		}
+#else
 		attrs->encapsulation = val;
+#endif
 		break;
 	    case AUTH_ALGORITHM | ISAKMP_ATTR_AF_TV:
 		attrs->auth = val;
@@ -1543,7 +1548,9 @@ echo_proposal(
     pb_stream *r_sa_pbs,		/* SA PBS into which to emit */
     struct ipsec_proto_info *pi,	/* info about this protocol instance */
     struct_desc *trans_desc,		/* descriptor for this transformation */
-    pb_stream *trans_pbs)		/* PBS for incoming transform */
+    pb_stream *trans_pbs,		/* PBS for incoming transform */
+    struct spd_route *sr,		/* host details for the association */
+    bool tunnel_mode)			/* true for inner most tunnel SA */
 {
     pb_stream r_proposal_pbs;
     pb_stream r_trans_pbs;
@@ -1562,7 +1569,7 @@ echo_proposal(
 	 * Note: we may fail to generate a satisfactory CPI,
 	 * but we'll ignore that.
 	 */
-	pi->our_spi = get_my_cpi();
+	pi->our_spi = get_my_cpi(sr, tunnel_mode);
 	out_raw((u_char *) &pi->our_spi
 	     + IPSEC_DOI_SPI_SIZE - IPCOMP_CPI_SIZE
 	    , IPCOMP_CPI_SIZE
@@ -1570,7 +1577,12 @@ echo_proposal(
     }
     else
     {
-	pi->our_spi = get_ipsec_spi(pi->attrs.spi);
+	pi->our_spi = get_ipsec_spi(pi->attrs.spi
+	    , r_proposal.isap_protoid == PROTO_IPSEC_AH ?
+		IPPROTO_AH : IPPROTO_ESP
+	    , sr
+	    , tunnel_mode);
+	/* XXX should check for errors */
 	out_raw((u_char *) &pi->our_spi, IPSEC_DOI_SPI_SIZE
 	    , &r_proposal_pbs, "SPI");
     }
@@ -1651,6 +1663,8 @@ parse_ipsec_sa_body(
 	struct isakmp_proposal ah_proposal, esp_proposal, ipcomp_proposal;
 	ipsec_spi_t ah_spi, esp_spi, ipcomp_cpi;
 	bool ah_seen = FALSE, esp_seen = FALSE, ipcomp_seen = FALSE;
+	int inner_proto = 0;
+	bool tunnel_mode = FALSE;
 	u_int16_t well_known_cpi = 0;
 
 	pb_stream ah_trans_pbs, esp_trans_pbs, ipcomp_trans_pbs;
@@ -1906,6 +1920,9 @@ parse_ipsec_sa_body(
 	    if (tn == ah_proposal.isap_notrans)
 		continue;	/* we didn't find a nice one */
 	    ah_attrs.spi = ah_spi;
+	    inner_proto = IPPROTO_AH;
+	    if (ah_attrs.encapsulation == ENCAPSULATION_MODE_TUNNEL)
+		tunnel_mode = TRUE;
 	}
 
 	if (esp_seen)
@@ -1929,19 +1946,13 @@ parse_ipsec_sa_body(
 
 		previous_transnum = esp_trans.isat_transnum;
 
-#ifndef NO_KERNEL_ALG
-		if (!kernel_alg_esp_enc_ok(esp_attrs.transid, esp_attrs.key_len,
-			c->alg_info_esp))
-#endif
 		switch (esp_attrs.transid)
 		{
 #if 0	/* we don't feel single DES is safe */
 		    case ESP_DES:
 #endif
-#ifdef NO_KERNEL_ALG	/* strictly use runtime information */
 		    case ESP_3DES:
 			break;
-#endif
 
 #ifdef SUPPORT_ESP_NULL	/* should be about as secure as AH-only */
 		    case ESP_NULL:
@@ -1968,9 +1979,7 @@ parse_ipsec_sa_body(
 				, ip_str(&c->spd.that.host_addr)));
 			continue;   /* try another */
 		}
-#ifndef NO_KERNEL_ALG
-		if (!kernel_alg_esp_auth_ok(esp_attrs.auth, c->alg_info_esp))
-#endif
+
 		switch (esp_attrs.auth)
 		{
 		    case AUTH_ALGORITHM_NONE:
@@ -1982,11 +1991,9 @@ parse_ipsec_sa_body(
 			    continue;   /* try another */
 			}
 			break;
-#ifdef NO_KERNEL_ALG	/* strictly use runtime information */
 		    case AUTH_ALGORITHM_HMAC_MD5:
 		    case AUTH_ALGORITHM_HMAC_SHA1:
 			break;
-#endif
 		    default:
 			DBG(DBG_CONTROL | DBG_CRYPT
 			    , DBG_log("unsupported ESP auth alg %s from %s"
@@ -2006,17 +2013,10 @@ parse_ipsec_sa_body(
 	    }
 	    if (tn == esp_proposal.isap_notrans)
 		continue;	/* we didn't find a nice one */
-#ifndef NO_KERNEL_ALG
-	    /* 
-	     * ML: at last check for allowed transforms in alg_info_esp 
-	     *     (ALG_INFO_F_STRICT flag)
-	     *
-	     */
-	    if (!kernel_alg_esp_ok_final(esp_attrs.transid, esp_attrs.key_len,
-				    esp_attrs.auth, c->alg_info_esp))
-		    continue;
-#endif
 	    esp_attrs.spi = esp_spi;
+	    inner_proto = IPPROTO_ESP;
+	    if (esp_attrs.encapsulation == ENCAPSULATION_MODE_TUNNEL)
+		tunnel_mode = TRUE;
 	}
 	else if (st->st_policy & POLICY_ENCRYPT)
 	{
@@ -2115,6 +2115,9 @@ parse_ipsec_sa_body(
 	    if (tn == ipcomp_proposal.isap_notrans)
 		continue;	/* we didn't find a nice one */
 	    ipcomp_attrs.spi = ipcomp_cpi;
+	    inner_proto = IPPROTO_COMP;
+	    if (ipcomp_attrs.encapsulation == ENCAPSULATION_MODE_TUNNEL)
+		tunnel_mode = TRUE;
 	}
 
 	/* Eureka: we liked what we saw -- accept it. */
@@ -2135,7 +2138,9 @@ parse_ipsec_sa_body(
 		    , r_sa_pbs
 		    , &st->st_ah
 		    , &isakmp_ah_transform_desc
-		    , &ah_trans_pbs);
+		    , &ah_trans_pbs
+		    , &st->st_connection->spd
+		    , tunnel_mode && inner_proto == IPPROTO_AH);
 
 	    /* ESP proposal */
 	    if (esp_seen)
@@ -2145,7 +2150,9 @@ parse_ipsec_sa_body(
 		    , r_sa_pbs
 		    , &st->st_esp
 		    , &isakmp_esp_transform_desc
-		    , &esp_trans_pbs);
+		    , &esp_trans_pbs
+		    , &st->st_connection->spd
+		    , tunnel_mode && inner_proto == IPPROTO_ESP);
 
 	    /* IPCOMP proposal */
 	    if (ipcomp_seen)
@@ -2155,7 +2162,9 @@ parse_ipsec_sa_body(
 		    , r_sa_pbs
 		    , &st->st_ipcomp
 		    , &isakmp_ipcomp_transform_desc
-		    , &ipcomp_trans_pbs);
+		    , &ipcomp_trans_pbs
+		    , &st->st_connection->spd
+		    , tunnel_mode && inner_proto == IPPROTO_COMP);
 
 	    close_output_pbs(r_sa_pbs);
 	}
