@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: state.c,v 1.2 2003/09/12 19:23:33 ken Exp $
+ * RCSID $Id: state.c,v 1.1.1.1 2003/10/31 17:57:08 ken Exp $
  */
 
 #include <stdio.h>
@@ -24,6 +24,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <fcntl.h>
+#include <sys/queue.h>
 
 #include <freeswan.h>
 
@@ -283,9 +284,6 @@ release_whack(struct state *st)
 }
 
 /* delete a state object */
-/*
- * XXX-mcr this will need attention in the co-terminal case
- */
 void
 delete_state(struct state *st)
 {
@@ -379,8 +377,6 @@ delete_state(struct state *st)
 
 /*
  * Is a connection in use by some state?
- *
- * XXX-mcr co-terminal will have to look at this.
  */
 bool
 states_use_connection(struct connection *c)
@@ -471,6 +467,62 @@ delete_states_by_connection(struct connection *c)
     }
 }
 
+/*
+ * walk through the state table, and delete each state whose phase 1 (IKE)
+ * peer is among those given.
+ */
+void
+delete_states_by_peer(ip_address *peer)
+{
+    char peerstr[ADDRTOT_BUF];
+    int i;
+
+    /* We take two passes so that we delete any ISAKMP SAs last.
+     * This allows Delete Notifications to be sent.
+     * ?? We could probably double the performance by caching any
+     * ISAKMP SA states found in the first pass, avoiding a second.
+     */
+
+    addrtot(peer, 0, peerstr, sizeof(peerstr));
+
+    /* For each hash chain... */
+    for (i = 0; i < STATE_TABLE_SIZE; i++)
+    {
+	struct state *st;
+
+	/* For each state in the hash chain... */
+	for (st = statetable[i]; st != NULL; )
+	{
+	    struct state *this = st;
+	    struct spd_route *sr;
+	    struct connection *thisc = this->st_connection;
+	    
+	    st = st->st_hashchain_next;	/* before this is deleted */
+
+	    for(sr = &thisc->spd;
+		sr != NULL;
+		sr = sr->next)
+	    {
+		if(sameaddr(&sr->that.host_addr, peer))
+		{
+		    break;
+		}
+	    }
+
+	    /* if we broke out, then we have something here,	    
+	     * we can only delete it once, so do that.
+	     */
+	    if(sr && sameaddr(&sr->that.host_addr, peer))
+	    {
+		plog("peer %s for connection %s deleting - claimed to have crashed"
+		     , peerstr
+		     , thisc->name);
+		delete_states_by_connection(thisc);
+	    }
+	}
+    }
+}
+
 /* Duplicate a Phase 1 state object, to create a Phase 2 object.
  * Caller must schedule an event for this object so that it doesn't leak.
  * Caller must insert_state().
@@ -511,6 +563,21 @@ duplicate_state(struct state *st)
     return nst;
 }
 
+#if 1
+void for_each_state(void *(f)(struct state *, void *data), void *data)
+{
+	struct state *st, *ocs = cur_state;
+	int i;
+	for (i=0; i<STATE_TABLE_SIZE; i++) {
+		for (st = statetable[i]; st != NULL; st = st->st_hashchain_next) {
+			set_cur_state(st);
+			f(st, data);
+		}
+	}
+	cur_state = ocs;
+}
+#endif
+
 /*
  * Find a state object.
  */
@@ -630,6 +697,7 @@ state_eroute_usage(ip_subnet *ours, ip_subnet *his
 	{
 	    struct connection *c = st->st_connection;
 
+	    /* XXX spd-enum */
 	    if (IS_IPSEC_SA_ESTABLISHED(st->st_state)
 		&& c->spd.eroute_owner == st->st_serialno
 		&& c->spd.routing == RT_ROUTED_TUNNEL
@@ -673,6 +741,7 @@ void fmt_state(struct state *st, time_t n
 	? "; newest ISAKMP" : "";
     const char *np2 = c->newest_ipsec_sa == st->st_serialno
 	? "; newest IPSEC" : "";
+    /* XXX spd-enum */
     const char *eo = c->spd.eroute_owner == st->st_serialno
 	? "; eroute owner" : "";
 
