@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: state.h,v 1.2 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: state.h,v 1.1.1.1 2003/10/31 17:57:09 ken Exp $
  */
 
 #include <sys/types.h>
@@ -53,7 +53,6 @@ extern msgid_t generate_msgid(struct state *isakmp_sa);
  */
 struct oakley_trans_attrs {
     u_int16_t encrypt;		/* Encryption algorithm */
-    u_int16_t enckeylen;	/* encryption key len (bits) */
     const struct encrypt_desc *encrypter;	/* package of encryption routines */
     u_int16_t hash;		/* Hash algorithm */
     const struct hash_desc *hasher;	/* package of hashing routines */
@@ -112,6 +111,7 @@ struct state
     int                st_whack_sock;          /* fd for our Whack TCP socket.
                                                 * Single copy: close when freeing struct.
                                                 */
+
     struct msg_digest *st_suspended_md;        /* suspended state-transition */
 
     struct oakley_trans_attrs st_oakley;
@@ -200,6 +200,10 @@ struct state
     struct event      *st_event;               /* backpointer for certain events */
     struct state      *st_hashchain_next;      /* Next in list */
     struct state      *st_hashchain_prev;      /* Previous in list */
+#ifdef NAT_TRAVERSAL
+    u_int32_t         nat_traversal;
+    ip_address        nat_oa;
+#endif
 };
 
 /* global variables */
@@ -235,8 +239,13 @@ extern struct state
 
 extern void show_states_status(void);
 
+#if 1
+void for_each_state(void *(f)(struct state *, void *data), void *data);
+#endif
+
 extern void find_my_cpi_gap(cpi_t *latest_cpi, cpi_t *first_busy_cpi);
 extern ipsec_spi_t uniquify_his_cpi(ipsec_spi_t cpi, struct state *st);
 extern void fmt_state(struct state *st, time_t n
 		     , char *state_buf, size_t state_buf_len
 		     , char *state_buf2, size_t state_buf_len2);
+extern void delete_states_by_peer(ip_address *peer);
