@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: timer.c,v 1.2 2003/09/12 19:23:33 ken Exp $
+ * RCSID $Id: timer.c,v 1.1.1.1 2003/10/31 17:57:09 ken Exp $
  */
 
 #include <stdio.h>
@@ -22,6 +22,7 @@
 #include <unistd.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <sys/queue.h>
 
 #include <freeswan.h>
 
@@ -44,6 +45,10 @@
 #include "timer.h"
 #include "whack.h"
 
+#ifdef NAT_TRAVERSAL
+#include "nat_traversal.h"
+#endif
+
 /* monotonic version of time(3) */
 time_t
 now(void)
@@ -405,6 +410,12 @@ handle_timer_event(void)
 	    delete_state(st);
 	    break;
 
+#ifdef NAT_TRAVERSAL
+	case EVENT_NAT_T_KEEPALIVE:
+	    nat_traversal_ka_event();
+	    break;
+#endif
+
 	default:
 	    loglog(RC_LOG_SERIOUS, "INTERNAL ERROR: ignoring unknown expiring event %s"
 		, enum_show(&timer_event_names, type));
