@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: whack.c,v 1.3 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: whack.c,v 1.1.1.1 2003/10/31 17:57:09 ken Exp $
  */
 
 #include <stdio.h>
@@ -67,6 +67,7 @@ help(void)
 	    " [--dnskeyondemand]"
 	    " \\\n   "
 	    " [--updown <updown>]"
+	    " \\\n   "
 	    " --to"
 	    " (--host <ip-address> | --id <identity> | --cert <path>)"
 	    " [--ca <distinguished name>]"
@@ -79,6 +80,7 @@ help(void)
 	    " [--dnskeyondemand]"
 	    " \\\n   "
 	    " [--updown <updown>]"
+	    " \\\n   "
 	    " [--psk]"
 	    " [--rsasig]"
 	    " \\\n   "
@@ -95,9 +97,6 @@ help(void)
 	    " [--reykeyfuzz <percentage>]"
 	    " \\\n   "
 	    " [--keyingtries <count>]"
-	    " \\\n   "
-	    " [--esp <esp-algos>]"
-	    " \\\n   "
 	    " [--dontrekey]"
 	    " \\\n   "
 	    " [--initiateontraffic|--pass|--drop|--reject]"
@@ -127,6 +126,7 @@ help(void)
 	    "\n\n"
 	"deletestate: whack"
 	    " --deletestate <state_object_number>"
+            " --crash <ip-address>"
 	    "\n\n"
 	"pubkey: whack"
 	    " --keyid <id>"
@@ -271,6 +271,7 @@ enum {
     OPT_OPPO_THERE,
 
     OPT_ASYNC,
+    OPT_DELETECRASH,
 
 #   define OPT_LAST OPT_ASYNC	/* last "normal" option */
 
@@ -320,11 +321,9 @@ enum {
     CD_IPSECLIFETIME,
     CD_RKMARGIN,
     CD_RKFUZZ,
-    CD_KTRIES,
-    CD_IKE,
-    CD_PFSGROUP,
-    CD_ESP	
-#   define CD_LAST CD_ESP	/* last connection description */
+    CD_KTRIES
+
+#   define CD_LAST CD_KTRIES	/* last connection description */
 
 #ifdef DEBUG	/* must be last so others are less than 32 to fit in lset_t */
 #   define DBGOPT_FIRST DBGOPT_NONE
@@ -390,6 +389,7 @@ static const struct option long_opts[] = {
     { "terminate", no_argument, NULL, OPT_TERMINATE + OO },
     { "delete", no_argument, NULL, OPT_DELETE + OO },
     { "deletestate", required_argument, NULL, OPT_DELETESTATE + OO + NUMERIC_ARG },
+    { "crash", required_argument, NULL, OPT_DELETECRASH + OO },
     { "listen", no_argument, NULL, OPT_LISTEN + OO },
     { "unlisten", no_argument, NULL, OPT_UNLISTEN + OO },
     { "utc", no_argument, NULL, OPT_UTC + OO },
@@ -468,9 +468,6 @@ static const struct option long_opts[] = {
     { "rekeywindow", required_argument, NULL, CD_RKMARGIN + OO + NUMERIC_ARG },	/* OBSOLETE */
     { "rekeyfuzz", required_argument, NULL, CD_RKFUZZ + OO + NUMERIC_ARG },
     { "keyingtries", required_argument, NULL, CD_KTRIES + OO + NUMERIC_ARG },
-    { "ike", required_argument, NULL, CD_IKE + OO },
-    { "pfsgroup", required_argument, NULL, CD_PFSGROUP + OO },
-    { "esp", required_argument, NULL, CD_ESP + OO },
 
 #ifdef DEBUG
     { "debug-none", no_argument, NULL, DBGOPT_NONE + OO },
@@ -646,7 +643,6 @@ int
 main(int argc, char **argv)
 {
     struct whack_message msg;
-    char esp_buf[256];	/* uses snprintf */
     lset_t
 	opts_seen = LEMPTY,
 	cd_seen = LEMPTY,
@@ -662,19 +658,11 @@ main(int argc, char **argv)
 #else
     assert(OPTION_OFFSET + CD_LAST < NUMERIC_ARG);
 #endif
-    /*
     assert(OPT_LAST - OPT_FIRST < 32);
     assert(END_LAST - END_FIRST < 32);
     assert(CD_LAST - CD_FIRST < 32);
-    */
-    assert(OPT_LAST - OPT_FIRST < (sizeof cd_seen * BITS_PER_BYTE));
-    assert(END_LAST - END_FIRST < (sizeof cd_seen * BITS_PER_BYTE));
-    assert(CD_LAST - CD_FIRST < (sizeof cd_seen * BITS_PER_BYTE));
 #ifdef DEBUG	/* must be last so others are less than 32 to fit in lset_t */
-    /*
     assert(DBGOPT_LAST - DBGOPT_FIRST < 32);
-    */
-    assert(DBGOPT_LAST - DBGOPT_FIRST < (sizeof cd_seen * BITS_PER_BYTE));
 #endif
     /* check that POLICY bit assignment matches with CD_ */
     assert(LELEM(CD_DONT_REKEY - CD_POLICY_FIRST) == POLICY_DONT_REKEY);
@@ -686,9 +674,6 @@ main(int argc, char **argv)
     msg.name = NULL;
     msg.keyid = NULL;
     msg.keyval.ptr = NULL;
-    msg.esp = NULL;
-    msg.ike = NULL;
-    msg.pfsgroup = NULL;
 
     msg.sa_ike_life_seconds = OAKLEY_ISAKMP_SA_LIFETIME_DEFAULT;
     msg.sa_ipsec_life_seconds = PLUTO_SA_LIFE_DURATION_DEFAULT;
@@ -890,6 +875,14 @@ main(int argc, char **argv)
 	    msg.whack_deletestateno = opt_whole;
 	    continue;
 
+	case OPT_DELETECRASH:   /* --crash <ip-address> */
+	    msg.whack_crash = TRUE;
+	    tunnel_af_used_by = long_opts[long_index].name;
+	    diagq(ttoaddr(optarg, 0, msg.tunnel_addr_family, &msg.whack_crash_peer), optarg);
+	    if (isanyaddr(&msg.whack_crash_peer))
+		diagq("0.0.0.0 or 0::0 isn't a valid client address", optarg);
+	    continue;
+
 	case OPT_LISTEN:	/* --listen */
 	    msg.whack_listen = TRUE;
 	    continue;
@@ -1046,8 +1039,19 @@ main(int argc, char **argv)
 	    if (end_seen & LELEM(END_CLIENTWITHIN - END_FIRST))
 		diag("--client conflicts with --clientwithin");
 	    tunnel_af_used_by = long_opts[long_index].name;
+#ifdef VIRTUAL_IP
+	    if ( ((strlen(optarg)>=6) && (strncmp(optarg,"vhost:",6)==0)) ||
+		((strlen(optarg)>=5) && (strncmp(optarg,"vnet:",5)==0)) ) {
+		msg.right.virt = optarg;
+	    }
+	    else {
+		diagq(ttosubnet(optarg, 0, msg.tunnel_addr_family, &msg.right.client), optarg);
+		msg.right.has_client = TRUE;
+	    }
+#else
 	    diagq(ttosubnet(optarg, 0, msg.tunnel_addr_family, &msg.right.client), optarg);
 	    msg.right.has_client = TRUE;
+#endif
 	    msg.policy |= POLICY_TUNNEL;	/* client => tunnel */
 	    continue;
 
@@ -1074,6 +1078,7 @@ main(int argc, char **argv)
 	    msg.right.updown = optarg;
 	    continue;
 
+
 	case CD_TO:		/* --to */
 	    /* process right end, move it to left, reset it */
 	    if (!LHAS(end_seen, END_HOST - END_FIRST))
@@ -1136,18 +1141,6 @@ main(int argc, char **argv)
 	    msg.sa_keying_tries = opt_whole;
 	    continue;
 
-	case CD_IKE:	/* --ike <ike_alg1,ike_alg2,...> */
-	    msg.ike = optarg;
-	    continue;
-	    
-	case CD_PFSGROUP:	/* --pfsgroup modpXXXX */
-	    msg.pfsgroup = optarg;
-	    continue;
-
-	case CD_ESP:	/* --esp <esp_alg1,esp_alg2,...> */
-	    msg.esp = optarg;
-	    continue;
-
 	case CD_CONNIPV4:
 	    if (LHAS(cd_seen, CD_CONNIPV6 - CD_FIRST))
 		diag("--ipv4 conflicts with --ipv6");
@@ -1362,26 +1355,23 @@ main(int argc, char **argv)
     next_str = msg.string;
     str_roof = &msg.string[sizeof(msg.string)];
 
-    /* build esp message as esp="<esp>;<pfsgroup>" */
-    if (msg.pfsgroup) {
-	    snprintf(esp_buf, sizeof (esp_buf), "%s;%s", 
-		    msg.esp ? msg.esp : "",
-		    msg.pfsgroup ? msg.pfsgroup : "");
-	    msg.esp=esp_buf;
-    }
     if (!pack_str(&msg.name)		/* string  1 */
     || !pack_str(&msg.left.id)		/* string  2 */
     || !pack_str(&msg.left.cert)	/* string  3 */
     || !pack_str(&msg.left.ca)		/* string  4 */
     || !pack_str(&msg.left.updown)	/* string  5 */
+#ifdef VIRTUAL_IP
+    || !pack_str(&msg.left.virt)
+#endif
     || !pack_str(&msg.right.id)		/* string  6 */
     || !pack_str(&msg.right.cert)	/* string  7 */
     || !pack_str(&msg.right.ca)		/* string  8 */
     || !pack_str(&msg.right.updown)	/* string  9 */
+#ifdef VIRTUAL_IP
+    || !pack_str(&msg.right.virt)
+#endif
     || !pack_str(&msg.keyid)		/* string 10 */
     || !pack_str(&msg.myid)		/* string 11 */
-    || !pack_str(&msg.ike)		/* string 12 */
-    || !pack_str(&msg.esp)		/* string 13 */
     || str_roof - next_str < (ptrdiff_t)msg.keyval.len)    /* chunk (sort of string 5) */
 	diag("too many bytes of strings to fit in message to pluto");
 
