@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: whack.h,v 1.3 2003/09/15 12:57:39 jjo Exp $
+ * RCSID $Id: whack.h,v 1.1.1.1 2003/10/31 17:57:10 ken Exp $
  */
 
 #include <freeswan.h>
@@ -33,7 +33,7 @@
  */
 
 #define WHACK_BASIC_MAGIC (((((('w' << 8) + 'h') << 8) + 'k') << 8) + 24)
-#define WHACK_MAGIC (((((('w' << 8) + 'h') << 8) + 'k') << 8) + 25)
+#define WHACK_MAGIC (((((('w' << 8) + 'h') << 8) + 'k') << 8) + 26)
 
 /* struct whack_end is a lot like connection.h's struct end
  * It differs because it is going to be shipped down a socket
@@ -55,6 +55,9 @@ struct whack_end {
     u_int16_t host_port;	/* host order */
     u_int16_t port;		/* host order */
     u_int8_t protocol;
+#ifdef VIRTUAL_IP
+    char *virt;
+#endif
  };
 
 struct whack_message {
@@ -102,10 +105,6 @@ struct whack_message {
     sa_family_t addr_family;	/* between gateways */
     sa_family_t tunnel_addr_family;	/* between clients */
 
-    char *ike;		/* ike algo string (separated by commas) */
-    char *pfsgroup;	/* pfsgroup will be "encapsulated" in esp string for pluto */
-    char *esp;		/* esp algo string (separated by commas) */
-
     /* for WHACK_KEY: */
     bool whack_key;
     bool whack_addkey;
@@ -143,6 +142,10 @@ struct whack_message {
     /* for WHACK_LISTEN: */
     bool whack_listen, whack_unlisten;
 
+    /* for WHACK_CRASH - note if a remote peer is known to have rebooted */
+    bool whack_crash;
+    ip_address whack_crash_peer;
+
     /* for WHACK_LIST */
     bool whack_utc;
     u_char whack_list;
