@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: rsasigkey.c,v 1.1.1.1 2003/09/12 19:03:33 ken Exp $
+ * RCSID $Id: rsasigkey.c,v 1.1.1.1 2003/10/31 17:57:10 ken Exp $
  */
 
 #include <sys/types.h>
@@ -395,8 +395,8 @@ int eval;			/* value of e; 0 means don't bother w. tweak */
 	}
 
 	len = mpz_sizeinbase(var, 2);
-	assert(len == nbits || len == nbits+1);
-	if (len == nbits+1) {
+	assert(len == (size_t)nbits || len == (size_t)(nbits+1));
+	if (len == (size_t)(nbits+1)) {
 		report("carry out occurred (!), retrying...");
 		mpz_clear(var);
 		initprime(var, nbits, eval);
