@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char spi_c_version[] = "RCSID $Id: spi.c,v 1.2 2003/09/15 12:57:41 jjo Exp $";
+char spi_c_version[] = "RCSID $Id: spi.c,v 1.1.1.1 2003/10/31 17:57:12 ken Exp $";
 
 #include <asm/types.h>
 #include <sys/types.h>
@@ -59,18 +59,6 @@ char spi_c_version[] = "RCSID $Id: spi.c,v 1.2 2003/09/15 12:57:41 jjo Exp $";
 
 struct encap_msghdr *em;
 
-/* 	
- * 	Manual conn support for ipsec_alg (modular algos).
- * 	Rather ugly to include from pluto dir but avoids
- * 	code duplication.
- */
-#ifndef NO_KERNEL_ALG
-#include "../pluto/alg_info.h"
-#include "../pluto/constants.h"
-struct connection;
-#include "../pluto/kernel_alg.h"
-#endif /* NO_KERNEL_ALG */
-
 char *program_name;
 int debug = 0;
 int saref = 0;
@@ -84,20 +72,6 @@ ip_address edst, dst, src;
 int address_family = 0;
 unsigned char proto = 0;
 int alg = 0;
-
-#ifndef NO_KERNEL_ALG
-/* 
- * 	Manual connection support for modular algos (ipsec_alg) --Juanjo.
- */
-#define XF_OTHER_ALG (XF_CLR-1)	/* define magic XF_ symbol for alg_info's */
-#include <assert.h>
-const char *alg_string = NULL;	/* algorithm string */
-struct alg_info_esp *alg_info = NULL;	/* algorithm info got from string */
-struct esp_info *esp_info = NULL;	/* esp info from 1st (only) element */
-const char *alg_err;		/* auxiliar for parsing errors */
-int proc_read_ok = 0;		/* /proc/net/pf_key_support read ok */
-#endif /* NO_KERNEL_ALG */
-
 int replay_window = 0;
 char sa[SATOT_BUF];
 
@@ -493,50 +467,6 @@ main(int argc, char *argv[])
 				alg = XF_ESP3DESSHA196;
 			} else if(!strcmp(optarg, "3des")) {
 				alg = XF_ESP3DES;
-#ifndef NO_KERNEL_ALG
-			} else if((alg_info=alg_info_esp_create_from_str(optarg, &alg_err))) {
-				int esp_ealg_id, esp_aalg_id;
-				alg = XF_OTHER_ALG;
-				if (alg_info->alg_info_cnt>1) {
-					fprintf(stderr, "%s: Invalid encryption algorithm '%s' "
-						"follows '--esp' option: lead too many(%d) "
-						"transforms\n",
-						program_name, optarg, alg_info->alg_info_cnt);
-					exit(1);
-				}
-				alg_string=optarg;
-				esp_info=&alg_info->esp[0];
-				if (debug) {
-					fprintf(stdout, "%s: alg_info: cnt=%d ealg[0]=%d aalg[0]=%d\n",
-						program_name, 
-						alg_info->alg_info_cnt,
-						esp_info->encryptalg,
-						esp_info->authalg);
-				}
-				esp_ealg_id=esp_info->esp_ealg_id;
-				esp_aalg_id=esp_info->esp_aalg_id;
-				if (kernel_alg_proc_read()==0) {
-					proc_read_ok++;
-					if (!kernel_alg_esp_enc_ok(esp_ealg_id, 0, 0))
-					{
-						fprintf(stderr, "%s: ESP encryptalg=%d (\"%s\") "
-								"not present\n",
-							program_name,
-							esp_ealg_id,
-							enum_name(&esp_transformid_names, esp_ealg_id));
-						exit(1);
-					}
-					if (!kernel_alg_esp_auth_ok(esp_aalg_id, 0))
-					{
-						fprintf(stderr, "%s: ESP authalg=%d (\"%s\")"
-								"not present\n",
-							program_name,
-							esp_aalg_id,
-							enum_name(&auth_alg_names, esp_aalg_id));
-						exit(1);
-					}
-				}
-#endif /* NO_KERNEL_ALG */
 			} else {
 				fprintf(stderr, "%s: Invalid encryption algorithm '%s' follows '--esp' option.\n",
 					program_name, optarg);
@@ -957,63 +887,6 @@ main(int argc, char *argv[])
 	}
 
 	switch(alg) {
-#ifndef NO_KERNEL_ALG
-	case XF_OTHER_ALG: 
-		/* validate keysizes */
-		if (proc_read_ok) {
-		       const struct sadb_alg *alg_p;
-		       int keylen, minbits, maxbits;
-		       alg_p=kernel_alg_sadb_alg_get(SADB_SATYPE_ESP,SADB_EXT_SUPPORTED_ENCRYPT, 
-				       esp_info->encryptalg);
-		       assert(alg_p);
-		       keylen=enckeylen * 8;
-
-		       if (alg_p->sadb_alg_id==ESP_3DES || alg_p->sadb_alg_id==ESP_DES) {
-			       maxbits=minbits=alg_p->sadb_alg_minbits * 8 /7;
-		       } else {
-			       minbits=alg_p->sadb_alg_minbits;
-			       maxbits=alg_p->sadb_alg_maxbits;
-		       }
-		       /* 
-			* if explicit keylen told in encrypt algo, eg "aes128"
-			* check actual keylen "equality"
-			*/
-		       if (esp_info->esp_ealg_keylen &&
-			       esp_info->esp_ealg_keylen!=keylen) {
-			       fprintf(stderr, "%s: invalid encryption keylen=%d, "
-					       "required %d by encrypt algo string=\"%s\"\n",
-				       program_name, 
-				       keylen,
-				       esp_info->esp_ealg_keylen,
-				       alg_string);
-			       exit(1);
-
-		       }
-		       /* thanks DES for this sh*t */
-
-		       if (minbits > keylen || maxbits < keylen) {
-			       fprintf(stderr, "%s: invalid encryption keylen=%d, "
-					       "must be between %d and %d bits\n",
-					       program_name, 
-					       keylen, minbits, maxbits);
-			       exit(1);
-		       }
-		       alg_p=kernel_alg_sadb_alg_get(SADB_SATYPE_ESP,SADB_EXT_SUPPORTED_AUTH, 
-				       esp_info->authalg);
-		       assert(alg_p);
-		       keylen=authkeylen * 8;
-		       minbits=alg_p->sadb_alg_minbits;
-		       maxbits=alg_p->sadb_alg_maxbits;
-		       if (minbits > keylen || maxbits < keylen) {
-			       fprintf(stderr, "%s: invalid auth keylen=%d, "
-					       "must be between %d and %d bits\n",
-					       program_name, 
-					       keylen, minbits, maxbits);
-			       exit(1);
-		       }
-
-		}
-#endif /* NO_KERNEL_ALG */
 	case XF_IP4:
 	case XF_IP6:
 	case XF_DEL:
@@ -1076,9 +949,6 @@ main(int argc, char *argv[])
 	case XF_ESP3DESSHA196:
 	case XF_ESP3DES:
 	case XF_COMPDEFLATE:
-#ifndef NO_KERNEL_ALG
-	case XF_OTHER_ALG:
-#endif /* NO_KERNEL_ALG */
 		break;
 	default:
 		fprintf(stderr, "%s: No action chosen.  See '%s --help' for usage.\n",
@@ -1198,15 +1068,6 @@ main(int argc, char *argv[])
 	case XF_ESP3DESSHA196:
 		authalg = SADB_AALG_SHA1HMAC;
 		break;
-#ifndef NO_KERNEL_ALG
-	case XF_OTHER_ALG:
-		authalg= esp_info->authalg;
-		if(debug) {
-			fprintf(stdout, "%s: debug: authalg=%d\n",
-				program_name, authalg);
-		}
-		break;
-#endif /* NO_KERNEL_ALG */
 	case XF_ESP3DESMD5:
 	default:
 		authalg = SADB_AALG_NONE;
@@ -1220,15 +1081,6 @@ main(int argc, char *argv[])
 	case XF_COMPDEFLATE:
 		encryptalg = SADB_X_CALG_DEFLATE;
 		break;
-#ifndef NO_KERNEL_ALG
-	case XF_OTHER_ALG:
-		encryptalg= esp_info->encryptalg;
-		if(debug) {
-			fprintf(stdout, "%s: debug: encryptalg=%d\n",
-				program_name, encryptalg);
-		}
-		break;
-#endif /* NO_KERNEL_ALG */
 	default:
 		encryptalg = SADB_EALG_NONE;
 	}
@@ -1409,12 +1261,6 @@ main(int argc, char *argv[])
 #endif /* PFKEY_PROXY */
 		
 		switch(alg) {
-#ifndef NO_KERNEL_ALG
-		/*	Allow no auth ... after all is local root decision 8)  */
-		case XF_OTHER_ALG:
-			if (!authalg)
-				break;
-#endif /* NO_KERNEL_ALG */
 		case XF_AHHMACMD5:
 		case XF_ESP3DESMD596:
 		case XF_AHHMACSHA1:
@@ -1441,9 +1287,6 @@ main(int argc, char *argv[])
 		case XF_ESP3DES:
 		case XF_ESP3DESMD596:
 		case XF_ESP3DESSHA196:
-#ifndef NO_KERNEL_ALG
-		case XF_OTHER_ALG:
-#endif /* NO_KERNEL_ALG */
 			if((error = pfkey_key_build(&extensions[SADB_EXT_KEY_ENCRYPT],
 						    SADB_EXT_KEY_ENCRYPT,
 						    enckeylen * 8,
@@ -1628,7 +1471,7 @@ main(int argc, char *argv[])
 			pfkey_msg = (struct sadb_msg *)pfkey_buf;
 			
 			/* first, see if we got enough for an sadb_msg */
-			if(readlen < sizeof(struct sadb_msg)) {
+			if((size_t)readlen < sizeof(struct sadb_msg)) {
 				if(debug) {
 					printf("%s: runt packet of size: %ld (<%lu)\n",
 					       program_name, (long)readlen, (unsigned long)sizeof(struct sadb_msg));
@@ -1696,11 +1539,12 @@ main(int argc, char *argv[])
 
 /*
  * $Log: spi.c,v $
- * Revision 1.2  2003/09/15 12:57:41  jjo
- * . alg-0.8.1_rc10 merged into sfs-2.02+x509-1.4.6
+ * Revision 1.1.1.1  2003/10/31 17:57:12  ken
  *
- * Revision 1.1.1.1  2003/09/12 19:03:34  ken
- * Stock 2.02
+ * Stock 2.03
+ *
+ * Revision 1.100  2003/09/10 00:01:38  mcr
+ * 	fixes for gcc 3.3 from Matthias Bethke <Matthias.Bethke@gmx.net>
  *
  * Revision 1.99  2003/06/07 16:42:10  dhr
  *
