@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char spigrp_c_version[] = "RCSID $Id: spigrp.c,v 1.1.1.1 2003/09/12 19:03:35 ken Exp $";
+char spigrp_c_version[] = "RCSID $Id: spigrp.c,v 1.1.1.1 2003/10/31 17:57:12 ken Exp $";
 
 
 #include <sys/types.h>
@@ -428,7 +428,7 @@ main(int argc, char **argv)
 		if((error = write(pfkey_sock,
 				  pfkey_msg,
 				  pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) !=
-		   pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN) {
+		   (ssize_t)(pfkey_msg->sadb_msg_len * IPSEC_PFKEYv2_ALIGN)) {
 			fprintf(stderr, "%s: pfkey write failed, returning %d with errno=%d.\n",
 				program_name, error, errno);
 			pfkey_extensions_free(extensions);
@@ -492,8 +492,12 @@ main(int argc, char **argv)
 }
 /*
  * $Log: spigrp.c,v $
- * Revision 1.1.1.1  2003/09/12 19:03:35  ken
- * Stock 2.02
+ * Revision 1.1.1.1  2003/10/31 17:57:12  ken
+ *
+ * Stock 2.03
+ *
+ * Revision 1.46  2003/09/10 00:01:42  mcr
+ * 	fixes for gcc 3.3 from Matthias Bethke <Matthias.Bethke@gmx.net>
  *
  * Revision 1.45  2003/01/30 02:33:07  rgb
  *
