@@ -1,7 +1,7 @@
 #!/bin/sh
 
 #
-# $Id: functions.sh,v 1.1.1.1 2003/09/12 19:05:30 ken Exp $
+# $Id: functions.sh,v 1.1.1.1 2003/10/31 17:58:18 ken Exp $
 #
 
 preptest() {
@@ -16,8 +16,8 @@ preptest() {
   
     # make sure no results survive from a past run
     if [ ! -z "$testdir" ] ; then
-	rm -rf "$testdir/OUTPUT"
-	mkdir -p "$testdir/OUTPUT"
+	rm -rf "$testdir/OUTPUT"${KLIPS_MODULE}
+	mkdir -p "$testdir/OUTPUT"${KLIPS_MODULE}
     fi
 
     cd $testdir
@@ -66,7 +66,7 @@ lookforcore() {
 	ROOT=$POOLSPACE/$host/root
 	if [ -f $ROOT/var/tmp/core ]
 	then
-	    mv $ROOT/var/tmp/core OUTPUT/pluto.$host.core
+	    mv $ROOT/var/tmp/core OUTPUT${KLIPS_MODULE}/pluto.$host.core
 	    echo "pluto.$host.core "
         fi
     done
@@ -302,7 +302,7 @@ roguekill() {
 #   $REGRESSRESULTS/$REPORT_NAME/status
 #
 # If the status is negative, then the "OUTPUT${KLIPS_MODULE}" directory of the test is
-# copied to $REGRESSRESULTS/$REPORT_NAME/OUTPUT as well.
+# copied to $REGRESSRESULTS/$REPORT_NAME/OUTPUT${KLIPS_MODULE} as well.
 #
 # The file $testname/description.txt if it exists is copied as well.
 #
@@ -381,6 +381,7 @@ recordresults() {
 	 then
 	    :
 	 else
+	    # NOTE: ${KLIPS_MODULE} is part of $REPORT_NAME
 	    rm -rf $REGRESSRESULTS/$REPORT_NAME/OUTPUT
 	    mkdir -p $REGRESSRESULTS/$REPORT_NAME/OUTPUT
 	    tar -C $testname/OUTPUT${KLIPS_MODULE} -c -f - . | (cd $REGRESSRESULTS/$REPORT_NAME/OUTPUT && tar xf - )
@@ -540,9 +541,9 @@ klipstest() {
     recordresults $testdir "$testexpect" $stat $testdir${KLIPS_MODULE}
     if [ $stat = 0 ]
     then
-	echo '*******  PASSED '$testdir' ********'
+	echo '*******  PASSED '$testdir${KLIPS_MODULE}' ********'
     else
-	echo '*******  FAILED '$testdir' ********'
+	echo '*******  FAILED '$testdir${KLIPS_MODULE}' ********'
     fi
 }
 
@@ -632,21 +633,21 @@ skiptest() {
 
 do_make_install_test() {
 
-    rm -rf OUTPUT/root
-    mkdir -p OUTPUT/root
+    rm -rf OUTPUT${KLIPS_MODULE}/root
+    mkdir -p OUTPUT${KLIPS_MODULE}/root
 
     # locale affects sort order.
     LC_ALL=C export LC_ALL
 
     success=true
-    instdir=`cd OUTPUT/root && pwd`
+    instdir=`cd OUTPUT${KLIPS_MODULE}/root && pwd`
 
     prerunsetup
 
     if [ -n "$INSTALL_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS 
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS ) >OUTPUT/install1.txt 2>&1 || exit 1
+	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/install1.txt 2>&1 || exit 1
     fi
 
     if [ -n "$POSTINSTALL_SCRIPT" ]
@@ -657,21 +658,21 @@ do_make_install_test() {
     if [ -n "$INSTALL2_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS 
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS ) >OUTPUT/install2.txt 2>&1 || exit 1
+	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $INSTALL2_FLAGS ) >OUTPUT${KLIPS_MODULE}/install2.txt 2>&1 || exit 1
     fi
 
     if [ -n "$UNINSTALL_FLAGS" ]
     then
 	$MAKE_INSTALL_TEST_DEBUG && echo make --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS 
-	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS ) >OUTPUT/uninstall.txt 2>&1 || exit 1
+	(cd $FREESWANSRCDIR && eval make FREESWANSRCDIR=`pwd` --no-print-directory DESTDIR=$instdir $UNINSTALL_FLAGS ) >OUTPUT${KLIPS_MODULE}/uninstall.txt 2>&1 || exit 1
     fi
 
     if [ -n "$REF_MAKE_DOC_OUTPUT" ]
     then
-      rm -f OUTPUT/$REF_MAKE_DOC_OUTPUT.txt
+      rm -f OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt
 
-      (cd $FREESWANSRCDIR/doc && eval make FREESWANSRCDIR=$FREESWANSRCDIR clean --no-print-directory && eval make FREESWANSRCDIR=$FREESWANSRCDIR --no-print-directory ) | sort >OUTPUT/$REF_MAKE_DOC_OUTPUT.txt
-      if diff -u -w -b -B $REF_MAKE_DOC_OUTPUT.txt OUTPUT/$REF_MAKE_DOC_OUTPUT.txt >OUTPUT/$REF_MAKE_DOC_OUTPUT.diff
+      (cd $FREESWANSRCDIR/doc && eval make FREESWANSRCDIR=$FREESWANSRCDIR clean --no-print-directory && eval make FREESWANSRCDIR=$FREESWANSRCDIR --no-print-directory ) | sort >OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt
+      if diff -u -w -b -B $REF_MAKE_DOC_OUTPUT.txt OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.txt >OUTPUT${KLIPS_MODULE}/$REF_MAKE_DOC_OUTPUT.diff
       then
 	 echo "make doc output matched"
       else
@@ -682,10 +683,10 @@ do_make_install_test() {
 
     if [ -n "$REF_FIND_f_l_OUTPUT" ]
     then
-      rm -f OUTPUT/$REF_FIND_f_l_OUTPUT
+      rm -f OUTPUT${KLIPS_MODULE}/$REF_FIND_f_l_OUTPUT
 
-      (cd OUTPUT/root && find . \( -type f -or -type l \) -print ) | sort >OUTPUT/$REF_FIND_f_l_OUTPUT.txt
-      if diff -u -w -b -B $REF_FIND_f_l_OUTPUT.txt OUTPUT/$REF_FIND_f_l_OUTPUT.txt >OUTPUT/$REF_FIND_f_l_OUTPUT.diff
+      (cd OUTPUT${KLIPS_MODULE}/root && find . \( -type f -or -type l \) -print ) | sort >OUTPUT${KLIPS_MODULE}/$REF_FIND_f_l_OUTPUT.txt
+      if diff -u -w -b -B $REF_FIND_f_l_OUTPUT.txt OUTPUT${KLIPS_MODULE}/$REF_FIND_f_l_OUTPUT.txt >OUTPUT${KLIPS_MODULE}/$REF_FIND_f_l_OUTPUT.diff
       then
 	 echo "Install list file list matched"
       else
@@ -699,7 +700,7 @@ do_make_install_test() {
     then
       cat $REF_FILE_CONTENTS | while read reffile samplefile
       do
-	if diff -u -w -b -B $reffile $instdir/$samplefile >OUTPUT/$reffile.diff
+	if diff -u -w -b -B $reffile $instdir/$samplefile >OUTPUT${KLIPS_MODULE}/$reffile.diff
 	then 
 	    echo "Reffile $samplefile matched"
 	else
@@ -723,7 +724,7 @@ mkinsttest() {
     testdir=$1
     testexpect=$2
 
-    echo '**** Make Install RUNNING' $testdir '****' 
+    echo '**** Make Install RUNNING' $testdir${KLIPS_MODULE} '****' 
 
     FREESWANSRCDIR=`cd $FREESWANSRCDIR && pwd` export FREESWANSRCDIR
 
@@ -731,12 +732,12 @@ mkinsttest() {
     ( preptest $testdir mkinsttest && do_make_install_test )
     stat=$?
 
-    recordresults $testdir "$testexpect" $stat $testdir
+    recordresults $testdir "$testexpect" $stat $testdir${KLIPS_MODULE}
     if [ $stat = 0 ]
     then
-	echo '**** PASSED '$testdir' ********'
+	echo '**** PASSED '$testdir${KLIPS_MODULE}' ********'
     else
-	echo '**** FAILED '$testdir' ********'
+	echo '**** FAILED '$testdir${KLIPS_MODULE}' ********'
     fi
 
 }
@@ -749,11 +750,11 @@ mkinsttest() {
 
 do_rpm_install_test() {
 
-    rm -rf OUTPUT/root
-    mkdir -p OUTPUT/root
+    rm -rf OUTPUT${KLIPS_MODULE}/root
+    mkdir -p OUTPUT${KLIPS_MODULE}/root
 
     success=true
-    instdir=`cd OUTPUT/root && pwd`
+    instdir=`cd OUTPUT${KLIPS_MODULE}/root && pwd`
 
     prerunsetup
 
@@ -772,11 +773,11 @@ do_rpm_install_test() {
 	(cd $FREESWANSRCDIR/packaging/redhat && make clean --no-print-directory && make --no-print-directory RH_KERNELSRC=$RPM_KERNEL_SOURCE FREESWANSRCDIR=$FREESWANSRCDIR rpm )
     fi
     
-    mkdir OUTPUT/rpm
-    cp $FREESWANSRCDIR/packaging/redhat/rpms/RPMS/i386/*.rpm OUTPUT/rpm
+    mkdir OUTPUT${KLIPS_MODULE}/rpm
+    cp $FREESWANSRCDIR/packaging/redhat/rpms/RPMS/i386/*.rpm OUTPUT${KLIPS_MODULE}/rpm
 
     # while loop below winds up in sub-shell. Argh.
-    successfile=OUTPUT/success
+    successfile=OUTPUT${KLIPS_MODULE}/success
     echo $success >$successfile
 
     if [ -n "$REF_RPM_CONTENTS" ]
@@ -788,14 +789,14 @@ do_rpm_install_test() {
 	    continue;
 	fi
         # expand $rpmfile, which may have wildcards!
-	realfile=`eval echo OUTPUT/rpm/${rpmfile}`
+	realfile=`eval echo OUTPUT${KLIPS_MODULE}/rpm/${rpmfile}`
 	if [ ! -f $realfile ]
 	then
 	    echo "RPM production failed to build anything to match $rpmfile"
 	    echo false >$successfile
 	fi
-        rpm2cpio $realfile | cpio -it >OUTPUT/$rpmcontents.txt
-	if diff -u -w -b -B $rpmcontents.txt OUTPUT/$rpmcontents.txt >OUTPUT/$rpmcontents.diff
+        rpm2cpio $realfile | cpio -it >OUTPUT${KLIPS_MODULE}/$rpmcontents.txt
+	if diff -u -w -b -B $rpmcontents.txt OUTPUT${KLIPS_MODULE}/$rpmcontents.txt >OUTPUT${KLIPS_MODULE}/$rpmcontents.diff
 	then 
 	    echo "Reffile ($rpmcontents) for $realfile matched"
 	else
@@ -820,7 +821,7 @@ rpm_build_install_test() {
     testdir=$1
     testexpect=$2
 
-    echo '**** Make Install RUNNING' $testdir '****' 
+    echo '**** Make Install RUNNING' $testdir${KLIPS_MODULE} '****' 
 
     FREESWANSRCDIR=`cd $FREESWANSRCDIR && pwd` export FREESWANSRCDIR
 
@@ -833,12 +834,12 @@ rpm_build_install_test() {
 	stat='missing'
     fi
 
-    recordresults $testdir "$testexpect" $stat $testdir
+    recordresults $testdir "$testexpect" $stat $testdir${KLIPS_MODULE}
     if [ $stat = 0 ]
     then
-	echo '**** PASSED '$testdir' ********'
+	echo '**** PASSED '$testdir${KLIPS_MODULE}' ********'
     else
-	echo '**** FAILED '$testdir' ********'
+	echo '**** FAILED '$testdir${KLIPS_MODULE}' ********'
     fi
 }
 
@@ -854,7 +855,7 @@ libtest() {
     cc -g -o $testobj -D$symbol -I${LIBFREESWANDIR} -I${FREESWANSRCDIR}/linux/include -I${FREESWANSRCDIR} ${LIBFREESWANDIR}/$testsrc ${FREESWANLIB}
     rm -rf lib-$testobj/OUTPUT
     mkdir -p lib-$testobj/OUTPUT
-    ( ./$testobj -r >lib-$testobj/OUTPUT/$testobj.txt )
+    ( ./$testobj -r >lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.txt )
 
     TEST_PURPOSE=regress export TEST_PURPOSE
 
@@ -901,19 +902,19 @@ umlplutotest() {
     testdir=$1
     testexpect=$2
 
-    echo '***** UML PLUTO RUNNING' $testdir '*******' 
+    echo '***** UML PLUTO RUNNING' $testdir${KLIPS_MODULE} '*******' 
 
     export UML_BRAND="$$"
     ( export XHOST_LIST="EAST WEST"
       preptest $testdir umlplutotest && do_umlX_test )
     stat=$?
 
-    recordresults $testdir "$testexpect" $stat $testdir
+    recordresults $testdir "$testexpect" $stat $testdir${KLIPS_MODULE}
     if [ $stat = 0 ]
     then
-	echo '*******  PASSED '$testdir' ********'
+	echo '*******  PASSED '$testdir${KLIPS_MODULE}' ********'
     else
-	echo '*******  FAILED '$testdir' ********'
+	echo '*******  FAILED '$testdir${KLIPS_MODULE}' ********'
     fi
 }
 
@@ -927,8 +928,8 @@ do_kernel_patch_test() {
 
     set -e
 
-    rm -rf OUTPUT
-    mkdir -p OUTPUT
+    rm -rf OUTPUT${KLIPS_MODULE}
+    mkdir -p OUTPUT${KLIPS_MODULE}
 
     if [ -z "${KERNEL_VERSION}" ]
     then
@@ -957,10 +958,10 @@ do_kernel_patch_test() {
     fi
 
     # okay, we got some source code to play with!
-    mkdir OUTPUT/$kernel_var_name
+    mkdir OUTPUT${KLIPS_MODULE}/$kernel_var_name
 
     # get ourselves a kernel source tree.
-    if (cd OUTPUT/$kernel_var_name && lndir -silent $KERNEL_SRC . )
+    if (cd OUTPUT${KLIPS_MODULE}/$kernel_var_name && lndir -silent $KERNEL_SRC . )
     then
 	:
     else
@@ -968,25 +969,25 @@ do_kernel_patch_test() {
 	exit 99
     fi
 
-    env >OUTPUT/env.txt
+    env >OUTPUT${KLIPS_MODULE}/env.txt
 
     # now patch it. (set +x turns off any debugging there might have been)
     set -x
     set -v
     # the environment variable FREESWANSRCDIR should be correct
     # but the make macro FREESWANSRCDIR may be relative, and hence wrong
-    (cd ${FREESWANSRCDIR} && make FREESWANSRCDIR=`pwd` kernelpatch${KERNEL_VERSION} ) | tee OUTPUT/patchfile.patch | (cd OUTPUT/$kernel_var_name && patch -p1 2>&1 ) >OUTPUT/patch-output.txt 
+    (cd ${FREESWANSRCDIR} && make FREESWANSRCDIR=`pwd` kernelpatch${KERNEL_VERSION} ) | tee OUTPUT${KLIPS_MODULE}/patchfile.patch | (cd OUTPUT${KLIPS_MODULE}/$kernel_var_name && patch -p1 2>&1 ) >OUTPUT${KLIPS_MODULE}/patch-output.txt 
 
     # compare the patch.
     if [ -n "${REF_PATCH_OUTPUT}" ]
     then
-        consolediff "" OUTPUT/patch-output.txt $REF_PATCH_OUTPUT
+        consolediff "" OUTPUT${KLIPS_MODULE}/patch-output.txt $REF_PATCH_OUTPUT
     fi
 
     # normally, clean up the kernel output, as it is volumnous
     if [ -z "${KERNEL_PATCH_LEAVE_SOURCE}" ]
     then
-      rm -rf OUTPUT/$kernel_var_name
+      rm -rf OUTPUT${KLIPS_MODULE}/$kernel_var_name
     fi
 
     if $success
@@ -1035,12 +1036,12 @@ kernel_patch_test() {
 
 do_module_compile_test() {
 
-    rm -rf OUTPUT/module
-    mkdir -p OUTPUT/module
+    rm -rf OUTPUT${KLIPS_MODULE}/module
+    mkdir -p OUTPUT${KLIPS_MODULE}/module
     set -e
 
     success=false
-    moddir=`cd OUTPUT/module && pwd`
+    moddir=`cd OUTPUT${KLIPS_MODULE}/module && pwd`
 
     prerunsetup
 
@@ -1103,7 +1104,7 @@ do_module_compile_test() {
 	# if there is a KERNEL_CONFIG_FILE, then we have to 
 	# lndir, and "make oldconfig" the kernel to get something working.
 
-	LOCAL_KERNEL_SRC=`pwd`/OUTPUT/$kernel_var_name
+	LOCAL_KERNEL_SRC=`pwd`/OUTPUT${KLIPS_MODULE}/$kernel_var_name
 
 	rm -rf ${LOCAL_KERNEL_SRC}
 	mkdir -p ${LOCAL_KERNEL_SRC}
@@ -1116,7 +1117,7 @@ do_module_compile_test() {
 
 	cp ${KERNEL_CONFIG_FILE} ${LOCAL_KERNEL_SRC}/.config
 
-	(cd ${LOCAL_KERNEL_SRC} && make ARCH=${ARCH} SUBARCH=${SUBARCH} oldconfig ) >OUTPUT/oldconfig.txt
+	(cd ${LOCAL_KERNEL_SRC} && make ARCH=${ARCH} SUBARCH=${SUBARCH} oldconfig ) >OUTPUT${KLIPS_MODULE}/oldconfig.txt
 
 	# repoint ourselves here, so we use the just configured sources.
 	KERNEL_SRC=${LOCAL_KERNEL_SRC}
@@ -1133,14 +1134,14 @@ do_module_compile_test() {
 	MODULE_DEFCONFIG=`pwd`/$MODULE_DEFCONFIG
     fi
 
-    rm -f OUTPUT/module/ipsec.o
+    rm -f OUTPUT${KLIPS_MODULE}/module/ipsec.o
 
     cmd="(cd $FREESWANSRCDIR && make KERNELSRC=$KERNEL_SRC MODBUILDDIR=$moddir FREESWANSRCDIR=$FREESWANSRCDIR MODULE_DEFCONFIG=${MODULE_DEFCONFIG} MODULE_DEF_INCLUDE=${MODULE_DEF_INCLUDE} ARCH=${ARCH} SUBARCH=${SUBARCH} module )"
-    echo "# run as" >OUTPUT/doit.sh
-    echo "$cmd" >>OUTPUT/doit.sh
-    . OUTPUT/doit.sh
+    echo "# run as" >OUTPUT${KLIPS_MODULE}/doit.sh
+    echo "$cmd" >>OUTPUT${KLIPS_MODULE}/doit.sh
+    . OUTPUT${KLIPS_MODULE}/doit.sh
 
-    if [ -r OUTPUT/module/ipsec.o ]
+    if [ -r OUTPUT${KLIPS_MODULE}/module/ipsec.o ]
     then
 	success=true
     fi
@@ -1208,8 +1209,8 @@ do_umlX_test() {
     WESTOUTPUT=''
     PUBOUTPUT=''
 
-    rm -rf OUTPUT
-    mkdir -p OUTPUT
+    rm -rf OUTPUT${KLIPS_MODULE}
+    mkdir -p OUTPUT${KLIPS_MODULE}
 
     EXP2_ARGS=''
 
@@ -1259,7 +1260,7 @@ do_umlX_test() {
        fi
        export ${host}_START
 
-       eval "REF_${host}_CONSOLE_RAW=OUTPUT/${lhost}console.txt"
+       eval "REF_${host}_CONSOLE_RAW=OUTPUT${KLIPS_MODULE}/${lhost}console.txt"
        export REF_${host}_CONSOLE_RAW
        export ${host}_INIT_SCRIPT
        export ${host}_RUN_SCRIPT
@@ -1273,19 +1274,19 @@ do_umlX_test() {
     if [ -n "$REF_EAST_OUTPUT" ]
     then
 	EASTOUTPUT=`basename $REF_EAST_OUTPUT .txt `
-	EXP2_ARGS="$EXP2_ARGS -E OUTPUT/$EASTOUTPUT.pcap"
+	EXP2_ARGS="$EXP2_ARGS -E OUTPUT${KLIPS_MODULE}/$EASTOUTPUT.pcap"
     fi
 
     if [ -n "$REF_WEST_OUTPUT" ]
     then
 	WESTOUTPUT=`basename $REF_WEST_OUTPUT .txt `
-	EXP2_ARGS="$EXP2_ARGS -W OUTPUT/$WESTOUTPUT.pcap"
+	EXP2_ARGS="$EXP2_ARGS -W OUTPUT${KLIPS_MODULE}/$WESTOUTPUT.pcap"
     fi
 
     if [ -n "$REF_PUB_OUTPUT" ]
     then
 	PUBOUTPUT=`basename $REF_PUB_OUTPUT .txt`
-	EXP2_ARGS="$EXP2_ARGS -P OUTPUT/$PUBOUTPUT.pcap"
+	EXP2_ARGS="$EXP2_ARGS -P OUTPUT${KLIPS_MODULE}/$PUBOUTPUT.pcap"
     fi
 			    
     if [ "X$ARPREPLY" = "X--arpreply" ]
@@ -1300,9 +1301,9 @@ do_umlX_test() {
 
     EXP2_ARGS="$EXP2_ARGS "`setup_additional_hosts`
 
-    rm -f OUTPUT/eastconsole.txt
-    rm -f OUTPUT/westconsole.txt
-    rm -f OUTPUT/japanconsole.txt
+    rm -f OUTPUT${KLIPS_MODULE}/eastconsole.txt
+    rm -f OUTPUT${KLIPS_MODULE}/westconsole.txt
+    rm -f OUTPUT${KLIPS_MODULE}/japanconsole.txt
 
     cmd="expect -f $UTILS/Xhost-test.tcl -- -n $NJ $EXP2_ARGS "
     $NETJIGDEBUG && echo $cmd
@@ -1320,7 +1321,7 @@ do_umlX_test() {
     
 	if [ -n "${!consoleref}" ]
 	then
-	    consolediff $lhost OUTPUT/${lhost}console.txt ${!consoleref}
+	    consolediff $lhost OUTPUT${KLIPS_MODULE}/${lhost}console.txt ${!consoleref}
 	fi
     done
 
@@ -1353,11 +1354,17 @@ umlXhost() {
 }
 
 #
-# $Id: functions.sh,v 1.1.1.1 2003/09/12 19:05:30 ken Exp $
+# $Id: functions.sh,v 1.1.1.1 2003/10/31 17:58:18 ken Exp $
 #
 # $Log: functions.sh,v $
-# Revision 1.1.1.1  2003/09/12 19:05:30  ken
-# Stock 2.02
+# Revision 1.1.1.1  2003/10/31 17:58:18  ken
+#
+# Stock 2.03
+#
+# Revision 1.89  2003/10/01 16:13:56  dhr
+#
+# Make the -modules hack in testing/klips/dotests.sh actually work:
+# add ${KLIPS_MODULE} to almost every path with OUTPUT that didn't already have it.
 #
 # Revision 1.88  2003/08/21 22:38:06  mcr
 # 	sense of test was wrong for MODULE_DEFCONFIG
@@ -1375,4 +1382,4 @@ umlXhost() {
 # Revision 1.84  2003/05/03 23:26:02  mcr
 # 	added RCS Ids.
 #
-# 
\ No newline at end of file
+# 
