@@ -1,7 +1,7 @@
 #!/usr/bin/expect --
 
 #
-# $Id: localswitches.tcl,v 1.1.1.1 2003/09/12 19:05:30 ken Exp $
+# $Id: localswitches.tcl,v 1.1.1.1 2003/10/31 17:58:18 ken Exp $
 #
 
 source $env(FREESWANSRCDIR)/testing/utils/GetOpts.tcl
@@ -17,6 +17,8 @@ set netjig1 $spawn_id
 newswitch $netjig1 public
 newswitch $netjig1 east
 newswitch $netjig1 west
+newswitch $netjig1 northpublic
+newswitch $netjig1 southpublic
 
 foreach host $argv {
     system "$host single &"
@@ -27,6 +29,12 @@ puts "\nExit the netjig when you are done\n"
 set timeout -1
 interact -reset -i $netjig1 
 
+foreach host $argv {
+    system "uml_mconsole $host halt"
+}
+
+
+
 
 
 
