@@ -1,7 +1,7 @@
 #! /bin/sh 
 #
 # 
-# $Id: uml-functions.sh,v 1.1.1.1 2003/09/12 19:05:32 ken Exp $
+# $Id: uml-functions.sh,v 1.1.1.1 2003/10/31 17:58:19 ken Exp $
 #
 
 setup_make() {
@@ -55,7 +55,7 @@ setup_host_make() {
     echo "$TAB (cd ${BASICROOT} && find var -print | cpio -pd $POOLSPACE/$hostroot 2>/dev/null )"
 
     # make sure that we have /dev, /tmp and /var/run
-    echo "$TAB mkdir -p $hostroot/dev $hostroot/tmp $hostroot/var/run $hostroot/usr/share $hostroot/proc"
+    echo "$TAB mkdir -p $hostroot/dev $hostroot/tmp $hostroot/var/run $hostroot/usr/share $hostroot/proc $hostroot/var/log/pluto/peer"
 
     # root image may be debian, but we expect rh-style /etc/rc.d
     echo "$TAB mkdir -p $hostroot/etc/rc.d"
@@ -165,7 +165,7 @@ setup_host_make() {
 	echo "$TAB echo '# get $net value from baseconfig'          >>$startscript"
 	echo "$TAB echo . ${TESTINGROOT}/baseconfigs/net.$host.sh   >>$startscript"
 	echo "$TAB echo ''          >>$startscript"
-	echo "$TAB echo '$POOLSPACE/plain/linux ubd0=$POOLSPACE/$hostroot umid=$host \$\$net \$\$UML_DEBUG_OPT \$\$UML_"${host}"_OPT \$\$*' >>$startscript"
+	echo "$TAB echo '$POOLSPACE/plain/linux root=/dev/root rootfstype=hostfs rootflags=$POOLSPACE/$hostroot rw umid=$host \$\$net \$\$UML_DEBUG_OPT \$\$UML_"${host}"_OPT \$\$*' >>$startscript"
 	echo "$TAB chmod +x $startscript"
 	echo
 	depends="$depends $startscript"
@@ -179,7 +179,7 @@ setup_host_make() {
     echo "$TAB echo '# get $net value from baseconfig'          >>$startscript"
     echo "$TAB echo . ${TESTINGROOT}/baseconfigs/net.$host.sh   >>$startscript"
     echo "$TAB echo ''          >>$startscript"
-    echo "$TAB echo '$POOLSPACE/$host/linux ubd0=$POOLSPACE/$hostroot umid=$host \$\$net \$\$UML_DEBUG_OPT \$\$UML_"${host}"_OPT \$\$*' >>$startscript"
+    echo "$TAB echo '$POOLSPACE/$host/linux root=/dev/root rootfstype=hostfs rootflags=$POOLSPACE/$hostroot rw umid=$host \$\$net \$\$UML_DEBUG_OPT \$\$UML_"${host}"_OPT \$\$*' >>$startscript"
     echo "$TAB chmod +x $startscript"
     echo
     depends="$depends $startscript"
@@ -274,8 +274,16 @@ setup_host() {
 
 #
 # $Log: uml-functions.sh,v $
-# Revision 1.1.1.1  2003/09/12 19:05:32  ken
-# Stock 2.02
+# Revision 1.1.1.1  2003/10/31 17:58:19  ken
+#
+# Stock 2.03
+#
+# Revision 1.28  2003/09/02 19:45:48  mcr
+# 	use rootfs= directive instead of ubd0= directive for
+# 	setting hostfs root file system.
+#
+# Revision 1.27  2003/07/30 16:46:57  mcr
+# 	created /var/log/pluto/peer directory in UMLs.
 #
 # Revision 1.26  2003/06/22 21:53:53  mcr
 # 	generated makefile list had $hostroot missing, put it in with
